<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: field.define.php 134 2012-04-05 20:45:38Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

/**
 * Field Define class
 *
 * @package	Collector
 */
class CollectorField_Define extends CollectorField
{
	/**
	 * type
	 * 
	 * @var string
	 */
	public $type = 'define';
	
	/**
	 * Object constructor to set field
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @access	protected
	 * @param	int								$collection	Collection Id
	 * @param	object TableCollector_fields	$field		TableCollector_fields object
	 * @param	int								$item		Item Id
	 */
	function __construct( $collection, $field, $item = 0 )
	{
		// Initialisation
		$this->_collection = $collection;
		$this->_item = $item;
		$this->_field = $field;
	}
	
	/**
	 * Gets the field attributes for the form definition
	 *
	 * @return string
	 */
	function getFieldAttributes()
	{
		$attributes = array(
			'list'			=> $this->_field->attribs['list'],
			'default'		=> ''
		);
		
		return parent::getFieldAttributes($attributes);
	}
	
	/**
	 * Method to add field to query
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	JDatabaseQuery object		$query
	 */
	function setQuery(&$query)
	{
		$query->select('d'.$this->_field->id.'.content AS `'.$this->_field->tablecolumn.'`');
		$query->join('LEFT', '#__collector_defined_content AS d'.$this->_field->id.' ON d'.$this->_field->id.'.id = h.'.$this->_field->tablecolumn);
		return;
	}
	
	/**
	 * Method to add where clause to query on search value
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	JDatabaseQuery object		$query
	 * @param	string						$search_all_value
	 */
	function getSearchWhereClause(&$query,$search_all_value)
	{
		$where = 'd'.$this->_field->id.'.content LIKE "%'.$search_all_value.'%"';
		return $where;
	}
	
	/**
	 * Method to add where clause to query on filter value
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	JDatabaseQuery object		$query
	 * @param	mixed						$value
	 */
	function setFilterWhereClause(&$query,$value)
	{
		if ( $value != '' )
		{
			$query->where('h.'.$this->_field->tablecolumn.' = "'.$value.'"');
			return true;
		}
		return false;
	}
	
	/**
	 * Method to add order by clause
	 *
	 * Can be overloaded/supplemented by the child class
	 */
	function getOrderBy()
	{
		$orderBy = 'd'.$this->_field->id.'.content';
		return $orderBy;
	}
	
	/**
	 * Method to display filter in search area
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	JRegistry object		$params
	 * @param	mixed					$value
	 * @param	boolean					$menu
	 */
	function displayFilter($params,$value,$menu=false)
	{
		// Initiliase variables.
		$app	= JFactory::getApplication();
		$html = array();
		$attr = '';
		
		$user	= JFactory::getUser();
		$groups	= implode(',', $user->getAuthorisedViewLevels());
		
		if ($menu) {
			$prefix = 'jform[params][filter][';
			$suffix = ']';
		} else {
			$prefix = '';
			$suffix = '';
		}
		
		// Create a new query object.
		$db =& JFactory::getDBO();
		$nullDate = $db->getNullDate();
		$jnow =& JFactory::getDate();
		$now = $jnow->toMySQL();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select('d'.$this->_field->id.'.id AS value, d'.$this->_field->id.'.content AS text');
		$query->from('#__collector_defined_content AS d'.$this->_field->id);
		
		// Filter by value used in collection
		$query->join('RIGHT', '#__collector_items_history_'.$this->_collection.' AS h ON h.'.$this->_field->tablecolumn.' = d'.$this->_field->id.'.id');
		$query->join('RIGHT', '#__collector_items AS i ON i.id = h.item');
		$query->where('h.state = 1');
		$query->where('i.access IN ('.$groups.')');
		$query->where('((i.created_by = '.$user->id.') OR (i.state = 1 AND ( i.publish_up = '.$db->Quote($nullDate).' OR i.publish_up <= '.$db->Quote($now).') AND ( i.publish_down = '.$db->Quote($nullDate).' OR i.publish_down >= '.$db->Quote($now).' )))');
		$query->group('value');
		
		// Add the list ordering clause.
		$query->order('text');
		
		$db->setQuery( $query );
		
		$results = $db->loadObjectList();
		//Check for database error
		if (!$db->query())
		{
			return JError::raiseWarning( 500, $db->getErrorMsg() );
		}
		
		array_unshift($results,array('value' => '', 'text' => ''));
		
		// Initialize some field attributes.
		if ( (!$params->get('show_entire_listing')) && ($menu == false) ) {
			$requiredparams = $params->get('required');
			$required = $requiredparams['filterfield_'.$this->_field->tablecolumn]?' required':'';
		} else {
			$required = '';
		}
		$attr .= ' class="inputbox'.$required.'"';
		$attr .= ' size="1"';

		if ( $this->valueFilterMenu == null ) {
			$this->isFiltered($params);
		}
		
		if ( ($menu == true) || (!$this->valueFilterMenu) || ( $this->valueFilterMenu && (!$params->get('hide_filter'))) )
		{
			if ( (!$params->get('show_entire_listing')) && ($menu == false) ) {
				$requiredparams = $params->get('required');
				$required = $requiredparams['filterfield_'.$this->_field->tablecolumn]?'<span class="star">&nbsp;*</span>&nbsp;&nbsp;':'&nbsp;&nbsp;';
			} else {
				$required = '&nbsp;&nbsp;';
			}
			// Create a regular list.
			$html[] = '<div style="display: inline-block; margin-right: 10px; margin-bottom: 10px" >';
			$html[] = $this->_field->field . $required;
			$html[] = JHtml::_('select.genericlist', $results, $prefix.'filterfield_'.$this->_field->tablecolumn.$suffix, trim($attr), 'value', 'text', $value);
			$html[] = '</div>';
		}
		else
		{
			$html[] = '<input type=hidden name=\''.$prefix.'filter_field_'.$this->_field->tablecolumn.$suffix.'\' value=\''.$value.'\' />';
		}

		return implode($html);
	}
	
	/**
	 * Method to display field
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	string		$value		Field value
	 * @param	boolean		$listing	Field value
	 */
	function display($value,$listing=true)
	{
		$db =& JFactory::getDBO();
		
		$query = 'SELECT content, image, defined';
		$query .= ' FROM #__collector_defined_content';
		$query .= ' WHERE content = "'.$value.'"';

		$db->setQuery( $query );

		$result = $db->loadObject();

		if ( $result != null )
		{
			if ( JFile::exists($result->image) )
			{
				$query = 'SELECT width, height';
				$query .= ' FROM #__collector_defined';
				$query .= ' WHERE id = "'.$result->defined.'"';

				$db->setQuery( $query );

				$image = $db->loadObject();

				$imagePath=implode(DS,explode('/',$result->image));
				$imagePath=JPATH_SITE.DS.$imagePath;
				$taille=getimagesize($imagePath);
				$largeur=$taille[0];
				$hauteur=$taille[1];

				$largeurmax = $image->width ? $image->width : $largeur;
				$hauteurmax = $image->height ? $image->height : $hauteur;

				if ( ($hauteur/$hauteurmax) < ($largeur/$largeurmax) )
				{
					if ($largeur < $largeurmax)
					{
						$size= ' width="'.$largeur.'"';
					}
					else
					{
						$size= ' width="'.$largeurmax.'"';
					}
				}
				else
				{
					if ($hauteur < $hauteurmax)
					{
						$size= ' height="'.$hauteur.'"';
					}
					else
					{
						$size= ' height="'.$hauteurmax.'"';
					}
				}
				
				$return = '<img src="'.$result->image.'" alt="'.$result->content.'" title="'.$result->content.'" '.$size.' />';
			} else {
				$return = $result->content;
			}
		} else {
			$return = '';
		}
		echo $return;
		return;
	}
}

require_once(JPATH_ROOT.DS.'libraries'.DS.'joomla'.DS.'form'.DS.'fields'.DS.'list.php');

/**
 * Form Field class for the Collector.
 *
 * @package		Collector
 */
class JFormFieldCollectorDefine extends JFormFieldList
{
	public $type 		= 'CollectorDefine';
	
	protected function getOptions()
	{
		// Get defined Id
		$defined = $this->element['list'];
		
		// Create a new query object.
		$db =& JFactory::getDBO();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select('id AS value, content AS text');
		$query->from('#__collector_defined_content');
		
		// Filter by defined
		$query->where('defined='.$defined);
		
		// Add the list ordering clause.
		$query->order('text');
		
		$db->setQuery( $query );
		
		$results = $db->loadObjectList();
		//Check for database error
		if (!$db->query())
		{
			return JError::raiseWarning( 500, $db->getErrorMsg() );
		}
		
		array_unshift($results,array('value' => 0, 'text' => ''));
		
		return $results;
	}
}