<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: field.file.php 131 2012-03-19 23:33:03Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

/**
 * Field File class
 *
 * @package	Collector
 */
class CollectorField_File extends CollectorField
{
	/**
	 * type
	 * 
	 * @var string
	 */
	public $type = 'file';
	
	/**
	 * Object constructor to set field
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @access	protected
	 * @param	int								$collection	Collection Id
	 * @param	object TableCollector_fields	$field		TableCollector_fields object
	 * @param	int								$item		Item Id
	 */
	function __construct( $collection, $field, $item = 0 )
	{
		// Initialisation
		$this->_collection = $collection;
		$this->_item = $item;
		$this->_field = $field;
		
		// Create a new query object.
		$db =& JFactory::getDBO();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select('alias');
		$query->from('#__collector');
		
		// Add the filder on ID
		$query->where('id = '.$collection);
		
		$db->setQuery( $query );
		
		$this->_directory = 'images/collector/collection/'.$db->loadResult();
	}
	
	/**
	 * Gets the field attributes for the form definition
	 *
	 * @return string
	 */
	function getFieldAttributes()
	{
		$attributes = array(
			'directory'		=> $this->_directory,
			'size'			=> "60"
		);
		
		return parent::getFieldAttributes($attributes);
	}
	
	/**
	 * Method to display field
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	string		$value		Field value
	 * @param	boolean		$listing	Field value
	 */
	function display($value,$listing=true)
	{
		$db =& JFactory::getDBO();
		
		$fileInfos = explode('|',$value);
		$fileUrl = $fileInfos[0];
		
		if ( $fileUrl == '' )
		{
			$return = '';
		}
		else
		{
			$filePath = implode(DS,explode('/',$fileUrl));
			$fileName = JFile::getName(JPATH_SITE.DS.$filePath);
			$fileDesc = $fileInfos[1] ? $fileInfos[1] : $fileName;
			$fileTitle = $fileInfos[2] ? $fileInfos[1] : $fileName;
			
			$ext = JFile::getExt(JPATH_SITE.DS.$filePath);
			$query = 'SELECT ico';
			$query .= ' FROM #__collector_files_ext';
			$query .= ' WHERE ext="'.$ext.'"';
			$db->setQuery( $query );
			$ico = $db->loadResult();
			$URLico='./administrator/components/com_collector/assets/images/'.$ico;
			$return = '<a href="'.$fileUrl.'" target="_blank" title="'.$fileTitle.'" ><img src="'.$URLico.'" /> '. $fileDesc . '</a>';
		}
		echo $return;
		return;
	}
}

/**
 * Form Field class for the Collector.
 *
 * @package		Collector
 */
class JFormFieldCollectorFile extends JFormField
{
	public $type 		= 'CollectorFile';
	
	protected function getInput()
	{
		// Initialize variables.
		$html = array();
		$attr = '';		
		
		$fileInfos = explode('|',$this->value);
			
		$html[] = '<input type="text" name="'.$this->name.'" id="'.$this->id.'" value="' . htmlspecialchars($this->value, ENT_QUOTES) . '" size="60" maxlength="254" />';
		
		if ( $fileInfos[0] == '' )
		{
			$folder = $this->element['directory'];
		}
		else
		{
			$path = explode('/',$fileInfos[0]);
			unset($path[sizeof($path)-1]);
			$folder = implode('/',$path);
		}
		
		$link = JRoute::_('index.php?option=com_collector&amp;view=fileselect&amp;tmpl=component&amp;folder='.$folder.'&amp;field='.$this->id.'&amp;type=0');
		$html[] = '</td><td><div class="button2-left"><div class="image"><a class="modal" rel="{handler: \'iframe\', size: {x: 550, y: 515}}" href="'.$link.'">'. JText::_('COM_COLLECTOR_FILE_SELECT') . '</a></div></div></td>';
		
		// Build the script.
		$script = array();
		$script[] = '    function setFile(nameField,path,desc,title){';
		$script[] = '        document.getElementById(nameField).value = path + "|" + desc + "|" + title;';
		$script[] = '    }';

		// Add the script to the document head.
		JFactory::getDocument()->addScriptDeclaration(implode("\n", $script));
		
		return implode($html);
	}
}