<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: field.image.php 131 2012-03-19 23:33:03Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

/**
 * Field Image class
 *
 * @package	Collector
 */
class CollectorField_Image extends CollectorField
{
	/**
	 * type
	 * 
	 * @var string
	 */
	public $type = 'image';
	
	/**
	 * Object constructor to set field
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @access	protected
	 * @param	int								$collection	Collection Id
	 * @param	object TableCollector_fields	$field		TableCollector_fields object
	 * @param	int								$item		Item Id
	 */
	function __construct( $collection, $field, $item = 0 )
	{
		// Initialisation
		$this->_collection = $collection;
		$this->_item = $item;
		$this->_field = $field;
		
		// Create a new query object.
		$db =& JFactory::getDBO();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select('alias');
		$query->from('#__collector');
		
		// Add the filder on ID
		$query->where('id = '.$collection);
		
		$db->setQuery( $query );
		
		$this->_directory = 'images/collector/collection/'.$db->loadResult();
	}
	
	/**
	 * Gets the field attributes for the form definition
	 *
	 * @return string
	 */
	function getFieldAttributes()
	{
		$attributes = array(
			'directory'		=> $this->_directory,
			'size'			=> "60"
		);
		
		return parent::getFieldAttributes($attributes);
	}
	
	/**
	 * Method to display field
	 *
	 * Can be overloaded/supplemented by the child class
	 *
	 * @param	string		$value		Field value
	 * @param	boolean		$listing	Field value
	 */
	function display($value,$listing=true)
	{
		if ($value == '' ) {
			$value = '||||';
		}
		$imageInfos = explode('|',$value);
		$imageUrl = $imageInfos[0];
		$imagePath = implode(DS,explode('/',$imageUrl));
		$imageName = JFile::getName(JPATH_SITE.DS.$imagePath);
		$imageDesc = isset($imageInfos[1]) ? $imageInfos[1] : $imageName;
		$imageTitle = isset($imageInfos[2]) ? $imageInfos[2] : $imageName;
		if ( isset($imageInfos[3]) ) {
			$largeurmax = $imageInfos[3] ? $imageInfos[3] : 100;
		} else {
			$largeurmax = 100;
		}
		if ( isset($imageInfos[4]) ) {
			$hauteurmax = $imageInfos[4] ? $imageInfos[4] : 80;
		} else {
			$hauteurmax = 80;
		}

		$image = '';

		// image de substitution
		$imagedefault=$this->_field->attribs['default'];
		$imagedefault=explode('|',$imagedefault);
		
		if ($imageUrl == '')
		{
			$image=JPATH_SITE.DS.implode(DS,explode('/',$imagedefault[0])); // adresse de l'image
			// $image=JPATH_SITE.DS.'components'.DS.'com_collector'.DS.'assets'.DS.'images'.DS.'camera.png'; // adresse de l'image
			$URLimage='./'.$imagedefault[0]; // adresse de l'image
		}
		else
		{
			$image=JPATH_SITE.DS.$imageUrl; // adresse de l'image
			if (!file_exists($image)) {
				$image=JPATH_SITE.DS.implode(DS,explode('/',$imagedefault[0])); // adresse de l'image
				$URLimage='./'.$imagedefault[0]; // adresse de l'image
			} else {
				$URLimage='./'.$imageUrl; // adresse de l'image
			}
		}

		$taille=getimagesize($image);
		$largeur=$taille[0];
		$hauteur=$taille[1];

		if ( ($hauteur/$hauteurmax) < ($largeur/$largeurmax) )
		{
			if ($largeur < $largeurmax)
			{
				$size= ' width="'.$largeur.'"';
			}
			else
			{
				$size= ' width="'.$largeurmax.'"';
			}
		}
		else
		{
			if ($hauteur < $hauteurmax)
			{
				$size= ' height="'.$hauteur.'"';
			}
			else
			{
				$size= ' height="'.$hauteurmax.'"';
			}
		}

		echo '<img alt="'.$imageDesc.'" title="'.$imageTitle.'" align="middle" border="1" src="'.$URLimage.'" '.$size.' />';
		return;
	}
}

/**
 * Form Field class for the Collector.
 *
 * @package		Collector
 */
class JFormFieldCollectorImage extends JFormField
{
	public $type 		= 'CollectorImage';
	
	protected function getInput()
	{
		// Initialize variables.
		$html = array();
		$attr = '';		
		
		// Initialize some field attributes.
        $attr .= $this->element['class'] ? ' class="'.(string) $this->element['class'].'"' : '';
        $attr .= $this->element['size'] ? ' size="'.(int) $this->element['size'].'"' : '';
 
		// The text field.
		$html[] = '<div class="fltlft" style="display:inline;" >';
		$html[] = '    <input type="text" name="'.$this->name.'" id="'.$this->id.'"'.
					' onchange="setImage(\''.$this->name.'\',\'0\');"'.
					' value="'.htmlspecialchars($this->value, ENT_QUOTES).'"'.
					' readonly="readonly"'.$attr.' />';
		$html[] = '</div>';
		
        $imageInfos = explode('|',$this->value);
		
		if ( $imageInfos[0] == '' )
		{
			$directory = (string)$this->element['directory'];
			$imageInfos[1] = '';
		}
		else
		{
			$path = explode('/',$imageInfos[0]);
			unset($path[sizeof($path)-1]);
			$directory = implode('/',$path);
		}
		
		$link = JRoute::_('index.php?option=com_collector&amp;view=fileselect&amp;tmpl=component&amp;folder='.$directory.'&amp;field='.$this->id.'&amp;type=1');
		
		// The button.
		$html[] = '<div class="button2-left" >';
		$html[] = '    <div class="image">';
		$html[] = '        <a class="modal" title="'.JText::_('COM_COLLECTOR_SELECT_IMAGE').'"'.
					' href="'.$link.'"'.
					' rel="{handler: \'iframe\', size: {x: 550, y: 515}}">';
		$html[] = '            '.JText::_('COM_COLLECTOR_SELECT_IMAGE').'</a>';
		$html[] = '    </div>';
		$html[] = '</div>';
		
		// The preview.
		$html[] = '<div class="fltlft" >';
		$html[] = '    <img src="'.JURI::root().$imageInfos[0].'" alt="'.$imageInfos[1].'" name="'.$this->name.'-preview" id="'.$this->id.'-preview" style="float: left;" />';
		$html[] = '</div>';
		
		// Build the script.
		$script = array();
		$script[] = '    function setImage(nameField,path,desc,title,width,height){';
		$script[] = '        var imgName = nameField + "-preview";';
		$script[] = '        if ( path == "0" ) {';
		$script[] = '            imgInfos = document.getElementById(nameField).value.split("|");';
		$script[] = '            path = imgInfos[0];';
		$script[] = '            if ( path == "" ) {';
		$script[] = '            	path = "images/blank.png";';
		$script[] = '            }';
		$script[] = '        } else {';
		$script[] = '            document.getElementById(nameField).value = path + "|" + desc + "|" + title + "|" + width + "|" + height;';
		$script[] = '        }';
		$script[] = '        document.getElementById(imgName).src = "'.JURI::root().'" + path;';
		$script[] = '    }';

		// Add the script to the document head.
		JFactory::getDocument()->addScriptDeclaration(implode("\n", $script));
		
		return implode("\n", $html);
	}
}