<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: collections.php 124 2011-09-18 21:51:13Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport('joomla.application.component.controller');

/**
 * Collections Controller
 *
 * @package  	Collector
 */
class CollectorsControllerCollections extends CollectorsController
{
	/**
	 * Method to edit a collection
	 *
	 * @access	public
	 */
	function edit()
	{
		JRequest::setVar('view', 'collectionedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('edit', true);
		
		parent::display();
	}
	
	/**
	 * Method to add a collection
	 *
	 * @access	public
	 */
	function add()
	{
		JRequest::setVar('view', 'collectionedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('edit', false);
		
		parent::display();
	}
	
	/**
	 * Cancels an edit collection operation
	 *
	 * @access	public
	 */
	function cancel()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collectionedit');
		
		$model->checkin();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to save a collection
	 *
	 * @access	public
	 */
	function save()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collectionedit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_COLLECTION_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to save a collection and reload edition
	 *
	 * @access	public
	 */
	function apply()
	{
		$option = JRequest::getCmd( 'option' );
		
		JRequest::setVar('hidemainmenu',1);
		
		$model = $this->getModel('collectionedit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_COLLECTION_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$id = $model->_collectionId;
		
		$this->setRedirect( 'index.php?option='.$option.'&controller=collections&task=edit&cid[]='.$id, $msg );
	}
	
	/**
	 * Method to delete a collection
	 *
	 * @access	public
	 */
	function remove()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to publish a collection
	 *
	 * @access	public
	 */
	function publish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$msg = $model->state(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to unpublish a collection
	 *
	 * @access	public
	 */
	function unpublish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to archive a collection
	 *
	 * @access	public
	 */
	function archive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$msg = $model->state(-1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to unarchive a collection
	 *
	 * @access	public
	 */
	function unarchive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to set public access to a collection
	 *
	 * @access	public
	 */
	function accesspublic()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$model->access(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view );
	}
	
	/**
	 * Method to set registered access to a collection
	 *
	 * @access	public
	 */
	function accessregistered()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$model->access(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view );
	}
	
	/**
	 * Method to set special access to a collection
	 *
	 * @access	public
	 */
	function accessspecial()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('collections');
		$model->access(2);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view );
	}
	
	/**
	 * Method to set collection as default
	 *
	 * @access	public
	 */
	function setdefault()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		// Get some variables from the request
		$cid	= JRequest::getVar( 'cid', array(), 'post', 'array' );
		JArrayHelper::toInteger($cid);
		
		if (isset($cid[0]) && $cid[0]) {
			$id = $cid[0];
		} else {
			$this->setRedirect( 'index.php?option='.$option.'&view='.$view, JText::_('COM_COLLECTOR_NO_ITEMS_SELECTED') );
			return false;
		}
		
		$model =& $this->getModel( 'collections' );
		if ($model->setHome($id)) {
			$msg = JText::_( 'COM_COLLECTOR_DEFAULT_COLLECTION_SET' );
		} else {
			$msg = $model->getError();
		}
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to display a view
	 *
	 * @access	public
	 */
	function display()
	{
		parent::display();
	}
}

}else{
//Code pour Joomla >= 1.6.0

jimport('joomla.application.component.controlleradmin');

/**
 * Collections list controller class
 *
 * @package  	Collector
 */
class CollectorControllerCollections extends JControllerAdmin
{
	/**
	 * Proxy for getModel.
	 * @since	1.6
	 */
	public function getModel($name = 'Collection', $prefix = 'CollectorModel') 
	{
		$model = parent::getModel($name, $prefix, array('ignore_request' => true));
		return $model;
	}
	
	/**
	 * Method to set the home property for a list of items
	 *
	 * @since	1.6
	 */
	function setDefault()
	{
		// Check for request forgeries
		JRequest::checkToken('default') or die(JText::_('JINVALID_TOKEN'));

		// Get items to publish from the request.
		$cid	= JRequest::getVar('cid', array(), '', 'array');
		
		if (empty($cid)) {
			JError::raiseWarning(500, JText::_('COM_COLLECTOR_NO_ITEMS_SELECTED'));
		} else {
			// Get the model.
			$model = $this->getModel();

			// Make sure the item ids are integers
			$id = $cid[0];

			// Publish the items.
			if (!$model->setHome($id)) {
				JError::raiseWarning(500, $model->getError());
			} else {
				$this->setMessage(JText::_('COM_COLLECTOR_DEFAULT_COLLECTION_SET'));
			}
		}

		$this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list, false));
	}
}

}