<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: defined.php 120 2011-09-04 22:33:31Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * Defined Controller
 *
 * @package  	Collector
 */
class CollectorsControllerDefined extends CollectorsController
{
	/**
	 * Method to edit a defined field
	 *
	 * @access	public
	 */
	function edit()
	{
		JRequest::setVar('view', 'definededit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('edit', true);
		
		parent::display();
	}
	
	/**
	 * Method to add a defined field
	 *
	 * @access	public
	 */
	function add()
	{
		JRequest::setVar('view', 'definededit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('edit', false);
		
		parent::display();
	}
	
	/**
	 * Cancels an edit defined field operation
	 *
	 * @access	public
	 */
	function cancel()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('definededit');
		
		$model->checkin();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to save a defined field
	 *
	 * @access	public
	 */
	function save()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('definededit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_FIELD_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to save a defined field and reload edition
	 *
	 * @access	public
	 */
	function apply()
	{
		$option = JRequest::getCmd( 'option' );
		
		$model = $this->getModel('definededit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_FIELD_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$id = $model->_definedId;
		
		$this->setRedirect( 'index.php?option='.$option.'&controller=defined&task=edit&cid[]='.$id, $msg );
	}
	
	/**
	 * Method to delete a defined field
	 *
	 * @access	public
	 */
	function remove()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to publish a defined field
	 *
	 * @access	public
	 */
	function publish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$msg = $model->state(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to unpublish a defined field
	 *
	 * @access	public
	 */
	function unpublish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to archive a defined field
	 *
	 * @access	public
	 */
	function archive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$msg = $model->state(-1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to unarchive a defined field
	 *
	 * @access	public
	 */
	function unarchive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to set public access to a defined field
	 *
	 * @access	public
	 */
	function accesspublic()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$model->access(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view );
	}
	
	/**
	 * Method to set registered access to a defined field
	 *
	 * @access	public
	 */
	function accessregistered()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$model->access(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view );
	}
	
	/**
	 * Method to set special access to a defined field
	 *
	 * @access	public
	 */
	function accessspecial()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('defined');
		$model->access(2);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view );
	}

	/**
	 * Method to display a view
	 *
	 * @access	public
	 */
	function display()
	{
		parent::display();
	}
}