<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: fields.php 127 2011-12-10 22:51:55Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport('joomla.application.component.controller');

/**
 * Fields Controller
 *
 * @package  	Collector
 */
class CollectorsControllerFields extends CollectorsController
{
	/**
	 * Method to edit a field
	 *
	 * @access	public
	 */
	function edit()
	{
		JRequest::setVar('view', 'fieldedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('edit', true);
		
		parent::display();
	}
	
	/**
	 * Method to add a field
	 *
	 * @access	public
	 */
	function add()
	{
		JRequest::setVar('view', 'fieldedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('edit', false);
		
		parent::display();
	}
	
	/**
	 * Cancels an edit field operation
	 *
	 * @access	public
	 */
	function cancel()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('fieldedit');
		
		$model->checkin();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to save a field
	 *
	 * @access	public
	 */
	function save()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('fieldedit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_FIELD_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to save a field and reload edition
	 *
	 * @access	public
	 */
	function apply()
	{
		$option = JRequest::getCmd( 'option' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('fieldedit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_FIELD_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$id = $model->_fieldId;
		
		$this->setRedirect( 'index.php?option='.$option.'&controller=fields&task=edit&collection='.$collection.'&cid[]='.$id, $msg );
	}
	
	/**
	 * Method to delete a field
	 *
	 * @access	public
	 */
	function remove()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to allow frontend edition
	 *
	 * @access	public
	 */
	function open()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->edit(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to forbid frontend edition
	 *
	 * @access	public
	 */
	function lock()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->edit(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to hide from listing
	 *
	 * @access	public
	 */
	function hide()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->listing(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to show in listing
	 *
	 * @access	public
	 */
	function nohide()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->listing(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to allow sorting
	 *
	 * @access	public
	 */
	function sort()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->sort(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to forbid sorting
	 *
	 * @access	public
	 */
	function nosort()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->sort(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to activate uniqueness
	 *
	 * @access	public
	 */
	function unik()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->unik(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to desactivate uniqueness
	 *
	 * @access	public
	 */
	function nounik()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->unik(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to allow filter
	 *
	 * @access	public
	 */
	function deny_filter()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->filter(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to forbid filter
	 *
	 * @access	public
	 */
	function allow_filter()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->filter(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to publish field
	 *
	 * @access	public
	 */
	function publish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->state(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to unpublish field
	 *
	 * @access	public
	 */
	function unpublish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to archive field
	 *
	 * @access	public
	 */
	function archive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->state(-1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to unarchive field
	 *
	 * @access	public
	 */
	function unarchive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to set public access to a field
	 *
	 * @access	public
	 */
	function accesspublic()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$model->access(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection );
	}
	
	/**
	 * Method to set registered access to a field
	 *
	 * @access	public
	 */
	function accessregistered()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$model->access(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection );
	}
	
	/**
	 * Method to set special access to a field
	 *
	 * @access	public
	 */
	function accessspecial()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$model->access(2);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection );
	}
	
	/**
	 * Method to save order
	 *
	 * @access	public
	 */
	function saveOrder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$model->saveOrder();
		
		$this->setRedirect('index.php?option='.$option.'&view='.$view .'&collection='.$collection );
	}
	
	/**
	 * Method to increase order
	 *
	 * @access	public
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		// Initialize variables
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$model->OrderField(-1);
		
		$this->setRedirect('index.php?option='.$option.'&view='.$view .'&collection='.$collection );
	}
	
	/**
	 * Method to decrease order
	 *
	 * @access	public
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		// Initialize variables
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('collectionfields');
		$model->OrderField(1);
		
		$this->setRedirect('index.php?option='.$option.'&view='.$view .'&collection='.$collection );
	}
	
	/**
	 * Method to set field as default
	 *
	 * @access	public
	 */
	function setdefault()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		// Get some variables from the request
		$cid	= JRequest::getVar( 'cid', array(), 'post', 'array' );
		JArrayHelper::toInteger($cid);
		
		if (isset($cid[0]) && $cid[0]) {
			$id = $cid[0];
		} else {
			$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, JText::_('COM_COLLECTOR_NO_ITEMS_SELECTED') );
			return false;
		}
		
		$model =& $this->getModel( 'collectionfields' );
		if ($model->setHome($id)) {
			$msg = JText::_( 'COM_COLLECTOR_DEFAULT_FIELD_SET' );
		} else {
			$msg = $model->getError();
		}
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to display an html select of defined lists
	 * For AJAX request
	 *
	 * @access	public
	 */
	function listDefined()
	{
		$init[] = array('value' => 0, 'text' => '');
		
		$db =& JFactory::getDBO(); 
		$query = 'SELECT id AS value, name AS text ';
		$query .= ' FROM #__collector_defined';
		$db->setQuery( $query );
		
		$results = $db->loadObjectList();
		
		//Check for database error
		if (!$db->query())
		{
			$this->setRedirect( 'index.php?option=com_collector' );
			return JError::raiseWarning( 500, $db->getErrorMsg() );
		}
		
		$select = $init;
		foreach ( $results as $key => $value )
		{
			$select[$key+1]=$value;
		}
		
		$code = JHTML::_('select.genericlist', $select, 'defined', ' class=inputbox size="1" ', 'value', 'text', 0);
		
		echo $code;
		return;
	}
	
	/**
	 * Method to display an html select of collections
	 * For AJAX request
	 *
	 * @access	public
	 */
	function listCollection()
	{
		$init[] = array('value' => 0, 'text' => '');
		
		$db =& JFactory::getDBO(); 
		$query = 'SELECT id AS value, name AS text ';
		$query .= ' FROM #__collector';
		$db->setQuery( $query );
		
		$results = $db->loadObjectList();
		
		//Check for database error
		if (!$db->query())
		{
			$this->setRedirect( 'index.php?option=com_collector' );
			return JError::raiseWarning( 500, $db->getErrorMsg() );
		}
		
		$select = $init;
		foreach ( $results as $key => $value )
		{
			$select[$key+1]=$value;
		}
		
		$code = JHTML::_('select.genericlist', $select, 'defined', ' class=inputbox size="1" ', 'value', 'text', 0);
		
		echo $code;
		return;
	}
	
	/**
	 * Method to display an input hidden
	 * For AJAX request
	 *
	 * @access	public
	 */
	function None()
	{
		$code = '<input type="hidden" name="defined" value="0" />';
		
		echo $code;
		return;
	}
	
	/**
	 * Method to display a view
	 *
	 * @access	public
	 */
	function display()
	{
		parent::display();
	}
}

}else{
//Code pour Joomla >= 1.6.0

jimport('joomla.application.component.controlleradmin');

/**
 * Fields Controller
 *
 * @package  	Collector
 */
class CollectorControllerFields extends JControllerAdmin
{
	/**
	 * Proxy for getModel.
	 * @since	1.6
	 */
	public function getModel($name = 'field', $prefix = 'CollectorModel') 
	{
		$model = parent::getModel($name, $prefix, array('ignore_request' => true));
		return $model;
	}
	
	/**
	 * Method to delete a field
	 *
	 * @access	public
	 */
	public function delete()
	{
		parent::delete();
		
		$collection = JRequest::getCmd( 'collection' );
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list .'&collection='.$collection );
	}
	
	/**
	 * Method to allow frontend edition
	 *
	 * @access	public
	 */
	public function open()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->edit(1);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to forbid frontend edition
	 *
	 * @access	public
	 */
	public function lock()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->edit(0);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to hide from listing
	 *
	 * @access	public
	 */
	public function hide()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->listing(0);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to show in listing
	 *
	 * @access	public
	 */
	public function nohide()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->listing(1);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to allow sorting
	 *
	 * @access	public
	 */
	public function sort()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->sort(1);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to forbid sorting
	 *
	 * @access	public
	 */
	public function nosort()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->sort(0);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to activate field required
	 *
	 * @access	public
	 */
	public function required()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->required(1);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to desactivate field required
	 *
	 * @access	public
	 */
	public function norequired()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->required(0);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to activate uniqueness
	 *
	 * @access	public
	 */
	public function unik()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->unik(1);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to desactivate uniqueness
	 *
	 * @access	public
	 */
	public function nounik()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->unik(0);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to allow filter
	 *
	 * @access	public
	 */
	public function deny_filter()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->filter(0);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to forbid filter
	 *
	 * @access	public
	 */
	public function allow_filter()
	{
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel();
		$msg = $model->filter(1);
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
     * Method to save the submitted ordering values for records.
     */
    public function saveorder()
    {
        // Check for request forgeries.
        JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
 
        // Get the input
        $pks		= JRequest::getVar('cid',    null,    'post',    'array');
        $order		= JRequest::getVar('order',    null,    'post',    'array');
		$collection = JRequest::getCmd( 'collection' );
 
        // Sanitize the input
        JArrayHelper::toInteger($pks);
        JArrayHelper::toInteger($order);
 
        // Get the model
        $model = $this->getModel();
 
        // Save the ordering
        $return = $model->saveorder($pks, $order);
 
        if ($return === false)
        {
            // Reorder failed
            $message = JText::sprintf('JLIB_APPLICATION_ERROR_REORDER_FAILED', $model->getError());
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message, 'error');
            return false;
        } else
        {
            // Reorder succeeded.
            $this->setMessage(JText::_('JLIB_APPLICATION_SUCCESS_ORDERING_SAVED'));
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false));
            return true;
        }
    }
	
	/**
     * Changes the order of one or more records.
     */
	public function reorder()
    {
        // Check for request forgeries.
        JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
 
        // Initialise variables.
        $ids    	= JRequest::getVar('cid', null, 'post', 'array');
        $inc    	= ($this->getTask() == 'orderup') ? -1 : +1;
		$collection = JRequest::getCmd( 'collection' );
 
        $model = $this->getModel();
        $return = $model->reorder($ids, $inc);
        if ($return === false) {
            // Reorder failed.
            $message = JText::sprintf('JLIB_APPLICATION_ERROR_REORDER_FAILED', $model->getError());
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message, 'error');
            return false;
        } else {
            // Reorder succeeded.
            $message = JText::_('JLIB_APPLICATION_SUCCESS_ITEM_REORDERED');
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message);
            return true;
        }
    }
	
	/**
	 * Method to set field as default
	 *
	 * @access	public
	 */
	public function setDefault()
	{
		// Check for request forgeries
		JRequest::checkToken('default') or die(JText::_('JINVALID_TOKEN'));
		
		// Get some variables from the request
		$cid	= JRequest::getVar( 'cid', array(), '', 'array' );
		JArrayHelper::toInteger($cid);
		$collection = JRequest::getVar( 'collection' );
		
		if (empty($cid)) {
			JError::raiseWarning(500, JText::_('COM_COLLECTOR_NO_ITEMS_SELECTED'));
		} else {
			// Get the model.
			$model = $this->getModel();

			// Make sure the item ids are integers
			$id = $cid[0];

			// Publish the items.
			if (!$model->setHome($id)) {
				JError::raiseWarning(500, $model->getError());
			} else {
				$this->setMessage(JText::_('COM_COLLECTOR_DEFAULT_FIELD_SET'));
			}
		}
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to publish field
	 *
	 * @access	public
	 */
	public function publish()
	{
		parent::publish();
		
		// Get some variables from the request
		$collection = JRequest::getVar( 'collection' );
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection );
	}
	
	/**
	 * Method to unpublish field
	 *
	 * @access	public
	 */
	public function unpublish()
	{
		parent::unpublish();
		
		// Get some variables from the request
		$collection = JRequest::getVar( 'collection' );
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection );
	}
	
	/**
     * Check in of one or more records.
     */
    public function checkin()
    {
        // Check for request forgeries.
        JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
 
        // Initialise variables.
        $user		= JFactory::getUser();
        $ids		= JRequest::getVar('cid', null, 'post', 'array');
		$collection = JRequest::getVar( 'collection' );
 
        $model = $this->getModel();
        $return = $model->checkin($ids);
        if ($return === false) {
            // Checkin failed.
            $message = JText::sprintf('JLIB_APPLICATION_ERROR_CHECKIN_FAILED', $model->getError());
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message, 'error');
            return false;
        } else {
            // Checkin succeeded.
            $message =  JText::plural($this->text_prefix.'_N_ITEMS_CHECKED_IN', count($ids));
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message);
            return true;
        }
    }
}

}