<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: items.php 127 2011-12-10 22:51:55Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport('joomla.application.component.controller');

/**
 * Items Controller
 *
 * @package  	Collector
 */
class CollectorsControllerItems extends CollectorsController
{
	/**
	 * Method to display item history
	 *
	 * @access	public
	 */
	function history()
	{
		$array = JRequest::getVar('cid', 0, '', 'array');
		$id = (int)$array[0];
		
		JRequest::setVar('view', 'itemhistory');
		JRequest::setVar('limitstart', '0');
		JRequest::setVar('itemId', $id);
		
		parent::display();
	}
	
	/**
	 * Method to duplicate item
	 *
	 * @access	public
	 */
	function duplicate()
	{
		JRequest::setVar('view', 'itemedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('task', 'duplicate');
		
		parent::display();
	}
	
	/**
	 * Method to edit item
	 *
	 * @access	public
	 */
	function edit()
	{
		JRequest::setVar('view', 'itemedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('task', 'edit');
		
		parent::display();
	}
	
	/**
	 * Method to add item
	 *
	 * @access	public
	 */
	function add()
	{
		JRequest::setVar('view', 'itemedit');
		JRequest::setVar('hidemainmenu',1);
		JRequest::setVar('task', 'add');
		
		parent::display();
	}
	
	/**
	 * Cancels an edit item operation
	 *
	 * @access	public
	 */
	function cancel()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('itemedit');
		
		$model->checkin();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view, $msg );
	}
	
	/**
	 * Method to save item
	 *
	 * @access	public
	 */
	function save()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('itemedit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_ITEM_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' ) . ' - ' . JText::_( $model->getError() );
		}
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view .'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to save item and reload edition
	 *
	 * @access	public
	 */
	function apply()
	{
		$option = JRequest::getCmd( 'option' );
		$collection = JRequest::getCmd( 'collection' );
		$controller = JRequest::getCmd( 'controller' );
		
		JRequest::setVar('hidemainmenu',1);
		
		$model = $this->getModel('itemedit');
		
		if ($model->store())
		{
			$msg = JText::_( 'COM_COLLECTOR_ITEM_SAVED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_ERROR_SAVE' );
		}
		
		$id = $model->_itemId;
		
		$this->setRedirect( 'index.php?option='.$option.'&controller='.$controller.'&collection='.$collection.'&task=edit&cid[]='.$id, $msg );
	}
	
	/**
	 * Method to delete item
	 *
	 * @access	public
	 */
	function remove()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to publish item
	 *
	 * @access	public
	 */
	function publish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$msg = $model->state(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to unpublish item
	 *
	 * @access	public
	 */
	function unpublish()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to archive item
	 *
	 * @access	public
	 */
	function archive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$msg = $model->state(-1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to unarchive item
	 *
	 * @access	public
	 */
	function unarchive()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to set public access to an item
	 *
	 * @access	public
	 */
	function accesspublic()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$model->access(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection );
	}
	
	/**
	 * Method to set registered access to an item
	 *
	 * @access	public
	 */
	function accessregistered()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$model->access(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection );
	}
	
	/**
	 * Method to set special access to an item
	 *
	 * @access	public
	 */
	function accessspecial()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$model->access(2);
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection );
	}
	
	/**
	 * Method to save order
	 *
	 * @access	public
	 */
	function saveOrder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$model->saveOrder();
		
		$this->setRedirect('index.php?option='.$option.'&view='.$view.'&collection='.$collection );
	}
	
	/**
	 * Method to increase order
	 *
	 * @access	public
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		// Initialize variables
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$model->OrderField(-1);
		
		$this->setRedirect('index.php?option='.$option.'&view='.$view.'&collection='.$collection );
	}
	
	/**
	 * Method to decrease order
	 *
	 * @access	public
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		// Initialize variables
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		$model->OrderField(1);
		
		$this->setRedirect('index.php?option='.$option.'&view='.$view.'&collection='.$collection );
	}
	
	/**
	 * Method to reset hits item
	 *
	 * @access	public
	 */
	function resethits()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		// Initialize variables
		$option = JRequest::getCmd( 'option' );
		$controller = JRequest::getCmd( 'controller' );
		$collection = JRequest::getCmd( 'collection' );
		$id = JRequest::getCmd( 'id' );
		
		$model = $this->getModel('itemedit');
		
		if ($model->resetHits($id))
		{
			$msg = JText::_('COM_COLLECTOR_SUCCESSFULLY_RESET_HIT_COUNT');
		}
		else
		{
			$msg = JText::_('COM_COLLECTOR_ERROR_SAVE');
		}
		
		$this->setRedirect( 'index.php?option='.$option.'&controller='.$controller.'&collection='.$collection.'&task=edit&cid[]='.$id, $msg );
	}
	
	/**
	 * Method to display a view
	 *
	 * @access	public
	 */
	function display()
	{
		parent::display();
	}
}

}else{
//Code pour Joomla >= 1.6.0

jimport('joomla.application.component.controlleradmin');

/**
 * Items Controller
 *
 * @package  	Collector
 */
class CollectorControllerItems extends JControllerAdmin
{
	/**
	 * Proxy for getModel.
	 * @since	1.6
	 */
	public function getModel($name = 'item', $prefix = 'CollectorModel') 
	{
		$model = parent::getModel($name, $prefix, array('ignore_request' => true));
		return $model;
	}
	
	/**
	 * Method to display item history
	 *
	 * @access	public
	 */
	function history()
	{
		// Get some variables from the request
		$collection = JRequest::getVar( 'collection' );
		$array = JRequest::getVar('cid', 0, '', 'array');
		$item = (int)$array[0];
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view=itemversions&collection='.$collection.'&item='.$item );
	}
	
	/**
	 * Method to delete item
	 *
	 * @access	public
	 */
	function remove()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$collection = JRequest::getCmd( 'collection' );
		
		$model = $this->getModel('items');
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&collection='.$collection, $msg );
	}
	
	/**
	 * Method to publish item
	 *
	 * @access	public
	 */
	public function publish()
	{
		parent::publish();
		
		// Get some variables from the request
		$collection = JRequest::getVar( 'collection' );
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection );
	}
	
	/**
	 * Method to unpublish item
	 *
	 * @access	public
	 */
	public function unpublish()
	{
		parent::unpublish();
		
		// Get some variables from the request
		$collection = JRequest::getVar( 'collection' );
		
		$this->setRedirect( 'index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection );
	}
	
	/**
     * Method to save the submitted ordering values for records.
     */
    public function saveorder()
    {
        // Check for request forgeries.
        JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
 
        // Get the input
        $pks		= JRequest::getVar('cid',    null,    'post',    'array');
        $order		= JRequest::getVar('order',    null,    'post',    'array');
		$collection = JRequest::getCmd( 'collection' );
 
        // Sanitize the input
        JArrayHelper::toInteger($pks);
        JArrayHelper::toInteger($order);
 
        // Get the model
        $model = $this->getModel();
 
        // Save the ordering
        $return = $model->saveorder($pks, $order);
 
        if ($return === false)
        {
            // Reorder failed
            $message = JText::sprintf('JLIB_APPLICATION_ERROR_REORDER_FAILED', $model->getError());
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message, 'error');
            return false;
        } else
        {
            // Reorder succeeded.
            $this->setMessage(JText::_('JLIB_APPLICATION_SUCCESS_ORDERING_SAVED'));
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false));
            return true;
        }
    }
	
	/**
     * Changes the order of one or more records.
     */
	public function reorder()
    {
        // Check for request forgeries.
        JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
 
        // Initialise variables.
        $ids    	= JRequest::getVar('cid', null, 'post', 'array');
        $inc    	= ($this->getTask() == 'orderup') ? -1 : +1;
		$collection = JRequest::getCmd( 'collection' );
 
        $model = $this->getModel();
        $return = $model->reorder($ids, $inc);
        if ($return === false) {
            // Reorder failed.
            $message = JText::sprintf('JLIB_APPLICATION_ERROR_REORDER_FAILED', $model->getError());
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message, 'error');
            return false;
        } else {
            // Reorder succeeded.
            $message = JText::_('JLIB_APPLICATION_SUCCESS_ITEM_REORDERED');
            $this->setRedirect(JRoute::_('index.php?option='.$this->option.'&view='.$this->view_list.'&collection='.$collection, false), $message);
            return true;
        }
    }
	
	/**
	 * Method to reset hits item
	 *
	 * @access	public
	 */
	function resethits()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		// Initialize variables
		$option = JRequest::getCmd( 'option' );
		$controller = JRequest::getCmd( 'controller' );
		$collection = JRequest::getCmd( 'collection' );
		$id = JRequest::getCmd( 'id' );
		
		$model = $this->getModel('itemedit');
		
		if ($model->resetHits($id))
		{
			$msg = JText::_('COM_COLLECTOR_SUCCESSFULLY_RESET_HIT_COUNT');
		}
		else
		{
			$msg = JText::_('COM_COLLECTOR_ERROR_SAVE');
		}
		
		$this->setRedirect( 'index.php?option='.$option.'&controller='.$controller.'&collection='.$collection.'&task=edit&cid[]='.$id, $msg );
	}
}

}