<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: defined.php 126 2011-11-09 21:54:29Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5

/**
 * Defined model
 * @package	Collector
 */
class CollectorsModelDefined extends JModel
{
	/**
	 * Array of objects containing the defined lists
	 * @var array
	 */
	var $_data = null;

	/**
	 * Defined total
	 * @var int
	 */
	var $_total = null;

	/**
	 * Pagination object
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Defined model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		global $mainframe, $option;
		
		// Get pagination request variables
		// Get folder request variables
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
			$limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
			$limitstart = $app->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		}
		
        // In case limit has been changed, adjust it
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		
        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Method to create the query to select defined lists
	 *
	 * @access	private
	 * @return	string			Query to select defined lists
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();
		
		$query = 'SELECT d.id, d.name, created, created_by, u.name AS author, created_by_alias, modified, modified_by, access, g.name AS groupname';
		$query .= ' FROM `#__collector_defined` AS d';
		$query .= ' LEFT JOIN `#__users` AS u ON d.created_by = u.id';
		$query .= ' LEFT JOIN `#__groups` AS g ON d.access = g.id';
		
		$query .= $where;
		$query .= $orderby;
		
		return $query;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select defined lists
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildContentOrderBy()
	{
		global $mainframe, $option;
		
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$filter_order		= $mainframe->getUserStateFromRequest( $option.'.admin.defined.filter_order',		'filter_order',		'd.name',		'cmd' );
			$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.admin.defined.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$filter_order		= $app->getUserStateFromRequest( $option.'.admin.defined.filter_order',		'filter_order',		'd.name',		'cmd' );
			$filter_order_Dir	= $app->getUserStateFromRequest( $option.'.admin.defined.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}
		
		if ($filter_order == 'd.name'){
			$orderby 	= ' ORDER BY d.name '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , d.name ';
		}
		
		return $orderby;
	}
	
	/**
	 * Method to build the WHERE clause of the query to select defined lists
	 *
	 * @access	private
	 * @return	string	WHERE clause
	 */
	function _buildContentWhere()
	{
		global $mainframe, $option;
		
		$db					=& JFactory::getDBO();
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			//$filter_state		= $mainframe->getUserStateFromRequest( $option.'.admin.defined.filter_state',		'filter_state',		'',				'word' );
			$search				= $mainframe->getUserStateFromRequest( $option.'.admin.defined.search',			'search',			'',				'string' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			//$filter_state		= $app->getUserStateFromRequest( $option.'.admin.defined.filter_state',		'filter_state',		'',				'word' );
			$search				= $app->getUserStateFromRequest( $option.'.admin.defined.search',			'search',			'',				'string' );
		}
		$search				= JString::strtolower( $search );
		
		$where = array();
		
		if ($search) {
			$where[] = 'LOWER(d.name) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
		}
		// if ( $filter_state ) {
			// if ( $filter_state == 'P' ) {
				// $where[] = 'f.state >= 1';
			// } else if ($filter_state == 'U' ) {
				// $where[] = 'f.state = 0';
			// }
		// }
		
		$where[] = 'd.id > 0';
		
		$where 		= ( count( $where ) ? ' WHERE '. implode( ' AND ', $where ) : '' );
		
		return $where;
	}
	
	/**
	 * Retrieves the defined lists
	 *
	 * @access	public
	 * @return	array	Array of objects containing the defined lists from the database
	 */
	function &getData()
	{
		// Lets load the fields if it doesn't already exist
		if ( empty( $this->_data ))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}
		
		return $this->_data;
	}
	
	/**
	 * Method to get number of results
	 * Put data in <var>_total</var>
	 *
	 * @access	public
	 * @return	int		Number of results
	 */
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);    
		}
		return $this->_total;
	}

	/**
	 * Method to get pagination
	 * Put data in <var>_pagination</var>
	 * Returns a reference to the global {@link JPagination} object
	 *
	 * @access	public
	 * @return	object JPagination
	 */
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}

	/**
	 * Method to delete defined lists
	 *
	 * @access	public
	 * @return	string	Message to display
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array');
		$row =& $this->getTable('collector_defined');
		
		foreach ($cid as $id)
		{
			if (!($row->delete($id)))
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
			else
			{
				// mise  jour des champs qui avaient ce type prdfini
				$query = 'UPDATE #__collector_fields SET `defined` = \'-1\' WHERE `defined` = ' . $id ;
				
				$this->_db->setQuery( $query );
				$this->_db->query();
				
				// suppression de tous les lments de ce champ prdfini
				$query = 'DELETE FROM `#__collector_defined_content` WHERE `defined` = ' . $id ;
				
				$this->_db->setQuery( $query );
				$this->_db->query();
			}
		}
		
		$msg = count($cid) . ' ' . JText::_( 'COM_COLLECTOR_FIELD_DELETED' );
		
		return $msg;
	}
	
	/**
	 * Method to set access parameter
	 *
	 * @access	public
	 * @param	int		$state	Parameter state
	 * @return	string			Message to display
	 */
	function access($access)
	{
		// on initialise les variables
		$cid = JRequest::getVar('cid', array(0), 'post', 'array');
		$cid = $cid[0];
		
		// on cre et charge l'objet table de la collection
		$row =& $this->getTable('collector_defined');
		$row->load($cid);
		$row->access = $access;
		
		// on s'assure que l'objet est valide
		if (!$row->check())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		// on enregistre le tout
		if (!$row->store())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
	}
	
	/**
	 * Method to check if a collection exists
	 *
	 * @access	public
	 * @return	int			Number of collections
	 */
	function collection_exist()
	{
		// mise  jour des champs qui avaient ce type prdfini
		$query = 'SELECT COUNT(id) FROM #__collector WHERE 1';
		
		$this->_db->setQuery( $query );
		$this->_db->query();
		
		return $this->_db->loadResult();
	}
}

}else{
//Code pour Joomla >= 1.6.0
/**
 * Defined model
 * @package	Collector
 */
class CollectorModelDefined extends JModel
{
	
}

}
