<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: definedcontent.php 120 2011-09-04 22:33:31Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

/**
 * Definedcontent model
 * @package	Collector
 */
class CollectorsModelDefinedcontent extends JModel
{
	/**
	 * Defined list Id
	 * @var int
	 */
	var $_defined = null;

	/**
	 * Items total
	 * @var int
	 */
	var $_total = null;

	/**
	 * Pagination object
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Definedcontent model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		global $mainframe, $option;
		
		$this->_defined = JRequest::getVar( 'defined', '', '', 'int');
		
        // Get pagination request variables
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
			$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
			$limitstart = $app->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		}
		
        // In case limit has been changed, adjust it
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		
        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Method to create the query to select defined items
	 *
	 * @access	private
	 * @return	string			Query to select defined items
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();
		
		$query = 'SELECT d.id, d.defined, d.content';
		$query .= ' FROM `#__collector_defined_content` AS d';
		
		$query .= $where;
		$query .= $orderby;
		
		return $query;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select defined items
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildContentOrderBy()
	{
		global $mainframe, $option;
		
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$filter_order		= $mainframe->getUserStateFromRequest( $option.'.admin.definedcontent.filter_order',		'filter_order',		'd.content',	'cmd' );
			$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.admin.definedcontent.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$filter_order		= $app->getUserStateFromRequest( $option.'.admin.definedcontent.filter_order',		'filter_order',		'd.content',	'cmd' );
			$filter_order_Dir	= $app->getUserStateFromRequest( $option.'.admin.definedcontent.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}
		
		if ($filter_order == 'd.content'){
			$orderby 	= ' ORDER BY d.content '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , d.content ';
		}
		
		return $orderby;
	}
	
	/**
	 * Method to build the WHERE clause of the query to select defined items
	 *
	 * @access	private
	 * @return	string	WHERE clause
	 */
	function _buildContentWhere()
	{
		global $mainframe, $option;
		
		$db					=& JFactory::getDBO();
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			//$filter_state		= $mainframe->getUserStateFromRequest( $option.'.admin.definedcontent.filter_state',		'filter_state',		'',				'word' );
			$search				= $mainframe->getUserStateFromRequest( $option.'.admin.definedcontent.search',			'search',			'',				'string' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			//$filter_state		= $app->getUserStateFromRequest( $option.'.admin.definedcontent.filter_state',		'filter_state',		'',				'word' );
			$search				= $app->getUserStateFromRequest( $option.'.admin.definedcontent.search',			'search',			'',				'string' );
		}
		$search				= JString::strtolower( $search );
		
		$where = array();
		
		$where[] = 'd.defined = \'' . $this->_defined . '\'';
		
		if ($search) {
			$where[] = 'LOWER(d.content) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
		}
		// if ( $filter_state ) {
			// if ( $filter_state == 'P' ) {
				// $where[] = 'f.state >= 1';
			// } else if ($filter_state == 'U' ) {
				// $where[] = 'f.state = 0';
			// }
		// }
		
		$where 		= ( count( $where ) ? ' WHERE '. implode( ' AND ', $where ) : '' );
		
		return $where;
	}
	
	/**
	 * Retrieves the defined items
	 *
	 * @access	public
	 * @return	array	Array of objects containing the defined items from the database
	 */
	function &getData()
	{
		// Lets load the defined items if it doesn't already exist
		if ( empty( $this->_data ))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}
		
		return $this->_data;
	}
	
	/**
	 * Retrieves the defined list Id
	 *
	 * @access	public
	 * @return	int		Defined list Id
	 */
	function getDefined()
	{
		return $this->_defined;
	}
	
	/**
	 * Method to get number of results
	 * Put data in <var>_total</var>
	 *
	 * @access	public
	 * @return	int		Number of results
	 */
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);    
		}
		return $this->_total;
	}

	/**
	 * Method to get pagination
	 * Put data in <var>_pagination</var>
	 * Returns a reference to the global {@link JPagination} object
	 *
	 * @access	public
	 * @return	object JPagination
	 */
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}

	/**
	 * Method to delete defined items
	 *
	 * @access	public
	 * @return	string	Message to display
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array');
		$row =& $this->getTable('collector_defined_content');
		
		foreach ($cid as $id)
		{
			if (!($row->delete($id)))
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
			else
			{
				// mise  jour des champs qui avaient cet lment
				//$query = 'ALTER TABLE `#__collector_' . $this->_collection . '` DROP `field_' . $id . '`';
				
				//$this->_db->setQuery( $query );
				//$this->_db->query();
			}
		}
		
		$msg = count($cid) . ' ' . JText::_( 'COM_COLLECTOR_FIELD_DELETED' );
		
		return $msg;
	}
	
	/**
	 * Method to check if a collection exists
	 *
	 * @access	public
	 * @return	int		Number of collections
	 */
	function collection_exist()
	{
		// mise  jour des champs qui avaient ce type prdfini
		$query = 'SELECT COUNT(id) FROM #__collector WHERE 1';
		
		$this->_db->setQuery( $query );
		$this->_db->query();
		
		return $this->_db->loadResult();
	}
}
