<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: filesconfig.php 123 2011-09-16 09:30:52Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5

/**
 * Filesconfig model
 * @package	Collector
 */
class CollectorsModelFilesconfig extends JModel
{
	var $_data;
	
	/**
	 * Filesconfig model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		global $mainframe, $option;
		
		$query = $this->_buildQuery();
		$this->_data = $this->_getList( $query );
	}
	
	/**
	 * Method to create the query to select extensions
	 *
	 * @access	private
	 * @return	string			Query to select extensions
	 */
	function _buildQuery()
	{
		// Get the ORDER BY clause for the query
		$orderby	= $this->_buildContentOrderBy();
		
		$query = 'SELECT e.id, t.text AS type, e.ext, e.ico, e.state';
		$query .= ' FROM `#__collector_files_ext` AS e';
		$query .= ' LEFT JOIN `#__collector_files_type` AS t ON e.type = t.id';
		
		$query .= $orderby;
		
		return $query;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select extensions
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildContentOrderBy()
	{
		global $mainframe, $option;
		
		$filter_order		= $mainframe->getUserStateFromRequest( $option.'.admin.filesconfig.filter_order',		'filter_order',		't.id',	'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.admin.filesconfig.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		
		if ($filter_order == 't.id'){
			$orderby 	= ' ORDER BY t.id '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , t.id ';
		}
		
		return $orderby;
	}
	
	/**
	 * Retrieves the extensions
	 *
	 * @access	public
	 * @return	array	Array of objects containing the extensions from the database
	 */
	function &getData()
	{
		// Lets load the data if it doesn't already exist
		if ( empty( $this->_data ))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query );
		}
		
		return $this->_data;
	}
	
	/**
	 * Method to delete extensions
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function remove()
	{
		$id = JRequest::getVar( 'id', int, 'get', '0');
		$row =& $this->getTable('collector_files_ext');
		
		$row->load($id);
		
		if (!($row->delete($id)))
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		return true;
	}
	
	/**
	 * Method to save extensions
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function save()
	{
		$row =& $this->getTable('collector_files_ext');
		
		if (!$row->bind(JRequest::get('post'))) {
			//JError::raiseError( 500, $db->stderr() );
			return false;
		}
		
		// make sure the collector record is valid
		if ( !$row->check() )
		{
			//JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		// store the record in the database
		if ( !$row->store() )
		{
			//JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		return true;
	}
	
	/**
	 * Method to set state parameter
	 *
	 * @access	public
	 * @param	int		$state	Parameter state
	 * @return	boolean			True on success
	 */
	function state($state)
	{
		// on initialise les variables
		$id = JRequest::getVar('id', int, 'get', '0');
		$row =& $this->getTable('collector_files_ext');
		
		$row->load($id);
		$row->state = $state;
		
		// on s'assure que l'objet est valide
		if (!$row->check())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		// on enregistre le tout
		if (!$row->store())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		return true;
	}
}

}else{
//Code pour Joomla >= 1.6.0
jimport('joomla.application.component.modellist');

/**
 * Filesconfig model
 * @package	Collector
 */
class CollectorModelFilesconfig extends JModelList
{
	/**
	 * Constructor.
	 *
	 * @param	array	An optional associative array of configuration settings.
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'ext', 'e.ext',
				'type', 'e.type',
			);
		}

		parent::__construct($config);
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return	void
	 * @since	1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// List state information.
		parent::populateState('e.type', 'asc');
	}
	
	/**
	 * Method to build an SQL query to load the list data.
	 *
	 * @return	string	An SQL query
	 */
	protected function getListQuery()
	{
		// Create a new query object.		
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select(
			$this->getState('list.select',
				'e.id, e.ext, e.ico, e.state'
			)
		);
		$query->from('#__collector_files_ext AS e');
		
		// Join over the files type.
		$query->select('t.text AS type');
		$query->join('LEFT', '#__collector_files_type AS t ON e.type = t.id');
		
		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
		
		$query->order($db->getEscaped($orderCol.' '.$orderDirn));
		
		return $query;
	}
	
	/**
	 * Method to build an SQL query to load the list data.
	 *
	 * @return	string	An SQL query
	 */
	public function getRow()
	{
		$id = JRequest::getVar( 'id', 'int', 'get', '0');
		
		$row = & JTable::getInstance('collector_files_ext','Table');
		
		if ( $id != 0 )
		{
			$row->load($id);
		}
		
		return $row;
	}
	
	/**
	 * Build a list of extensions
	 *
	 * @return	JDatabaseQuery
	 */
	public function getTypes()
	{
		$init[] = array('value' => 0, 'text' => '');
		
		// Get list of files types
		$db =& JFactory::getDBO(); 
		$query = 'SELECT id AS value, text ';
		$query .= ' FROM #__collector_files_type';
		$db->setQuery( $query );
		
		// Load the content if it doesn't already exist
		$results = $db->loadObjectList();
		
		//Check for database error
		if (!$db->query())
		{
			return JError::raiseWarning( 500, $db->getErrorMsg() );
		}
		
		$select = $init;
		foreach ( $results as $key => $value )
		{
			$value->text=JText::_('COM_COLLECTOR_'.$value->text);
			$select[$key+1]=$value;
		}
		
		return $select;
	}
	
	/**
	 * Method to delete extensions
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function remove()
	{
		$id = JRequest::getVar( 'id', 'int', 'get', '0');
		$row =& $this->getTable('collector_files_ext');
		
		$row->load($id);
		
		if (!($row->delete($id)))
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		return true;
	}
	
	/**
	 * Method to save extensions
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function save()
	{
		$row =& $this->getTable('collector_files_ext');
		
		if (!$row->bind(JRequest::get('post'))) {
			//JError::raiseError( 500, $db->stderr() );
			return false;
		}
		
		// make sure the collector record is valid
		if ( !$row->check() )
		{
			//JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		// store the record in the database
		if ( !$row->store() )
		{
			//JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		return true;
	}
	
	/**
	 * Method to set state parameter
	 *
	 * @access	public
	 * @param	int		$state	Parameter state
	 * @return	boolean			True on success
	 */
	public function state($state = 0)
	{
		// on initialise les variables
		$id = JRequest::getVar( 'id', 'int', 'get', '0');
		$row =& $this->getTable('collector_files_ext');
		
		$row->load($id);
		$row->state = $state;
		
		// on s'assure que l'objet est valide
		if (!$row->check())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		// on enregistre le tout
		if (!$row->store())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		return true;
	}
}

}
