<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: itemhistory.php 120 2011-09-04 22:33:31Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

/**
 * Itemhistory model
 * @package	Collector
 */
class CollectorsModelItemhistory extends JModel
{
	/**
	 * Item Id
	 * @var int
	 */
	var $_id;
	
	/**
	 * Item details
	 * @var object
	 */
	var $_item;
	
	/**
	 * Item history
	 * @var array
	 */
	var $_history;
	
	/**
	 * Collection Id
	 * @var int
	 */
	var $_collection;
	
	/**
	 * Items total
	 * @var int
	 */
	var $_total = null;

	/**
	 * Pagination object
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Itemhistory model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		$this->_collection = JRequest::getVar( 'collection', '', '', 'int');
		
		$this->_id = JRequest::getVar('itemId', '', '', 'int');
		
		global $mainframe, $option;
		
        // Get pagination request variables
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
			$limitstart = $mainframe->getUserStateFromRequest($option.'.itemhistory.limitstart', 'limitstart', 0, 'int');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
			$limitstart = $app->getUserStateFromRequest($option.'.itemhistory.limitstart', 'limitstart', 0, 'int');
		}
		
        // In case limit has been changed, adjust it
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		
        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Method to create the query to select item history
	 *
	 * @access	private
	 * @return	string			Query to select item history
	 */
	function _buildQuery()
	{
		$query = 'SELECT c.id, state, modified, modified_by, modification, u.name AS author';
		$query .= ' FROM `#__collector_items_history_'.$this->_collection.'` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON c.modified_by = u.id';
		$query .= ' WHERE c.item = \''.$this->_id.'\'';
		$query .= ' ORDER BY modified DESC';
		
		return $query;
	}
	
	/**
	 * Retrieves item history
	 *
	 * @access	public
	 * @return	array	Array of objects containing history from the database
	 */
	function &getHistory()
	{
		// Lets load the data if it doesn't already exist
		if ( empty( $this->_history ))
		{
			$query = $this->_buildQuery();
			$this->_history = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}
		
		return $this->_history;
	}
	
	/**
	 * Retrieves item details
	 * Put data in <var>_item</var>
	 * Returns a reference to the global {@link TableCollector_items} object
	 *
	 * @access	public
	 * @return	object TableCollector_items
	 */
	function &getItem()
	{
		if ( empty( $this->_item ))
		{
			$this->_item = & JTable::getInstance('collector_items','Table');
			$this->_item->initVersion($this->_collection);
			$this->_item->load($this->_id);
		}
		
		return $this->_item;
	}
	
	/**
	 * Method to get number of results
	 * Put data in <var>_total</var>
	 *
	 * @access	public
	 * @return	int		Number of results
	 */
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);    
		}
		return $this->_total;
	}

	/**
	 * Method to get pagination
	 * Put data in <var>_pagination</var>
	 * Returns a reference to the global {@link JPagination} object
	 *
	 * @access	public
	 * @return	object JPagination
	 */
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}
	
	/**
	 * Retrieves the collection Id
	 *
	 * @access	public
	 * @return	int		Collection Id
	 */
	function getCollection()
	{
		return $this->_collection;
	}
	
	/**
	 * Method to delete history
	 *
	 * @access	public
	 * @return	string	Message to display
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array');
		$row =& $this->getTable('collector_items_history_');
		$row->initVersion($this->_collection);
		$count = count($cid);
		
		foreach ($cid as $id)
		{
			$row->load($id);
			
			if ( $row->state == 1 )
			{
				$msg = JText::_( 'COM_COLLECTOR_CANT_DELETE_CURRENT' ) . '</li><li>';
				$count = $count - 1;
			}
			else if (!($row->delete($id)))
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
		}
		
		$msg .= $count . ' ' . JText::_( 'COM_COLLECTOR_HIST_DELETED' );
		
		return $msg;
	}
}
