<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: items.php 129 2012-01-26 22:10:24Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport( 'joomla.application.component.model' );

/**
 * Items model
 * @package	Collector
 */
class CollectorsModelItems extends JModel
{
	/**
	 * Items list
	 * @var array
	 */
	var $_data;
	
	/**
	 * Collection Id
	 * @var int
	 */
	var $_collection;
	
	/**
	 * Default field number
	 * @var array
	 */
	var $_number_field_default;
	
	/**
	 * Default field name
	 * @var array
	 */
	var $_name_field_default;
	
	/**
	 * Default table column name
	 * @var array
	 */
	var $_column_field_default;
	
	/**
	 * Default field defined
	 * @var array
	 */
	var $_defined_field_default;
	
	/**
	 * Items model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		$this->_collection = JRequest::getVar( 'collection', '', '', 'int');
		
		$this->_loaddefaults();
		
		//$array = JRequest::getVar('cid', 0, '', 'array');
		//$this->_id = (int)$array[0];
		
		global $mainframe, $option;
		
        // Get pagination request variables
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
			$limitstart = $mainframe->getUserStateFromRequest($option.'.items.limitstart', 'limitstart', 0, 'int');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
			$limitstart = $app->getUserStateFromRequest($option.'.items.limitstart', 'limitstart', 0, 'int');
		}
		
        // In case limit has been changed, adjust it
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		
        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Method to load default collection Id in <var>_collection</var>
	 *
	 * @access	private
	 */
	function _loaddefaults()
	{
		if ($this->_collection == '')
		{
			/**
			* si pas de collection particuliere visualiser, on recupere la collection par defaut
			*/
			$query = 'SELECT id';
			$query .= ' FROM `#__collector`';
			$query .= ' WHERE home = 1';
			
			$row = $this->_getList( $query );
			
			if ( !$row )
			{
				/**
				* si aucune collection definie par defaut, tag  defaut d'une collection
				*/
				$query = 'UPDATE `#__collector` SET home = 1 LIMIT 1;';
				$this->_db->setQuery( $query );
				$this->_db->query();
				
				$query = 'SELECT id';
				$query .= ' FROM `#__collector`';
				$query .= ' WHERE home = 1';
				
				$row = $this->_getList( $query );
			}
			$this->_collection = $row[0]->id;
		}
		
		/**
		* on recupere le champ a afficher dans la premiere colonne
		*/
		$query = 'SELECT id, field, tablecolumn, type, defined';
		$query .= ' FROM `#__collector_fields`';
		$query .= ' WHERE collection = "' . $this->_collection . '"';
		$query .= ' AND home = 1';
		
		$row = $this->_getList( $query );
		
		if ( !$row )
		{
			/**
			* si aucun champ defini par defaut, tag  defaut d'un champ
			*/
			$query = 'UPDATE `#__collector_fields`';
			$query .= ' SET home = 1';
			$query .= ' WHERE collection = "' . $this->_collection . '"';
			$query .= ' LIMIT 1;';
			$this->_db->setQuery( $query );
			$this->_db->query();
			
			$query = 'SELECT id, field, tablecolumn, type, defined';
			$query .= ' FROM `#__collector_fields`';
			$query .= ' WHERE collection = "' . $this->_collection . '"';
			$query .= ' AND home = 1';
			
			$row = $this->_getList( $query );
			
			if ( $row == null )
			{
				/**
				* si aucun champ cree , tout a null
				*/
				$this->_number_field_default = array();
				$this->_name_field_default = array();
				$this->_column_field_default = array();
				$this->_defined_field_default = array();
				return;
			}
		}
		
		$this->_number_field_default[0] = $row[0]->id;
		$this->_name_field_default[0] = $row[0]->field;
		$this->_column_field_default[0] = $row[0]->tablecolumn;
		if ( $row[0]->type == 3 )
		{
			$this->_defined_field_default[0] = $row[0]->defined;
		}
		else
		{
			$this->_defined_field_default[0] = null;
		}
		
		$this->_loadCustomTitle();
		
		return;
	}
	
	/**
	 * Method to load custom title in <var>_number_field_default</var>
	 *
	 * @access	private
	 */
	function _loadCustomTitle()
	{
		/**
		* recherche de titre personnalise
		*/
		$query = 'SELECT custom';
		$query .= ' FROM `#__collector`';
		$query .= ' WHERE id = \'' . $this->_collection . '\'';
		
		$row = $this->_getList( $query );
		
		$custom = explode( '/', $row[0]->custom );
		
		if ( $custom[0] != '0' )
		{
			$query = 'SELECT id, field, tablecolumn, type, defined';
			$query .= ' FROM `#__collector_fields`';
			$query .= ' WHERE collection = \'' . $this->_collection . '\'';
			
			$results = $this->_getList( $query );
			
			$i = 0;
			
			foreach ( $custom as $field )
			{
				for ($j = 0; $j < count($results); $j ++)
				{
					$this->_number_field_default[$i] = $field;
					
					if ( $results[$j]->id == $field )
					{
						$this->_name_field_default[$i] = $results[$j]->field;
						$this->_column_field_default[$i] = $results[$j]->tablecolumn;
						if ( $results[$j]->type == 3 )
						{
							$this->_defined_field_default[$i] = $results[$j]->defined;
						}
						else
						{
							$this->_defined_field_default[$i] = null;
						}
					}
				}
				$i ++;
			}
		}
	}
	
	/**
	 * Method to create the query to select items
	 *
	 * @access	private
	 * @return	string			Query to select items
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();
		
		$query = 'SELECT c.id, c.state, ordering, hits, created, created_by, u.name AS author, created_by_alias, access, g.name AS groupname, publish_up, publish_down';
		for ( $i=0; $i < count($this->_number_field_default); $i ++ )
		{
			if ( $this->_defined_field_default[$i] != null )
			{
				$query .= ', d'.$i.'.content AS name'.$i;
			}
			else
			{
				$query .= ', h.'.$this->_column_field_default[$i].' AS name'.$i;
			}
		}
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON c.created_by = u.id';
		$query .= ' LEFT JOIN `#__groups` AS g ON c.access = g.id';
		$query .= ' LEFT JOIN `#__collector_items_history_'.$this->_collection.'` AS h ON h.item = c.id';
		
		for ( $i=0; $i < count($this->_number_field_default); $i ++ )
		{
			if ( $this->_defined_field_default[$i] != null )
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$i.' ON d'.$i.'.id = h.'.$this->_column_field_default[$i];
			}
		}
		
		$query .= $where;
		$query .= $orderby;
		
		return $query;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select items
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildContentOrderBy()
	{
		global $mainframe, $option;
		
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$filter_order		= $mainframe->getUserStateFromRequest( $option.'.items.filter_order',		'filter_order',		'ordering',		'cmd' );
			$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.items.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$filter_order		= $app->getUserStateFromRequest( $option.'.items.filter_order',		'filter_order',		'ordering',		'cmd' );
			$filter_order_Dir	= $app->getUserStateFromRequest( $option.'.items.filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}
		
		if ($filter_order == 'ordering'){
			$orderby 	= ' ORDER BY ordering '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , ordering ';
		}
		
		return $orderby;
	}
	
	/**
	 * Method to build the WHERE clause of the query to select items
	 *
	 * @access	private
	 * @return	string	WHERE clause
	 */
	function _buildContentWhere()
	{
		global $mainframe, $option;
		
		$db					=& JFactory::getDBO();
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$search				= $mainframe->getUserStateFromRequest( $option.'.items.search',			'search',			'',				'string' );
			$filter_state		= $mainframe->getUserStateFromRequest( $option.'.items.filter_state',		'filter_state',		'',				'word' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$filter_state		= $app->getUserStateFromRequest( $option.'.items.filter_state',		'filter_state',		'',				'word' );
			$search				= $app->getUserStateFromRequest( $option.'.items.search',			'search',			'',				'string' );
		}
		$search				= JString::strtolower( $search );
		
		$where = array();
		$wheresearch = array();
		
		//$where[] = 'c.collection = ' . $this->_collection;
		
		if ($search) {
			for ( $i=0; $i < count($this->_number_field_default); $i ++ )
			{
				if ($this->_defined_field_default[$i])
				{
					$wheresearch[] = 'LOWER(d'.$i.'.content) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
				}
				else
				{
					$wheresearch[] = 'LOWER(h.'.$this->_column_field_default[$i].') LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
				}
			}
		}
		if ( $filter_state ) {
			if ( $filter_state == 'P' ) {
				$where[] = 'c.state >= 1';
			} else if ($filter_state == 'U' ) {
				$where[] = 'c.state = 0';
			}
		}
		
		$where[] = 'h.state = 1';
		$where[] = 'c.collection = '.$this->_collection;
		
		if ( !empty($wheresearch) )
		{
			$where[] = ' ( ' . implode( ' OR ', $wheresearch ) . ' ) ';
		}
		
		$where 		= ( count( $where ) ? ' WHERE '. implode( ' AND ', $where ) : '' );
		
		return $where;
	}
	
	/**
	 * Retrieves the items
	 *
	 * @access	public
	 * @return	array	Array of objects containing the items from the database
	 */
	function &getData()
	{
		// Lets load the data if it doesn't already exist
		if ( empty( $this->_data ))
		{
			if ( $this->_number_field_default == null )
			{
				$this->_data = null;
			}
			else
			{
				$query = $this->_buildQuery();
				$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
			}
		}
		
		return $this->_data;
	}
	
	/**
	 * Method to get default title
	 *
	 * @access	public
	 * @return	string	Default title
	 */
	function getTitle()
	{
		$title = implode(' ', $this->_name_field_default);
		
		return $title;
	}
	
	/**
	 * Method to get title lenght
	 *
	 * @access	public
	 * @return	int		Title lenght
	 */
	function getTitleLength()
	{
		return count($this->_name_field_default);
	}
	
	/**
	 * Retrieves the collection Id
	 *
	 * @access	public
	 * @return	int		Collection Id
	 */
	function getCollection()
	{
		return $this->_collection;
	}
	
	/**
	 * Method to get number of results
	 * Put data in <var>_total</var>
	 *
	 * @access	public
	 * @return	int		Number of results
	 */
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_total))
		{
			if ( $this->_number_field_default == null )
			{
				$this->_total = 0;
			}
			else
			{
				$query = $this->_buildQuery();
				$this->_total = $this->_getListCount($query);
			}
		}
		return $this->_total;
	}

	/**
	 * Method to get pagination
	 * Put data in <var>_pagination</var>
	 * Returns a reference to the global {@link JPagination} object
	 *
	 * @access	public
	 * @return	object JPagination
	 */
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}
	
	/**
	 * Method to delete items
	 *
	 * @access	public
	 * @return	string	Message to display
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array');
		$row =& $this->getTable('collector_items');
		$row->initVersion($this->_collection);
		
		foreach ($cid as $id)
		{
			if (!($row->delete($id)))
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
		}
		
		$row->reorder();
		
		$msg = count($cid) . ' ' . JText::_( 'COM_COLLECTOR_ITEM_DELETED' );
		
		return $msg;
	}
	
	/**
	 * Method to set state parameter
	 *
	 * @access	public
	 * @param	int		$state	Parameter state
	 * @return	string			Message to display
	 */
	function state($state)
	{
		// on initialise les variables
		$cid = JRequest::getVar('cid', array(0), 'post', 'array');
		$row =& $this->getTable('collector_items');
		$row->initVersion($this->_collection);
		
		$task = JRequest::getCmd('task');
		
		foreach ( $cid as $id )
		{
			$row->load($id);
			$row->state = $state;
			
			// on s'assure que l'objet est valide
			if (!$row->check())
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
			
			// on enregistre le tout
			if (!$row->store())
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
		}
		
		// cration du message de retour
		$msg ='';
		
		if ( ( $state == 0 ) && ( $task == 'unpublish' ) )
		{
			$msg = 'COM_COLLECTOR_ITEM_UNPUBLISHED';
		}
		else if ( ( $state == 0 ) && ( $task == 'unarchive' ) )
		{
			$msg = 'COM_COLLECTOR_ITEM_UNARCHIVED';
		}
		else if ( $state == 1 )
		{
			$msg = 'COM_COLLECTOR_ITEM_PUBLISHED';
		}
		else if ( $state == -1 )
		{
			$msg = 'COM_COLLECTOR_ITEM_ARCHIVED';
		}
		
		$msg = count($cid) . ' ' . JText::_( $msg );
		
		return $msg;
	}
	
	/**
	 * Method to set access parameter
	 *
	 * @access	public
	 * @param	int		$state	Parameter state
	 * @return	string			Message to display
	 */
	function access($access)
	{
		// on initialise les variables
		$cid = JRequest::getVar('cid', array(0), 'post', 'array');
		$cid = $cid[0];
		
		// on cre et charge l'objet table de la collection
		$row =& $this->getTable('collector_items');
		$row->initVersion($this->_collection);
		
		$row->load($cid);
		$row->access = $access;
		
		// on s'assure que l'objet est valide
		if (!$row->check())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
		
		// on enregistre le tout
		if (!$row->store())
		{
			JError::raiseError( 500, $row->getError() );
			return false;
		}
	}
	
	/**
	 * Method to save order
	 *
	 * @access	public
	 * @return	string			Message to display
	 */
	function saveOrder()
	{
		// Initialize variables
		$db			= & JFactory::getDBO();
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order		= JRequest::getVar( 'order', array (0), 'post', 'array' );
		$total		= count($cid);
		$conditions	= array ();
		
		JArrayHelper::toInteger($cid, array(0));
		JArrayHelper::toInteger($order, array(0));
		
		// Instantiate an article table object
		$row =& $this->getTable('collector_items');
		$row->initVersion($this->_collection);
		
		// Update the ordering for items in the cid array
		for ($i = 0; $i < $total; $i ++)
		{
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					JError::raiseError( 500, $db->getErrorMsg() );
					return false;
				}
				// remember to updateOrder this group
				$condition = 'state >= 0';
				$found = false;
				foreach ($conditions as $cond)
					if ($cond[1] == $condition) {
						$found = true;
						break;
					}
				if (!$found)
					$conditions[] = array ($row->id, $condition);
			}
		}
		
		// execute updateOrder for each group
		foreach ($conditions as $cond)
		{
			$row->load($cond[0]);
			$row->reorder($cond[1]);
		}
		
		$cache = & JFactory::getCache('com_collector');
		$cache->clean();
		
		$msg = JText::_('COM_COLLECTOR_NEW_ORDERING_SAVED');
		
		return $msg;
	}
	
	/**
	 * Method to move the order of a record
	 *
	 * @access	public
	 * @param	int		$direction	The increment to reorder by
	 * @return	string				Message to display
	 */
	function orderField($direction)
	{
		$db		= & JFactory::getDBO();
		
		// Initialize variables
		$cid	= JRequest::getVar( 'cid', array(), 'post', 'array' );
		
		if (isset( $cid[0] ))
		{
			$row =& $this->getTable('collector_items');
			$row->initVersion($this->_collection);
			
			if (!$row->load( (int) $cid[0] ))
			{
				$this->setError($db->getErrorMsg());
				return false;
			}
			
			if (!$row->move($direction, 'state >= 0'))
			{
				$this->setError($db->getErrorMsg());
				return false;
			}
			
			$cache = & JFactory::getCache('com_collector');
			$cache->clean();
		}
		
		return true;
	}
}

}else{
//Code pour Joomla >= 1.6.0
jimport( 'joomla.application.component.modellist' );

require_once(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_collector'.DS.'classes'.DS.'field.php');

/**
 * Items model
 * @package	Collector
 */
class CollectorModelItems extends JModelList
{
	/**
	 * Collection Id
	 * @var int
	 */
	var $_collection;
	
	/**
	 * Fields
	 * @var int
	 */
	var $_fields = array();
	
	/**
	 * Constructor.
	 *
	 * @param	array	An optional associative array of configuration settings.
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'i.id',
				'alias', 'i.alias',
				'collection', 'i.collection',
				'state', 'i.state',
				'ordering', 'i.ordering',
				'hits', 'i.hits',
				'created', 'i.created',
				'created_by', 'i.created_by',
				'checked_out', 'i.checked_out',
				'checked_out_time', 'i.checked_out_time',
				'publish_up', 'i.publish_up',
				'publish_down', 'i.publish_down',
				'access', 'i.access', 'access_level',
			);
		}

		parent::__construct($config);
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return	void
	 * @since	1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication();
		$session = JFactory::getSession();

		// Adjust the context to support modal layouts.
		if ($layout = JRequest::getVar('layout')) {
			$this->context .= '.'.$layout;
		}

		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$access = $this->getUserStateFromRequest($this->context.'.filter.access', 'filter_access', 0, 'int');
		$this->setState('filter.access', $access);

		$published = $this->getUserStateFromRequest($this->context.'.filter.published', 'filter_published', '');
		$this->setState('filter.published', $published);

		// List state information.
		parent::populateState('i.ordering', 'asc');
	}
	
	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 */
	protected function getListQuery()
	{
		// Get collection
		$collection = $this->getCollection();
		$fields = $this->getFields();
		
		// Create a new query object.
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select',
				'i.id, i.alias, i.collection, i.ordering, i.state, i.hits, i.created, i.created_by, i.created_by_alias, i.modified, i.modified_by' .
				', i.access, i.publish_up, i.publish_down, i.checked_out, i.checked_out_time'
			)
		);
		$query->from('#__collector_items AS i');
		
		// Join over the values.
		$query->join('LEFT', '#__collector_items_history_'.$collection->id.' AS h ON h.item = i.id');
		foreach($fields as $field)
		{
			$field->setQuery($query);
		}
		
		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join('LEFT', '#__users AS uc ON uc.id = i.checked_out');
		
		// Join over the asset groups.
		$query->select('ag.title AS access_level');
		$query->join('LEFT', '#__viewlevels AS ag ON ag.id = i.access');
		
		// Join over the users for the author.
		$query->select('ua.name AS author_name');
		$query->join('LEFT', '#__users AS ua ON ua.id = i.created_by');
		
		// Filter by collection
		$query->where('i.collection = '.$collection->id);
		
		// Filter by history
		$query->where('h.state = 1');
		
		// Filter by access level.
		if ($access = $this->getState('filter.access')) {
			$query->where('i.access = ' . (int) $access);
		}
		
		// Filter by published state
		$published = $this->getState('filter.published');
		if (is_numeric($published)) {
			$query->where('i.state = ' . (int) $published);
		}
		else if ($published === '') {
			$query->where('(i.state = 0 OR i.state = 1)');
		}
		
		// Filter by search in title.
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('i.id = '.(int) substr($search, 3));
			}
			else if (stripos($search, 'author:') === 0) {
				$search = $db->Quote('%'.$db->getEscaped(substr($search, 7), true).'%');
				$query->where('(ua.name LIKE '.$search.' OR ua.username LIKE '.$search.')');
			}
			else {
				$search = $db->Quote('%'.$db->getEscaped($search, true).'%');
				$whereClause = array();
				foreach($fields as $field)
				{
					if ( $field->type == 3 )
					{
						$whereClause[] = 'd'.$field->id.'.content LIKE '.$search;
					}
					else
					{
						$whereClause[] = 'h.'.$field->tablecolumn.' LIKE '.$search;
					}
				}
				$whereClause[] = 'i.alias LIKE '.$search;
				$query->where('('.implode(' OR ',$whereClause).')');
			}
		}
		
		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
		$query->order($db->getEscaped($orderCol.' '.$orderDirn));
		
		return $query;
	}
	
	/**
	 * Method to load default collection Id in <var>_collection</var>
	 *
	 * @access	private
	 */
	public function getCollection()
	{
		if ( empty($this->_collection) )
		{
			$collection = JRequest::getVar( 'collection', '', '', 'int');
			
			if ($collection == '')
			{
				$query = 'SELECT id';
				$query .= ' FROM `#__collector`';
				$query .= ' WHERE home = 1';
				
				$row = $this->_getList( $query );
				
				if ( !$row )
				{
					/**
					 * tag  defaut d'une collection
					 */
					$query = 'UPDATE `#__collector` SET home = 1 LIMIT 1;';
					$this->_db->setQuery( $query );
					$this->_db->query();
					
					$query = 'SELECT id';
					$query .= ' FROM `#__collector`';
					$query .= ' WHERE home = 1';
					
					$row = $this->_getList( $query );
				}
				if ( $row == null )
				{
					return false;
				}
				else
				{
					$collection = $row[0]->id;
				}
			}
			
			// Create a new query object.
			$db =& JFactory::getDBO();
			$query = $db->getQuery(true);
			
			// Select the required fields from the table.
			$query->select('id, name, custom');
			$query->from('#__collector');
			
			// Add the filder on ID
			$query->where('id = '.$collection);
			
			$db->setQuery( $query );
			
			$this->_collection = $db->loadObject();
		}
		
		return $this->_collection;
	}

	/**
	 * Method to load listdrop of collections
	 *
	 * @access	public
	 */
	public function getFields()
	{
		if ( empty($this->_fields) )
		{
			$collection = $this->getCollection();
			
			// Create a new query object.
			$db =& JFactory::getDBO();
			$query = $db->getQuery(true);
			
			// Select the required fields from the table.
			$query->select('f.id, f.field, f.tablecolumn');
			$query->from('#__collector_fields as f');
			
			// Join over the type.
			$query->select('t.type AS type');
			$query->join('LEFT', '#__collector_fields_type AS t ON t.id = f.type');
			
			// Filter by collection
			$query->where('f.collection = '.$collection->id);
			
			// Filter by title
			if ( $collection->custom != '0' )
			{
				$custom = explode('/',$collection->custom);
				$query->where('f.id IN("'.implode('","',$custom).'")');
			}
			else
			{
				$queryHome = 'SELECT id';
				$queryHome .= ' FROM `#__collector_fields`';
				$queryHome .= ' WHERE collection = '.$collection->id.' AND home = 1';
				
				$row = $this->_getList( $queryHome );
				
				if ( !$row )
				{
					/**
					 * tag  defaut d'une collection
					 */
					$queryHome = 'UPDATE `#__collector_fields` SET home = 1  WHERE collection = '.$collection->id.' LIMIT 1;';
					$this->_db->setQuery( $queryHome );
					$this->_db->query();
					
				}
				$query->where('home = 1');
			}
			
			$db->setQuery( $query );
			
			$fields = $db->loadObjectList();
			
			// Reorder
			$fieldsReordered = $fields;
			if ( $collection->custom != '0' )
			{
				$custom = array_flip($custom);
				foreach( $fields as $field )
				{
					$fieldsReordered[$custom[$field->id]] = $field;
				}
			}
			
			foreach ($fieldsReordered as $field)
			{
				$this->_fields[] =& CollectorField::getInstance( $this->_collection->id, $field );
			}
		}
		
		$title = '';
		
		foreach($this->_fields as $field)
		{
			if ( $title != '' )
			{
				$title .= ' ';
			}
			$title .= $field->getFieldName();
		}
		$this->_collection->title = $title;
		
		return $this->_fields;
	}

	/**
	 * Method to load listdrop of collections
	 *
	 * @access	public
	 */
	public function getCollections()
	{
		$collection = $this->getCollection();
		
		// Create a new query object.
		$db =& JFactory::getDBO();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select('id AS value, name AS text');
		$query->from('#__collector');
		
		// Add the list ordering clause.
		$query->order('text');
		
		$db->setQuery( $query );
		
		$results = $db->loadObjectList();
		
		return JHTML::_('select.genericlist', $results, 'collection', ' class="inputbox" size="1" onchange="this.form.submit()"', 'value', 'text', $collection->id);
	}
}

}
