<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: templates.php 128 2012-01-24 23:17:19Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport( 'joomla.application.component.model' );

/**
 * Templates model
 * @package	Collector
 */
class CollectorsModelTemplates extends JModel
{
	/**
	 * Array of objects containing the templates
	 * @var array
	 */
	var $_data;
	
	/**
	 * Collection Id
	 * @var int
	 */
	var $_collection;
	
	/**
	 * Templates model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		$this->_collection = JRequest::getVar( 'collection', '', '', 'int');
		
		$this->_loaddefaults();
		
		//$array = JRequest::getVar('cid', 0, '', 'array');
		//$this->_id = (int)$array[0];
		
		global $mainframe, $option;
		
        // Get pagination request variables
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
			$limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
			$limitstart = $app->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		}
		
        // In case limit has been changed, adjust it
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		
        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Method to load default collection Id in <var>_collection</var>
	 *
	 * @access	private
	 */
	function _loaddefaults()
	{
		if ($this->_collection == '')
		{	
			$query = 'SELECT id';
			$query .= ' FROM `#__collector`';
			$query .= ' WHERE home = 1';
			
			$row = $this->_getList( $query );
			
			if ( !$row )
			{
				/**
				* tag  defaut d'une collection
				*/
				$query = 'UPDATE `#__collector` SET home = 1 LIMIT 1;';
				$this->_db->setQuery( $query );
				$this->_db->query();
				
				$query = 'SELECT id';
				$query .= ' FROM `#__collector`';
				$query .= ' WHERE home = 1';
				
				$row = $this->_getList( $query );
			}
			$this->_collection = $row[0]->id;
		}
	}
	
	/**
	 * Method to create the query to select templates
	 *
	 * @access	private
	 * @return	string			Query to select templates
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();
		
		$query = 'SELECT id, name, alias, client, home';
		$query .= ' FROM `#__collector_templates`';
		
		$query .= $where;
		$query .= $orderby;
		
		return $query;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select templates
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildContentOrderBy()
	{
		global $mainframe, $option;
		
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$filter_order		= $mainframe->getUserStateFromRequest( $option.'filter_order',		'filter_order',		'name',		'cmd' );
			$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$filter_order		= $app->getUserStateFromRequest( $option.'filter_order',		'filter_order',		'name',		'cmd' );
			$filter_order_Dir	= $app->getUserStateFromRequest( $option.'filter_order_Dir',	'filter_order_Dir',	'',				'word' );
		}
		
		if ($filter_order == 'c.name'){
			$orderby 	= ' ORDER BY name '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , name ';
		}
		
		return $orderby;
	}
	
	/**
	 * Method to build the WHERE clause of the query to select templates
	 *
	 * @access	private
	 * @return	string	WHERE clause
	 */
	function _buildContentWhere()
	{
		global $mainframe, $option;
		
		$db					=& JFactory::getDBO();
		$filter_client		= JRequest::getVar( 'filter_client', '', '', 'int');
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$search				= $mainframe->getUserStateFromRequest( $option.'search',			'search',			'',				'string' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$search				= $app->getUserStateFromRequest( $option.'search',			'search',			'',				'string' );
		}
		$search				= JString::strtolower( $search );
		
		$where = array();
		
		if ($search) {
			$where[] = 'LOWER(name) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
		}
		if ( $filter_client ) {
			if ( $filter_client == '2' ) {
				$where[] = 'client = 2';
			} else if ($filter_client == '1' ) {
				$where[] = 'client = 1';
			}
		}
		
		$where[] = '( collection = ' . $this->_collection . ' OR collection = 0 )';
		
		$where = ( count( $where ) ? ' WHERE '. implode( ' AND ', $where ) : '' );
		
		return $where;
	}
	
	/**
	 * Retrieves the templates
	 *
	 * @access	public
	 * @return	array	Array of objects containing the templates from the database
	 */
	function &getData()
	{
		// Lets load the data if it doesn't already exist
		if ( empty( $this->_data ))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}
		
		return $this->_data;
	}
	
	/**
	 * Retrieves the collection Id
	 *
	 * @access	public
	 * @return	int		Collection Id
	 */
	function getCollection()
	{
		return $this->_collection;
	}
	
	/**
	 * Method to get number of results
	 * Put data in <var>_total</var>
	 *
	 * @access	public
	 * @return	int		Number of results
	 */
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);    
		}
		return $this->_total;
	}

	/**
	 * Method to get pagination
	 * Put data in <var>_pagination</var>
	 * Returns a reference to the global {@link JPagination} object
	 *
	 * @access	public
	 * @return	object JPagination
	 */
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}
	
	/**
	 * Check if collection has a default template selected
	 *
	 * @param	int		$collection	Collection Id
	 * @return	array				Number of listing and detail templates
	 */
	function checkHome( $collection )
	{
		$db =& $this->getDBO();
		
		$query = 'SELECT COUNT(id)';
		$query .= ' FROM #__collector_templates';
		$query .= ' WHERE collection = ' . $collection;
		$query .= ' AND client = 1';
		$query .= ' AND home = 1';
		$db->setQuery( $query );
		$return['listing'] = $db->loadResult();
		
		$query = 'SELECT COUNT(id)';
		$query .= ' FROM #__collector_templates';
		$query .= ' WHERE collection = ' . $collection;
		$query .= ' AND client = 2';
		$query .= ' AND home = 1';
		$db->setQuery( $query );
		$return['detail'] = $db->loadResult();
		
		return $return;
	}
	
	/**
	 * Method to delete templates
	 *
	 * @access	public
	 * @return	string	Message to display
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array');
		$row =& $this->getTable('collector_templates');
		
		$id = $cid[0];
		
		$row->load($id);
		
		if ( $row->alias != 'default' )
		{
			if (!($row->delete($id)))
			{
				JError::raiseError( 500, $row->getError() );
				return false;
			}
			
			$msg = JText::_( 'COM_COLLECTOR_TPL_DELETED' );
		}
		else
		{
			$msg = JText::_( 'COM_COLLECTOR_NO_DELETE_DEFAULT_TPL' );
		}
		
		return $msg;
	}
	
	/**
	 * Method to set a field as default
	 *
	 * @access	public
	 * @param	int		$item	Field Id
	 * @return	boolean			True on success
	 */
	function setHome( $item )
	{
		$db =& $this->getDBO();
		
		$row =& $this->getTable('collector_templates');
		$row->load($item);
		
		if ( $row->collection == 0 )
		{
			$row->collection = $this->_collection;
		}
		// Clear home field for all other items
		$query = 'UPDATE #__collector_templates' .
				' SET home = 0' .
				' WHERE 1' .
				' AND collection = ' . $row->collection .
				' AND client = ' . $row->client;
		$db->setQuery( $query );
		if ( !$db->query() ) {
			$this->setError($db->getErrorMsg());
			return false;
		}
		
		// Set the given item to home
		$query = 'UPDATE #__collector_templates' .
				' SET home = 1' .
				' WHERE id = '.(int) $item .
				' AND collection = ' . $row->collection .
				' AND client = ' . $row->client;
		$db->setQuery( $query );
		if ( !$db->query() ) {
			$this->setError($db->getErrorMsg());
			return false;
		}
		
		return true;
	}
}

}else{
//Code pour Joomla >= 1.6.0
jimport( 'joomla.application.component.modellist' );

/**
 * Templates model
 * @package	Collector
 */
class CollectorModelTemplates extends JModelList
{
	/**
	 * Array of objects containing the templates
	 * @var array
	 */
	var $_data;
	
	/**
	 * Collection Id
	 * @var int
	 */
	var $_collection;
	
	/**
	 * Constructor.
	 *
	 * @param	array	An optional associative array of configuration settings.
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{
		parent::__construct($config);
	}
}

}