<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: collector_defined.php 125 2011-10-03 22:53:05Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
/**
 * Collector_defined table
 * @package		Collector
 */
class TableCollector_defined extends JTable
{
	/** @var int Primary key */
	var $id	= null;
	
	/** @var string */
	var $name = null;
	
	/** @var string */
	var $alias = null;
	
	/** @var datetime */
	var $created = null;

	/** @var int */
	var $created_by = null;

	/** @var string */
	var $created_by_alias = null;

	/** @var datetime */
	var $modified = null;

	/** @var int */
	var $modified_by = null;

	/** @var int */
	var $checked_out = null;

	/** @var datetime */
	var $checked_out_time = null;

	/** @var int */
	var $access = null;

	/** @var int */
	var $width = null;

	/** @var int */
	var $height = null;

	/**
	 * @param database A database connector object
	 */
	function TableCollector_defined( &$db )
	{
		$nulldate = $db->getNullDate();
		$this->created = $nulldate;
		$this->modified = $nulldate;
		parent::__construct( '#__collector_defined', 'id', $db );
	}
	
	/**
	 * Overloaded check function
	 *
	 * @access	public
	 * @return	boolean	True if the object is ok
	 * @see		JTable::check
	 */
	function check()
	{
		// check for valid name
		if( trim($this->name) == '' ) {
			$this->setError(JText::_( 'COM_COLLECTOR_FIELD_NAME' ));
			return false;
		}
		
		if(empty($this->alias)) {
			$this->alias = $this->name;
		}
		$this->alias = JFilterOutput::stringURLSafe($this->alias);
		
		return true;
	}
}

}else{
//Code pour Joomla >= 1.6.0
/**
 * Collector_defined table
 * @package		Collector
 */
class TableCollector_defined extends JTable
{
	/**
	 * @param database A database connector object
	 */
	function TableCollector_defined( &$db )
	{
		parent::__construct( '#__collector_defined', 'id', $db );
	}
	
	/**
	 * Overloaded check function
	 *
	 * @access	public
	 * @return	boolean	True if the object is ok
	 * @see		JTable::check
	 */
	function check()
	{
		// check for valid name
		if( trim($this->name) == '' ) {
			$this->setError(JText::_( 'COM_COLLECTOR_WARNING_PROVIDE_VALID_NAME' ));
			return false;
		}
		
		if(empty($this->alias)) {
			$this->alias = $this->name;
		}
		$this->alias = JFilterOutput::stringURLSafe($this->alias);
		
		if (trim(str_replace('-','',$this->alias)) == '') {
			$this->alias = JFactory::getDate()->format('Y-m-d-H-i-s');
		}
		
		return true;
	}
	
	/**
	 * Overrides JTable::store to set modified data and user id.
	 *
	 * @param   boolean  True to update fields even if they are null.
	 *
	 * @return  boolean  True on success.
	 */
	public function store($updateNulls = false)
	{
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();

		if ($this->id) {
			// Existing item
			$this->modified		= $date->toMySQL();
			$this->modified_by	= $user->get('id');
		} else {
			// New collection. A collection created and created_by field can be set by the user,
			// so we don't touch either of these if they are set.
			if (!intval($this->created)) {
				$this->created = $date->toMySQL();
			}

			if (empty($this->created_by)) {
				$this->created_by = $user->get('id');
			}
		}
		// Verify that the alias is unique
		$table = JTable::getInstance('Collector_defined','Table');
		if ($table->load(array('alias'=>$this->alias)) && ($table->id != $this->id || $this->id==0)) {
			$this->setError(JText::_('COM_COLLECTOR_DATABASE_ERROR_COLLECTION_UNIQUE_ALIAS'));
			return false;
		}
		return parent::store($updateNulls);
	}
}

}