<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: view.html.php 127 2011-12-10 22:51:55Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.view');

/**
 * HTML Itemhistory View class for the Collector component
 *
 * @package	Collector
 */
class CollectorsViewItemhistory extends JView
{
	/**
	 * Display function
	 */
	function display($tpl = null)
	{
		$user =& JFactory::getUser();
		
		JToolBarHelper::title( JText::_( 'COM_COLLECTOR_ITEMS_MANAGER' ) . ': <small><small>[ '. JText::_( 'COM_COLLECTOR_HISTORY' ) .' ]</small></small>', 'addedit' );
		
		JToolBarHelper::deleteList();
		JToolBarHelper::preview();
		JToolBarHelper::cancel('cancel', 'Close');
		
		JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_HOME'), 'index.php?option=com_collector');
		if ($user->authorize('com_collector', 'filemanage')) {
			JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_FILE_MANAGER'), 'index.php?option=com_collector&view=filemanager');
		}
		JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_COLLECTIONS'), 'index.php?option=com_collector&view=collections');
		JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_LISTS'), 'index.php?option=com_collector&view=defined');
		JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_FIELDS'), 'index.php?option=com_collector&view=collectionfields');
		JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_ITEMS'), 'index.php?option=com_collector&view=items', true);
		if ($user->authorize('com_collector', 'templatemanage')) {
			JSubMenuHelper::addEntry( JText::_('COM_COLLECTOR_TEMPLATES'), 'index.php?option=com_collector&view=templates');
		}
		
		JHTML::_('behavior.tooltip');
		
		// Get data from the model
		$model =& $this->getModel('itemhistory');
		$history =& $model->getHistory();
		$item =& $model->getItem();
		$collection = $model->getCollection();
		
		$pagination =& $model->getPagination();
		
		// Get list of collections
		$db =& JFactory::getDBO(); 
		$query = 'SELECT id AS value, name AS text ';
		$query .= ' FROM #__collector';
		$db->setQuery( $query );
		
		$results = $db->loadObjectList();
		
		//Check for database error
		if (!$db->query())
		{
			return JError::raiseWarning( 500, $db->getErrorMsg() );
		}
		
		$lists['collections'] = JHTML::_('select.genericlist', $results, 'collection', ' class=inputbox size="1" disabled', 'value', 'text', $collection);
		
		$this->assignRef( 'history', $history );
		$this->assignRef( 'lists', $lists );
		$this->assignRef( 'item', $item );
		$this->assignRef( 'collection', $collection );
		$this->assignRef( 'pagination', $pagination );
		
		parent::display($tpl);
	}
	
	/**
	 * Method to display item informations
	 *
	 * @access	public
	 * @param	string	$row	Item to display
	 * @return	void
	 */
	function displayItemInformations(&$row)
	{
		$db =& JFactory::getDBO();
		$nulldate = $db->getNullDate();
		$archived = $this->pagination->total - 1;
		
		// used to hide "Reset Hits" when hits = 0
		if ( !$row->hits ) {
			$visibility = 'style="display: none; visibility: hidden;"';
		} else {
			$visibility = '';
		}
		
		?>
		<table width="100%" style="border: 1px dashed silver; padding: 5px; margin-bottom: 10px;">
		<tr>
			<td>
				<strong><?php echo JText::_( 'COM_COLLECTOR_ITEM_ID' ); ?>:</strong>
			</td>
			<td>
				<?php echo $row->id; ?>
			</td>
		</tr>
		<tr>
			<td>
				<strong><?php echo JText::_( 'COM_COLLECTOR_STATE' ); ?></strong>
			</td>
			<td>
				<?php echo $row->state > 0 ? JText::_( 'COM_COLLECTOR_PUBLISHED' ) : ( $row->state < 0 ? JText::_( 'COM_COLLECTOR_ARCHIVED' ) : JText::_( 'COM_COLLECTOR_DRAFT_UNPUBLISHED' ) );?>
			</td>
		</tr>
		<tr>
			<td>
				<strong><?php echo JText::_( 'COM_COLLECTOR_CREATED' ); ?></strong>
			</td>
			<td>
				<?php echo JHTML::_( 'date', $row->created, JText::_( 'DATE_FORMAT_LC2') );?>
			</td>
		</tr>
		<tr>
			<td>
				<strong><?php echo JText::_( 'COM_COLLECTOR_MODIFIED' ); ?></strong>
			</td>
			<td>
				<?php
				if ( $row->modified == $nulldate )
				{
					echo JText::_( 'COM_COLLECTOR_NOT_MODIFIED' );
				}
				else
				{
					echo JHTML::_('date', $row->modified, JText::_( 'DATE_FORMAT_LC2' ));
				}
				?>
			</td>
		</tr>
		<tr>
			<td>
				<strong><?php echo JText::_( 'COM_COLLECTOR_ARCHIVED_VERSIONS' ); ?></strong>
			</td>
			<td>
				<?php echo $archived;?>
			</td>
		</tr>
		<tr>
			<td>
				<strong><?php echo JText::_( 'COM_COLLECTOR_HITS' ); ?></strong>
			</td>
			<td>
				<?php echo $row->hits;?>
				<span <?php echo $visibility; ?>>
					<input name="reset_hits" type="button" class="button" value="<?php echo JText::_( 'COM_COLLECTOR_RESET' ); ?>" onclick="submitbutton('resethits');" />
				</span>
			</td>
		</tr>
		</table>
		<?php
	}
}

?>
