<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: filemanager.php 131 2012-03-19 23:33:03Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5

jimport( 'joomla.application.component.controller' );

/**
 * filemanager Controller
 *
 * @package  	Collector
 */
class CollectorControllerFilemanager extends CollectorController
{
	/**
	 * Method to create a new folder
	 *
	 * @access	public
	 */
	function create()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$tmpl = JRequest::getCmd( 'tmpl' );

		$model = $this->getModel('filemanager');
		$folder = $model->getFolder();

		$msg = $model->createFolder();

		if ( $tmpl == 'component' )
		{
			$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&tmpl=component&folder='.$folder );
		}
		else
		{
			$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&folder='.$folder, $msg[0], $msg[1] );
		}
	}

	/**
	 * Method to upload a new file
	 *
	 * @access	public
	 */
	function upload()
	{
		global $mainframe;

		$view = JRequest::getCmd( 'view' );
		$file 		= JRequest::getVar( 'fileupload', '', 'files', 'array' );
		$folder		= JRequest::getVar( 'folder', '', '', 'path' );
		$tmpl		= JRequest::getVar( 'tmpl', '', '', 'cmd');
		$format		= JRequest::getVar( 'format', 'html', '', 'cmd');
		$err		= null;
		$return		= 'index.php?option=com_collector&view='.$view.'&folder='.$folder.( $tmpl != '' ? '&tmpl='.$tmpl : '' );

		// Set FTP credentials, if given
		jimport('joomla.client.helper');
		JClientHelper::setCredentialsFromRequest('ftp');

		// Make the filename safe
		jimport('joomla.filesystem.file');
		$file['name']	= JFile::makeSafe($file['name']);

		if (isset($file['name'])) {
			$filepath = JPath::clean(JPATH_ROOT.DS.$folder.DS.strtolower($file['name']));

			if (JFile::exists($filepath)) {
				if ($format == 'json') {
					jimport('joomla.error.log');
					$log = &JLog::getInstance('upload.error.php');
					$log->addEntry(array('comment' => 'File already exists: '.$filepath));
					header('HTTP/1.0 409 Conflict');
					jexit('Error. File already exists');
				} else {
					JError::raiseNotice(100, JText::_('COM_COLLECTOR_ERROR_FILE_ALREADY_EXISTS'));
					// REDIRECT
					$mainframe->redirect($return);
					return;
				}
			}

			if (!JFile::upload($file['tmp_name'], $filepath)) {
				if ($format == 'json') {
					jimport('joomla.error.log');
					$log = &JLog::getInstance('upload.error.php');
					$log->addEntry(array('comment' => 'Cannot upload: '.$filepath));
					header('HTTP/1.0 400 Bad Request');
					jexit('Error. Unable to upload file');
				} else {
					JError::raiseWarning(100, JText::_('COM_COLLECTOR_ERROR_UNABLE_TO_UPLOAD_FILE'));
					// REDIRECT
					$mainframe->redirect($return);
					return;
				}
			} else {
				if ($format == 'json') {
					jimport('joomla.error.log');
					$log = &JLog::getInstance();
					$log->addEntry(array('comment' => $folder));
					jexit('Upload complete');
				} else {
					if ( $tmpl == '' )
					{
						$mainframe->enqueueMessage(JText::_('COM_COLLECTOR_UPLOAD_COMPLETE'));
					}
					// REDIRECT
					$mainframe->redirect($return);
					return;
				}
			}
		} else {
			$mainframe->redirect('index.php', 'Invalid Request', 'error');
		}
		$this->setRedirect( $return );
	}

	/**
	 * Method to display a view
	 *
	 * @access	public
	 */
	function display()
	{
		$view = JRequest::getCmd( 'view' );
		$view = $this->getView( $view , 'html' );
		$model &= $this->getModel( 'filemanager' );
		$view->setModel( $model , false );
		$view->display();
		//parent::display();
	}
}

}else{
//Code pour Joomla >= 1.6.0

jimport('joomla.application.component.controlleradmin');

/**
 * Filemanager Controller
 *
 * @package  	Collector
 */
class CollectorControllerFilemanager extends JControllerAdmin
{
	/**
	 * Method to create a new folder
	 *
	 * @access	public
	 */
	function create()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		$tmpl = JRequest::getCmd( 'tmpl' );
		
		$model = $this->getModel('filemanager');
		$folder = $model->getFolder();
		
		$msg = $model->createFolder();
		
		if ( $tmpl == 'component' )
		{
			$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&tmpl=component&folder='.$folder );
		}
		else
		{
			$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&folder='.$folder, $msg[0], $msg[1] );
		}
		
	}
	
	/**
	 * Method to delete a file or a folder
	 *
	 * @access	public
	 */
	function remove()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('filemanager');
		$folder = $model->getFolder();
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&folder='.$folder, $msg[0], $msg[1] );
	}
	
	/**
	 * Method to rename a file or a folder
	 *
	 * @access	public
	 */
	function rename()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('filemanager');
		$folder = $model->getFolder();
		
		$msg = $model->rename();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&folder='.$folder );
	}
	
	/**
	 * Method to copy a file or a folder
	 *
	 * @access	public
	 */
	function copy()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('filemanager');
		$folder = $model->getFolder();
		
		$msg = $model->copy();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&folder='.$folder );
	}
	
	/**
	 * Method to move a file or a folder
	 *
	 * @access	public
	 */
	function move()
	{
		$option = JRequest::getCmd( 'option' );
		$view = JRequest::getCmd( 'view' );
		
		$model = $this->getModel('filemanager');
		$folder = $model->getFolder();
		
		$msg = $model->move();
		
		$this->setRedirect( 'index.php?option='.$option.'&view='.$view.'&folder='.$folder );
	}
	
	/**
	 * Method to upload a file
	 *
	 * @access	public
	 */
	function upload()
	{
		$application = JFactory::getApplication();

		$view = JRequest::getCmd( 'view' );
		$file 		= JRequest::getVar( 'fileupload', '', 'files', 'array' );
		$folder		= JRequest::getVar( 'folder', '', '', 'path' );
		$tmpl		= JRequest::getVar( 'tmpl', '', '', 'cmd');
		$format		= JRequest::getVar( 'format', 'html', '', 'cmd');
		$err		= null;
		$return		= 'index.php?option=com_collector&view='.$view.'&folder='.$folder.( $tmpl != '' ? '&tmpl='.$tmpl : '' );
		
		// Set FTP credentials, if given
		jimport('joomla.client.helper');
		JClientHelper::setCredentialsFromRequest('ftp');

		// Make the filename safe
		jimport('joomla.filesystem.file');
		$file['name']	= JFile::makeSafe($file['name']);

		if (isset($file['name'])) {
			$filepath = JPath::clean(JPATH_ROOT.DS.$folder.DS.strtolower($file['name']));

			if (JFile::exists($filepath)) {
				if ($format == 'json') {
					jimport('joomla.error.log');
					$log = &JLog::getInstance('upload.error.php');
					$log->addEntry(array('comment' => 'File already exists: '.$filepath));
					header('HTTP/1.0 409 Conflict');
					jexit('Error. File already exists');
				} else {
					JError::raiseNotice(100, JText::_('COM_COLLECTOR_ERROR_FILE_ALREADY_EXISTS'));
					// REDIRECT
					$application->redirect($return);
					return;
				}
			}

			if (!JFile::upload($file['tmp_name'], $filepath)) {
				if ($format == 'json') {
					jimport('joomla.error.log');
					$log = &JLog::getInstance('upload.error.php');
					$log->addEntry(array('comment' => 'Cannot upload: '.$filepath));
					header('HTTP/1.0 400 Bad Request');
					jexit('Error. Unable to upload file');
				} else {
					JError::raiseWarning(100, JText::_('COM_COLLECTOR_ERROR_UNABLE_TO_UPLOAD_FILE'));
					// REDIRECT
					$application->redirect($return);
					return;
				}
			} else {
				if ($format == 'json') {
					jimport('joomla.error.log');
					$log = &JLog::getInstance();
					$log->addEntry(array('comment' => $folder));
					jexit('Upload complete');
				} else {
					if ( $tmpl == '' )
					{
						$application->enqueueMessage(JText::_('COM_COLLECTOR_UPLOAD_COMPLETE'));
					}
					// REDIRECT
					$application->redirect($return);
					return;
				}
			}
		} else {
			$application->redirect('index.php', 'Invalid Request', 'error');
		}
		$this->setRedirect( $return );
	}
	
	/**
	 * Method to remove an extension
	 *
	 * @access	public
	 */
	function remove_ext()
	{
		$option = JRequest::getCmd( 'option' );
		
		$model = $this->getModel('filesconfig');
		
		$msg = $model->remove();
		
		$this->setRedirect( 'index.php?option='.$option.'&tmpl=component&view=filesconfig' );
	}
	
	/**
	 * Method to add an extension
	 *
	 * @access	public
	 */
	function save_ext()
	{
		$option = JRequest::getCmd( 'option' );
		
		$model = $this->getModel('filesconfig');
		
		$msg = $model->save();
		
		$this->setRedirect( 'index.php?option='.$option.'&tmpl=component&view=filesconfig' );
	}
	
	/**
	 * Method to display filemanager configuration
	 *
	 * @access	public
	 */
	function config()
	{
		JRequest::setVar('view', 'filesconfig');
		
		parent::display();
	}
	
	/**
	 * Method to enable an extension
	 *
	 * @access	public
	 */
	function enable()
	{
		$option = JRequest::getCmd( 'option' );
		
		$model = $this->getModel('filesconfig');
		$msg = $model->state(1);
		
		$this->setRedirect( 'index.php?option='.$option.'&tmpl=component&view=filesconfig' );
	}
	
	/**
	 * Method to disable an extension
	 *
	 * @access	public
	 */
	function disable()
	{
		$option = JRequest::getCmd( 'option' );
		
		$model = $this->getModel('filesconfig');
		$msg = $model->state(0);
		
		$this->setRedirect( 'index.php?option='.$option.'&tmpl=component&view=filesconfig' );
	}
	
	/**
	 * Method to display a view
	 *
	 * @access	public
	 */
	function display()
	{
		$view = JRequest::getCmd( 'view' );
		$view = $this->getView( $view , 'html' );
		$model = $this->getModel( 'filemanager' );
		
		$view->setModel( $model , false );
		$view->display();
		//parent::display();
	}
}

}
