<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: collections.php 130 2012-02-19 20:14:53Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport( 'joomla.application.component.model' );

/**
 * Collections model
 * @package	Collector
 */
class CollectorModelCollections extends JModel
{
	/**
	 * Collection data
	 *
	 * @var array object
	 */
	var $_collection = null;
	
	/**
	 * Collection template
	 *
	 * @var object
	 */
	var $_template = null;
	
	/**
	 * @var boolean
	 */
	var $_search = 0;
	
	/**
	 * Constructor
	 */
	function __construct()
	{
		parent::__construct();
		
		global $mainframe, $option;
		
		// Get the pagination request variables
		$limitstart	= $mainframe->getUserStateFromRequest($option.'.collection.limitstart', 'limitstart', 0, 'int');
		$limit = $mainframe->getUserStateFromRequest($option.'.collection.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		
		// In case limit has been changed, adjust it
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		$mainframe->setUserState($option.'.collection.limitstart',0);
		
		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Method to load collection data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 */
	function _loadCollection()
	{
		global $mainframe;
		
		if($this->_id == '0')
		{
			return false;
		}
		
		// Load the collection if it doesn't already exist
		if (empty($this->_collection))
		{
			// Get the page/component configuration
			$query = 'SELECT c.*, u.name AS author,'.
					' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'.
					' FROM #__collector AS c'.
					' LEFT JOIN #__users AS u ON u.id = c.created_by' .
					' WHERE c.id = '. (int) $this->_id;
			$this->_db->setQuery($query);
			$this->_collection = $this->_db->loadObject();
			
			if ( ! $this->_collection ) {
				return false;
			}
			if($this->_collection->publish_down == $this->_db->getNullDate()) {
				$this->_collection->publish_down = JText::_('Never');
			}
		}
		
		return true;
	}

	/**
	 * Method to get collection data
	 */
	function &getCollection()
	{
		global $mainframe, $option;
		
		$reset = $mainframe->getUserState($option.'.collection.reset');
		
		// Load the collection data
		if ($this->_loadCollection())
		{
			// Is the collection published?
			if (!$this->isPublished())
			{
				JError::raiseError( 404, JText::_("Collection not published") );
			}
			
			$this->_collection->parameters =& $this->_loadCollectionParams();
			$this->_collection->fieldsDisplayed = $this->_loadCollectionFields(false);
			$this->_collection->fields = $this->_loadCollectionFields(true);
			
			if ( $this->_collection->custom != '0' )
			{
				$this->custom = explode( '/', $this->_collection->custom );
			}
			else
			{
				foreach ( $this->_collection->fields as $field )
				{
					if ( $field->home == 1 )
					{
						$this->custom[0] = $field->id;
						break;
					}
				}
			}
			
			if ( $reset )
			{
				$this->searchReset();
			}
			$this->_collection->items = $this->_loadItems($reset);
		}
		else
		{
			$collection =& JTable::getInstance('collector');
			$this->_collection = $collection;
		}
		
		return $this->_collection;
	}
	
	function _buildQuery($reset=0)
	{
		global $mainframe;
		
		$model = JModel::getInstance('collection','CollectorModel');
		
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildCollectionWhere();
		$orderby	= $this->_buildCollectionOrderBy();
		
		$query = 'SELECT c.id AS cid, c.*, u.name AS creator, u2.name AS author, u.usertype, ';
		
		foreach ($fields as $field)
		{
			$query .= 'v'.$field->id.'.value AS `field_'.$field->id.'`, ';
		}
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON u.id = c.created_by';
		$query .= ' LEFT JOIN `#__users` AS u2 ON u2.id = c.modified_by';
		
		$query .= $where;
		$query .= $orderby;
		
		if ($reset)
		{
			$cache = & JFactory::getCache("com_collector");
			$this->_total = $cache->call( array ( $model, '_getListCount' ), $query );
		}
		else
		{
			$this->_total = $this->_getListCount($query);
		}
		
		return $query;
	}
	
	/**
	 * Method to build the WHERE clause of the query to select items
	 *
	 * @access	private
	 * @return	string	WHERE clause
	 */
	function _buildCollectionWhere()
	{
		global $mainframe, $option;
		
		$reset = $mainframe->getUserState($option.'.collection.reset');
		
		$fields = $this->_collection->fields;
		$params = $this->_collection->parameters;
		
		$user		=& JFactory::getUser();
		$aid		= (int) $user->get('aid', 0);
		
		$jnow		=& JFactory::getDate();
		$now		= $jnow->toMySQL();
		$nullDate	= $this->_db->getNullDate();
		
		/*
		 * First thing we need to do is assert that the content article is the one
		 * we are looking for and we have access to it.
		 */
		
		$search_all_value = $reset ? '' : $mainframe->getUserStateFromRequest('collection.filter_search_all', 'filter_search_all');
		
		$where = ' WHERE c.collection = ' . $this->_id;
		$where .= ' AND h.state = 1';
		
		$where .= ' AND c.access <= '. (int) $aid;
		
		$where .= ' AND ( ';
		$where .= ' ( c.created_by = ' . (int) $user->id . ' ) ';
		$where .= '   OR ';
		$where .= ' ( c.state = 1' .
				' AND ( c.publish_up = '.$this->_db->Quote($nullDate).' OR c.publish_up <= '.$this->_db->Quote($now).' )' .
				' AND ( c.publish_down = '.$this->_db->Quote($nullDate).' OR c.publish_down >= '.$this->_db->Quote($now).' )';
		$where .= '   ) ';
		$where .= ' ) ';
		
		$where2 = array();
		
		foreach ($fields as $field)
		{
			if ( $field->type == 3 )
			{
				$nameFilterCollection = 'filterfield_'.$field->id;
				$valueFilterCollection = $this->_collection->parameters->get( $nameFilterCollection, 0 );
				
				$filter_field = $reset ? $valueFilterCollection : $mainframe->getUserStateFromRequest( $option.'.collection.filter_field_'.$field->id, 'filter_field_'.$field->id, '', 'int' );
				
				if ( $filter_field != '' )
				{
					$this->_search = 1;
					$where .= ' AND v'.$field->id.'.value = "'.$filter_field.'"';
				}
			}
			if ( $search_all_value != '' )
			{
				$this->_search = 1;
				if ( $field->type == 3 )
				{
					$where2[] = 'd'.$field->id.'.content LIKE "%'.$search_all_value.'%"';
				}
				else
				{
					$where2[] = 'v'.$field->id.'.value LIKE "%'.$search_all_value.'%"';
				}
			}
		}
		
		if (count($where2) > 0 ) {
			$where.= ' AND ('.implode(' OR ', $where2).')';
		}
		
		return $where;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select items
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildCollectionOrderBy()
	{
		global $mainframe, $option;
		
		$reset = $mainframe->getUserState($option.'.collection.reset');
		
		/*$fields_type = array();
		
		$order = '';
		
		$params = $this->_collection->parameters;
		
		$special_order		= $params->get('order');
		if ( $special_order == 'ordering' ) {
			$this->_collection->order_default = 'c.ordering';
			$this->_collection->order_dir_default = '';
		} else if ( $special_order == 'created' ) {
			$this->_collection->order_default = 'c.created';
			$this->_collection->order_dir_default = '';
		} else if ( $special_order == 'rcreated' ) {
			$this->_collection->order_default = 'c.created';
			$this->_collection->order_dir_default = 'desc';
		} else if ( $special_order == 'modified' ) {
			$this->_collection->order_default = 'h.modified';
			$this->_collection->order_dir_default = 'desc';
		} else if ( $special_order == 'rmodified' ) {
			$this->_collection->order_default = 'h.modified';
			$this->_collection->order_dir_default = '';
		} else if ( $special_order == 'default' ) {
			foreach ($this->_collection->fields as $field)
			{
				$fields_type[$field->id] = $field->type;
			}
			foreach ( $this->custom as $field )
			{
				if ( $order != '' )
				{
					$order .= ' , ';
				}
				if ( $fields_type[$field] == 3 )
				{
					$order .= 'd'.$field.'.content';
				}
				else if ( $fields_type[$field] == 6 )
				{
					$order .= 'CAST(v'. $field .'.value AS SIGNED)';
				}
				else
				{
					$order .= 'v'.$field.'.value';
				}
			}
			$this->_collection->order_default = $order;
			$this->_collection->order_dir_default = '';
		} else {
			$this->_collection->order_default = 'c.ordering';
			$this->_collection->order_dir_default = '';
		}*/
		
		
		$this->_collection->filter_order		= $reset ? $this->_collection->order_default : $mainframe->getUserStateFromRequest( $option.'.collection.filter_order'.$this->_id, 'filter_order', '', 'string' );
		$this->_collection->filter_order_Dir	= $reset ? $this->_collection->order_dir_default : $mainframe->getUserStateFromRequest( $option.'.collection.filter_order_Dir'.$this->_id, 'filter_order_Dir', '', 'word' );
		//$filter_order		= $mainframe->getUserStateFromRequest( $option.'.collection.filter_order'.$this->_id, 'filter_order', '', 'string' );
		//$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.collection.filter_order_Dir'.$this->_id, 'filter_order_Dir', '', 'word' );
		
		if ($this->_collection->filter_order == 'c.ordering'){
			$orderby 	= ' ORDER BY c.ordering '.$this->_collection->filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$this->_collection->filter_order.' '.$this->_collection->filter_order_Dir.' , c.ordering ';
		}
		
		return $orderby;
	}
	
	/**
	 * Overridden get method to get properties from the article
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 */
	function get($property, $default=null)
	{
		if ($this->_loadCollection()) {
			if(isset($this->_collection->$property)) {
				return $this->_collection->$property;
			}
		}
		return $default;
	}
	
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->setBigSelects();
			$this->_total = $this->_getListCount($query);
		}
		return $this->_total;
	}
	
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}
}

}else{
//Code pour Joomla >= 1.6.0
jimport('joomla.application.component.modellist');

/**
 * Collections model
 * @package	Collector
 */
class CollectorModelCollections extends JModelList
{
	/**
	 * Constructor.
	 *
	 * @param	array	An optional associative array of configuration settings.
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'c.id',
				'name', 'c.title',
				'description', 'c.description',
				'alias', 'c.alias',
				'checked_out', 'c.checked_out',
				'checked_out_time', 'c.checked_out_time',
				'state', 'c.state',
				'access', 'c.access', 'access_level',
				'created', 'c.created',
				'created_by', 'c.created_by',
				'publish_up', 'c.publish_up',
				'publish_down', 'c.publish_down',
			);
		}

		parent::__construct($config);
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return	void
	 * @since	1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication();
		$session = JFactory::getSession();

		// Adjust the context to support modal layouts.
		if ($layout = JRequest::getVar('layout')) {
			$this->context .= '.'.$layout;
		}

		$this->setState('filter.access', true);

		$this->setState('filter.published', 1);

		// List state information.
		parent::populateState('c.name', 'asc');
	}
	
	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 */
	protected function getListQuery()
	{
		// Create a new query object.
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select',
				'c.id, c.name, c.description, c.alias, c.state, c.created, c.created_by, c.created_by_alias, c.checked_out, c.checked_out_time' .
				', c.modified, c.modified_by, c.access, c.publish_up, c.publish_down, c.home'
			)
		);
		$query->from('#__collector AS c');
		
		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join('LEFT', '#__users AS uc ON uc.id = c.checked_out');
		
		// Join over the users for the author.
		$query->select('ua.name AS author_name');
		$query->join('LEFT', '#__users AS ua ON ua.id = c.created_by');
		
		// Filter by access level.
		if ($access = $this->getState('filter.access')) {
			$user	= JFactory::getUser();
			$groups	= implode(',', $user->getAuthorisedViewLevels());
			$query->where('c.access IN ('.$groups.')');
		}
		
		// Filter by published state
		$published = $this->getState('filter.published');
		if (is_numeric($published)) {
			$query->where('c.state = ' . (int) $published);
		}
		else if ($published === '') {
			$query->where('(c.state = 0 OR c.state = 1)');
		}
		
		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
		$query->order($db->getEscaped($orderCol.' '.$orderDirn));
		
		return $query;
	}
	
	/**
	 * Method to get a list of collections.
	 * Overridden to add a check for access levels.
	 *
	 * @return	mixed	An array of data items on success, false on failure.
	 */
	public function getItems()
	{
		$items	= parent::getItems();
		$app	= JFactory::getApplication();
		if ($app->isSite()) {
			$user	= JFactory::getUser();
			$groups	= $user->getAuthorisedViewLevels();

			for ($x = 0, $count = count($items); $x < $count; $x++) {
				//Check the access level. Remove collections the user shouldn't see
				if (!in_array($items[$x]->access, $groups)) {
					unset($items[$x]);
				}
			}
		}
		return $items;
	}
}
}