<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: item.php 131 2012-03-19 23:33:03Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );


if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
jimport('joomla.application.component.model');

/**
 * Filelist model
 * @package	Collector
 */
class CollectorModelItem extends JModel
{
	/**
	 * Collection Id
	 * @var integer
	 */
	var $_id = null;

	/**
	 * Collection
	 * @var object
	 */
	var $_collection = null;

	/**
	 * Item Id
	 * @var integer
	 */
	var $_itemId = null;

	/**
	 * Item
	 * @var object
	 */
	var $_item = null;

	/**
	 * Only one item displayed
	 * @var booleen
	 */
	var $_singleItem = 0;
	
	/**
	 * Item template
	 * @var object
	 */
	var $_template = null;
	
	/**
	 * Prev item Id
	 * @var int
	 */
	var $_prev = null;
	
	/**
	 * Next item Id
	 * @var int
	 */
	var $_next = null;
	
	/**
	 * HTML navigation
	 * @var string
	 */
	var $_navigation = null;
	
	/**
	 * Item model constructor
	 *
	 * @access	public
	 */
	function __construct()
	{
		parent::__construct();
		
		$id = JRequest::getVar('collection', 0, 'get', 'int');
		if ( $id != 0 )
		{
			$this->_singleItem = 1;
		}
		else
		{
			$id = JRequest::getInt('id', JRequest::getInt('collection', 0, 'post'), 'get');
		}
		$this->setId((int)$id);
		
		global $mainframe, $option;
		
		$this->_itemId	= JRequest::getInt('item', JRequest::getInt('id', 0, 'post'), 'get');
		
		// Get the pagination request variables
		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$this->_limit = $mainframe->getUserStateFromRequest($option.'.collection.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$this->_limit = $app->getUserStateFromRequest($option.'.collection.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		}
	}

	/**
	 * Method to set the collection id
	 *
	 * @access	public
	 * @param	int		Collection ID
	 * @return	void
	 */
	function setId($id)
	{
		// Set new collection ID and wipe data
		$this->_id = $id;
		$this->_collection = null;
		$this->_item = null;
	}

	/**
	 * Method to load collection data
	 * Put data in <var>_collection</var>
	 *
	 * @access	private
	 * @return	boolean	True on success
	 */
	function _loadCollection()
	{
		global $mainframe;

		if($this->_id == '0')
		{
			return false;
		}

		// Load the collection if it doesn't already exist
		if (empty($this->_collection))
		{
			// Get the page/component configuration
			$params = &$mainframe->getParams();

			$query = 'SELECT c.*, u.name AS author,'.
					' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'.
					' FROM #__collector AS c'.
					' LEFT JOIN #__users AS u ON u.id = c.created_by' .
					' WHERE c.id = '. (int) $this->_id;
			$this->_db->setQuery($query);
			$this->_collection = $this->_db->loadObject();

			if ( ! $this->_collection ) {
				return false;
			}
			if($this->_collection->publish_down == $this->_db->getNullDate()) {
				//$this->_collection->publish_down = JText::_('COM_COLLECTOR_NEVER');
			}
		}
		return true;
	}

	/**
	 * Method to get collection data
	 *
	 * @access	public
	 * @return	object	Collection informations
	 */
	function &getCollection()
	{

		// Load the collection data
		if ($this->_loadCollection())
		{
			// Is the collection published?
			if (!$this->isPublished())
			{
				JError::raiseError( 404, JText::_('COM_COLLECTOR_COLLECTION_NOT_PUBLISHED') );
			}

			$this->_loadCollectionParams();
			$this->_loadCollectionFields();

			if ( $this->_collection->custom != '0' )
			{
				$this->custom = explode( '/', $this->_collection->custom );
			}
			else
			{
				foreach ( $this->_collection->fields as $field )
				{
					if ( $field->home == 1 )
					{
						$this->custom[0] = $field->id;
						break;
					}
				}
			}
		}
		else
		{
			$collection =& JTable::getInstance('collector');
			$this->_collection = $collection;
		}

		return $this->_collection;
	}

	/**
	 * Method to load collection parameters
	 * Returns a reference to the global {@link JParameter} object
	 *
	 * @access	private
	 * @return	object JParameter
	 */
	function _loadCollectionParams()
	{
		global $mainframe;

		// Get the page/component configuration
		$params = clone($mainframe->getParams('com_collector'));

		// Set the collection object's parameters
		$this->_collection->parameters = & $params;
	}

	/**
	 * Method to load fields informations
	 *
	 * @access	private
	 * @return	mixed			Array of fields objects. False if no fields loaded.
	 */
	function _loadCollectionFields()
	{
		if($this->_id == '0')
		{
			return false;
		}

		$user		=& JFactory::getUser();
		$aid		= (int) $user->get('aid', 0);

		$jnow		=& JFactory::getDate();
		$now		= $jnow->toMySQL();
		$nullDate	= $this->_db->getNullDate();

		$query = 'SELECT c.*, u.name AS author, u.usertype';
		$query .= ' FROM #__collector_fields AS c';
		$query .= ' LEFT JOIN #__users AS u ON u.id = c.created_by';
		$query .= ' WHERE collection = ' . $this->_id;
		$query .= ' AND c.access <= '. (int) $aid;

		$query .= ' AND ( ';
		$query .= ' ( c.created_by = ' . (int) $user->id . ' ) ';
		$query .= '   OR ';
		$query .= ' ( c.state = 1' .
				' AND ( c.publish_up = '.$this->_db->Quote($nullDate).' OR c.publish_up <= '.$this->_db->Quote($now).' )' .
				' AND ( c.publish_down = '.$this->_db->Quote($nullDate).' OR c.publish_down >= '.$this->_db->Quote($now).' )';
		$query .= '   ) ';
		$query .= ' ) ';

		$query .= ' ORDER BY ordering';

		$this->_db->setQuery($query);
		$this->_collection->fields = $this->_db->loadObjectList();

		if ( ! $this->_collection->fields ) {
			return false;
		}

		return true;
	}

	/**
	 * Method to load item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 */
	function _loadItem()
	{
		if($this->_id == '0')
		{
			return false;
		}

		$query = $this->_buildQuery();

		$this->setBigSelects();
		$this->_db->setQuery($query);
		$this->_item = $this->_db->loadObject();

		if ( ! $this->_item ) {
			return false;
		}

		$fields = $this->_collection->fields;

		foreach ( $fields as $field )
		{
			if ( $field->type == '3' )
			{
				//$nameField[$field->id] = $field->field;
				$nameField[$field->id] = $field->tablecolumn.'_content';
			}
			else
			{
				//$nameField[$field->id] = 'field_'.$field->id;
				$nameField[$field->id] = $field->tablecolumn;
			}

			if ( $field->home == 1 )
			{
				$defaultField = $nameField[$field->id];
			}
		}

		if ( $this->_collection->custom != "0" )
		{
			$customTitle = explode( '/', $this->_collection->custom );

			foreach ( $customTitle as $fieldNumber )
			{
				$fieldName = $nameField[$fieldNumber];
				$title[] = $this->_item->$fieldName;
			}
			$this->_item->customTitle = implode( ' ', $title );
		}
		else
		{
			$this->_item->customTitle = $this->_item->$defaultField;
		}

		return true;
	}

	/**
	 * Method to get item data
	 *
	 * @access	public
	 * @return	object	Item informations
	 */
	function &getItem()
	{

		// Load the collection data
		if (!$this->_loadItem())
		{
			return false;
		}

		return $this->_item;
	}

	/**
	 * Method to create the query to select item
	 *
	 * @access	private
	 * @return	string			Query to select item
	 */
	function _buildQuery()
	{
		global $mainframe;

		$fields = $this->_collection->fields;

		// Get the page/component configuration
		$params = &$mainframe->getParams();

		// Get the WHERE and ORDER BY clauses for the query
		$where = $this->_buildCollectionWhere();
		$where .= ' AND c.id = ' . (int) $this->_itemId ;
		//$orderby = $this->_buildCollectionOrderBy();

		$query = 'SELECT c.*, u.name AS creator, u2.name AS author, u.usertype, h.*, ';

		foreach ($fields as $field)
		{
			if ($field->type == 3)
			{
				$query .= 'd'.$field->id.'.content AS `'.$field->tablecolumn.'_content`, ';
			}
		}
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON u.id = c.created_by';
		$query .= ' LEFT JOIN `#__users` AS u2 ON u2.id = c.modified_by';
		$query .= ' LEFT JOIN `#__collector_items_history_'.$this->_id.'` AS h ON h.item = c.id';

		foreach ($fields as $field)
		{
			if ($field->type == 3)
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$field->id.' ON d'.$field->id.'.id = h.'.$field->tablecolumn;
			}
		}

		$query .= $where;
		//$query .= $orderby;

		return $query;
	}

	/**
	 * Method to build the WHERE clause of the query to select items
	 *
	 * @access	private
	 * @return	string	WHERE clause
	 */
	function _buildCollectionWhere()
	{
		global $mainframe,$option;

		$fields = $this->_collection->fields;

		$user		=& JFactory::getUser();
		$aid		= (int) $user->get('aid', 0);

		$jnow		=& JFactory::getDate();
		$now		= $jnow->toMySQL();
		$nullDate	= $this->_db->getNullDate();

		/*
		 * First thing we need to do is assert that the content article is the one
		 * we are looking for and we have access to it.
		 */

		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$search_all_value = $mainframe->getUserStateFromRequest('collection.filter_search_all', 'filter_search_all');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$search_all_value = $app->getUserStateFromRequest('collection.filter_search_all', 'filter_search_all');
		}

		$where = ' WHERE h.state = 1';
		
		$where .= ' AND c.collection = '.$this->_id;

		$where .= ' AND c.access <= '. (int) $aid;

		$where .= ' AND ( ';
		$where .= ' ( c.created_by = ' . (int) $user->id . ' ) ';
		$where .= '   OR ';
		$where .= ' ( c.state = 1' .
				' AND ( c.publish_up = '.$this->_db->Quote($nullDate).' OR c.publish_up <= '.$this->_db->Quote($now).' )' .
				' AND ( c.publish_down = '.$this->_db->Quote($nullDate).' OR c.publish_down >= '.$this->_db->Quote($now).' )';
		$where .= '   ) ';
		$where .= ' ) ';

		$where2 = array();

		foreach ($fields as $field)
		{
			if ( $field->type == 3 )
			{
				if(version_compare(JVERSION,'1.6.0','<')){
					//Code pour Joomla! 1.5
					$filter_field = $mainframe->getUserStateFromRequest( $option.'.collection.filter_field_'.$field->id, 'filter_field_'.$field->id, '', 'int' );
				}else{
					//Code pour Joomla >= 1.6.0
					$app = JFactory::getApplication();
					$filter_field = $app->getUserStateFromRequest( $option.'.collection.filter_field_'.$field->id, 'filter_field_'.$field->id, '', 'int' );
				}
				
				if ( $filter_field != '' )
				{
					$where .= ' AND h.'.$field->tablecolumn.' = "'.$filter_field.'"';
				}
			}
			if ( $search_all_value != '' )
			{
				if ( $field->type == 3 )
				{
					$where2[] = 'd'.$field->id.'.content LIKE "%'.$search_all_value.'%"';
				}
				else
				{
					$where2[] = 'h.'.$field->tablecolumn.' LIKE "%'.$search_all_value.'%"';
				}
			}
		}

		if (count($where2) > 0 ) {
			$where.= ' AND ('.implode(' OR ', $where2).')';
		}

		return $where;
	}

	/**
	 * Method to build the ORDER BY clause of the query to select items
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildCollectionOrderBy()
	{
		global $mainframe, $option;

		$fields_type = array();

		$order = '';

		$params = &JComponentHelper::getParams( 'com_collector' );

		$special_order		= $params->get('order');
		if ( $special_order == 'ordering' ) {
			$this->_collection->order_default = 'c.ordering';
			$this->_collection->order_dir_default = '';
		} else if ( $special_order == 'created' ) {
			$this->_collection->order_default = 'c.created';
			$this->_collection->order_dir_default = '';
		} else if ( $special_order == 'rcreated' ) {
			$this->_collection->order_default = 'c.created';
			$this->_collection->order_dir_default = 'DESC';
		} else if ( $special_order == 'modified' ) {
			$this->_collection->order_default = 'h.modified';
			$this->_collection->order_dir_default = 'DESC';
		} else if ( $special_order == 'rmodified' ) {
			$this->_collection->order_default = 'h.modified';
			$this->_collection->order_dir_default = '';
		} else if ( $special_order == 'default' ) {
			foreach ($this->_collection->fields as $field)
			{
				$fields_type[$field->id] = $field->type;
				$fields_column[$field->id] = $field->tablecolumn;
			}
			foreach ( $this->custom as $field )
			{
				if ( $order != '' )
				{
					$order .= ' , ';
				}
				if ( $fields_type[$field] == 3 )
				{
					$order .= 'd'.$field.'.content';
				}
				else if ( $fields_type[$field] == 6 )
				{
					$order .= 'CAST(h.'. $fields_column[$field] .' AS SIGNED)';
				}
				else if ( $fields_type[$field] == 7 )
				{
					$order .= 'CAST(h.'. $fields_column[$field] .' AS DATETIME)';
				}
				else
				{
					$order .= 'h'.$fields_column[$field];
				}
			}
			$this->_collection->order_default = $order;
			$this->_collection->order_dir_default = '';
		} else {
			$this->_collection->order_default = 'c.ordering';
			$this->_collection->order_dir_default = '';
		}

		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$filter_order		= $mainframe->getUserStateFromRequest( $option.'.collection.filter_order'.$this->_id,		'filter_order',		$this->_collection->order_default,		'string' );
			$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.collection.filter_order_Dir'.$this->_id,	'filter_order_Dir',	$this->_collection->order_dir_default,	'word' );
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$filter_order		= $app->getUserStateFromRequest( $option.'.collection.filter_order'.$this->_id,		'filter_order',		$this->_collection->order_default,		'string' );
			$filter_order_Dir	= $app->getUserStateFromRequest( $option.'.collection.filter_order_Dir'.$this->_id,	'filter_order_Dir',	$this->_collection->order_dir_default,	'word' );
		}

		if ($filter_order == 'c.ordering'){
			$orderby 	= ' ORDER BY c.ordering '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , c.ordering ';
		}

		return $orderby;
	}

	/**
	 * Overridden get method to get properties from the collection
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 */
	function get($property, $default=null)
	{
		if ($this->_loadCollection()) {
			if(isset($this->_collection->$property)) {
				return $this->_collection->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to increment the hit counter for the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function hit()
	{
		global $mainframe;

		if ($this->_id)
		{
			$item = & JTable::getInstance('collector_items','Table');
			$item->initVersion($this->_id);
			
			$item->hit($this->_itemId);
			return true;
		}
		return false;
	}

	/**
	 * Tests if collection is checked out
	 *
	 * @access	public
	 * @param	int		$uid	A user id
	 * @return	boolean			True if checked out
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadCollection())
		{
			if ($uid) {
				return ($this->_collection->checked_out && $this->_collection->checked_out != $uid);
			} else {
				return $this->_collection->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'Unable to Load Data');
			return false;
		}
	}

	/**
	 * Tests if collection is published
	 *
	 * @access	public
	 * @return	boolean	True if published
	 */
	function isPublished( )
	{
		global $mainframe;

		$now =& JFactory::getDate();
		$nullDate = $this->_db->getNullDate();
		$config =& JFactory::getConfig();


		// Test state of the collection
		if ($this->_loadCollection())
		{

			$publish_up =& JFactory::getDate($this->_collection->publish_up);
			$publish_down =& JFactory::getDate($this->_collection->publish_down);
			$publish_up->setOffset($config->getValue('config.offset'));
			$publish_down->setOffset($config->getValue('config.offset'));

			if ( $this->_collection->state == 1 )
			{
				if ( $now->toUnix() <= $publish_up->toUnix() )
				{
					return true;
				}
				else if ( ($now->toUnix() <= $publish_down->toUnix() || $this->_collection->publish_down == $nullDate ) )
				{
					return true;
				}
				else if ( $now->toUnix() > $publish_down->toUnix() )
				{
					return false;
				}
			}
			else if ( $this->_collection->state == 0 )
			{
				return false;
			}
			else if ( $this->_collection->state == -1 )
			{
				return false;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'Unable to Load Data');
			return false;
		}

	}

	/**
	 * Method to load item template
	 * Put data in <var>_template</var>
	 *
	 * @access	private
	 * @return	boolean	True on success
	 */
	function _loadTemplate()
	{
		global $mainframe;

		if($this->_id == '0')
		{
			return false;
		}

		// Load the collection if it doesn't already exist
		if (empty($this->_template))
		{
			$query = 'SELECT *';
			$query .= ' FROM #__collector_templates';
			$query .= ' WHERE client = 2';
			$query .= ' AND collection = '. $this->_id;
			$query .= ' AND home = 1' ;
			$this->_db->setQuery($query);
			$this->_template = $this->_db->loadObject();

			if ( empty($this->_template) ) {
				$query = 'SELECT *';
				$query .= ' FROM #__collector_templates';
				$query .= ' WHERE client = 2';
				$query .= ' AND collection = 0';
				$this->_db->setQuery($query);
				$this->_template = $this->_db->loadObject();

				if ( empty($this->_template) ) {
					return false;
				}
			}
		}
		return true;
	}

	/**
	 * Method to get collection template
	 *
	 * @access	public
	 * @return	object	Template object
	 */
	function &getTemplate()
	{
		// Load the collection data
		if (!$this->_loadTemplate())
		{
			JError::raiseError( 404, JText::_('COM_COLLECTOR_ERROR_LOADING_TEMPLATE') );
		}

		return $this->_template;
	}

	/**
	 * Method to get navigation
	 * using FOR loop
	 * Put values in <var>_prev</var> and <var>_next</var>
	 *
	 * @access	public
	 * @return	void
	 */
	function getPrevNextFOR()
	{
		$fields = $this->_collection->fields;
		$this->_prev = 0;
		$this->_next = 0;

		// Get the WHERE and ORDER BY clauses for the query
		$where = $this->_buildCollectionWhere();
		$orderby = $this->_buildCollectionOrderBy();

		$query = 'SELECT c.id,';
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON u.id = c.created_by';
		$query .= ' LEFT JOIN `#__users` AS u2 ON u2.id = c.modified_by';
		$query .= ' LEFT JOIN `#__collector_items_history_'.$this->_id.'` AS h ON h.item = c.id';

		foreach ($fields as $field)
		{
			if ($field->type == 3)
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$field->id.' ON d'.$field->id.'.id = h.'.$field->tablecolumn;
			}
		}

		$query .= $where;
		$query .= $orderby;

		$this->_db->setQuery($query);
		//$items = $this->_db->loadResultArray();
		$items = $this->_db->loadRowList();

		$total = count($items);

		for($i=0;$i<count($items);$i++)
		{
			if ($items[$i][0] == $this->_itemId)
			{
				$key = $i;
				break;
			}
		}
		//$key = array_search($this->_itemId, $items);
		if ( $key != 0 )
		{
			$this->_prev = $items[$key - 1][1];
		}
		if ( $key != $total - 1 )
		{
			$this->_next = $items[$key + 1][1];
		}
		
		$this->_limitstart = $this->_limit ? ((int)($key/$this->_limit))*$this->_limit : 0;
	}

	/**
	 * Method to get navigation
	 * using ARRAY search
	 * Put values in <var>_prev</var> and <var>_next</var>
	 *
	 * @access	public
	 * @return	void
	 */
	function getPrevNextARRAY()
	{
		$fields = $this->_collection->fields;
		$this->_prev = 0;
		$this->_next = 0;

		// Get the WHERE and ORDER BY clauses for the query
		$where = $this->_buildCollectionWhere();
		$orderby = $this->_buildCollectionOrderBy();

		$query = 'SELECT c.id,';
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON u.id = c.created_by';
		$query .= ' LEFT JOIN `#__users` AS u2 ON u2.id = c.modified_by';
		$query .= ' LEFT JOIN `#__collector_items_history_'.$this->_id.'` AS h ON h.item = c.id';

		foreach ($fields as $field)
		{
			if ($field->type == 3)
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$field->id.' ON d'.$field->id.'.id = h.'.$field->tablecolumn;
			}
		}

		$query .= $where;
		$query .= $orderby;

		$this->_db->setQuery($query);
		$itemsId = $this->_db->loadResultArray();
		$itemsSlug = $this->_db->loadResultArray(1);

		$total = count($itemsId);

		$key = array_search($this->_itemId, $itemsId);
		if ( $key != 0 )
		{
			$this->_prev = $itemsSlug[$key - 1];
		}
		if ( $key != $total - 1 )
		{
			$this->_next = $itemsSlug[$key + 1];
		}
		
		$this->_limitstart = $this->_limit ? ((int)($key/$this->_limit))*$this->_limit : 0;
	}

	function checkId($item, $key)
	{
		if ($item['id'] == $this->_itemId)
		{
			if ( $key != 0 )
			{
				$this->_prev = $items[$key - 1][1];
			}
			if ( $key != $total - 1 )
			{
				$this->_next = $items[$key + 1][1];
			}
		}
	}
	
	/**
	 * Method to get html navigation
	 * Put data in <var>_navigation</var>
	 *
	 * @access	public
	 * @return	string Navigation html
	 */
	function getNavigation()
	{
		global $mainframe, $option;

		// Load the content if it doesn't already exist
		if (empty($this->_navigation))
		{
			$this->_navigation = '';
			
			if ( !$this->_singleItem )
			{
				/*list($date_debut_usec, $date_debut_sec) = explode(" ", microtime());*/
				$this->getPrevNextFOR();
				/*list($date_fin_usec, $date_fin_sec) = explode(" ", microtime());
				echo 'Boucle FOR = '.($date_fin_usec - $date_debut_usec);
				
				list($date_debut_usec, $date_debut_sec) = explode(" ", microtime());
				$this->getPrevNextARRAY();
				list($date_fin_usec, $date_fin_sec) = explode(" ", microtime());
				echo ' - Joomla + Array = '.($date_fin_usec - $date_debut_usec);*/
				
				$prev = $this->_prev;
				$next = $this->_next;
				$limitstart = $mainframe->setUserState($option.'.collection.limitstart',$this->_limitstart);
				$img_base = './components/com_collector/assets/images/';
				$link_base = 'index.php';
				$link_back = $link_base;

				$option = JRequest::getVar('option', 0, 'get');
				$collection = JRequest::getVar('id', 0, 'get');
				$item = JRequest::getVar('item', 0, 'get');
				$Itemid = JRequest::getVar('Itemid', 0, 'get');

				$link_base .= '?option='.$option.'&view=item&id='.$collection.'&Itemid='.$Itemid;
				$link_back .= '?option='.$option.'&view=collection&id='.$collection.'&Itemid='.$Itemid;

				if ($prev == 0)
				{
					$this->_navigation .= '<img src="'.$img_base.'empty.png" />';
				}
				else
				{
					$this->_navigation .= '<a href="'.JRoute::_($link_base.'&item='. $prev) .'" ><img src="'.$img_base.'leftarrow.png" /></a>';
				}

				$this->_navigation .= '<a href="javascript:document.backForm.submit()" ><img src="'.$img_base.'uparrow.png" /><form name="backForm" method="post" action="'.JRoute::_($link_back).'" style="display:inline" ><input type="hidden" name="reset" value="0" /></form></a>';

				if ($next == 0)
				{
					$this->_navigation .= '<img src="'.$img_base.'empty.png" />';
				}
				else
				{
					$this->_navigation .= '<a href="'.JRoute::_($link_base.'&item='. $next) .'" ><img src="'.$img_base.'rightarrow.png" /></a>';
				}
			}
		}
		return $this->_navigation;
	}

	/**
	 * Method to get an item from a collection
	 *
	 * @access	public
	 * @param	object	$field	The field object
	 * @param	int		$id		The Id of the item
	 * @return 	mixed 			Item object. False if no item loaded
	 */
	function getObject($field, $id)
	{
		// recuperation du titre personnalise pour la collection
		$collection = $field->defined;
		
		$query = 'SELECT custom';
		$query .= ' FROM `#__collector`';
		$query .= ' WHERE id = \'' . $collection . '\'';
		
		$row = $this->_getList( $query );
		
		if ( $row[0]->custom == "0" )
		{
			$query = 'SELECT id';
			$query .= ' FROM `#__collector_fields`';
			$query .= ' WHERE collection = \'' . $collection . '\'';
			$query .= ' AND home = \'1\'';
			
			$row = $this->_getList( $query );
			
			$custom[] = $row[0]->id;
		}
		else
		{
			$custom = explode( '/', $row[0]->custom );
		}
		
		$query = 'SELECT id, field, tablecolumn, type, defined';
		$query .= ' FROM `#__collector_fields`';
		$query .= ' WHERE collection = \'' . $collection . '\'';
		
		$results = $this->_getList( $query );
		
		$i = 0;
		
		foreach ( $custom as $field )
		{
			for ($j = 0; $j < count($results); $j ++)
			{
				$number_field_default[$i] = $field;
				
				if ( $results[$j]->id == $field )
				{
					$name_field_default[$i] = $results[$j]->field;
					$column_field_default[$i] = $results[$j]->tablecolumn;
					if ( $results[$j]->type == 3 )
					{
						$defined_field_default[$i] = $results[$j]->defined;
					}
					else
					{
						$defined_field_default[$i] = null;
					}
				}
			}
			$i ++;
		}
		
		// recherche des objets de la collection
		//$query = 'SELECT c.id, c.state, ordering, hits, created, created_by, u.name AS author, created_by_alias, access, g.name AS groupname, publish_up, publish_down, ';
		$query = 'SELECT c.id,';
		for ( $i=0; $i < count($number_field_default); $i ++ )
		{
			if ($defined_field_default[$i])
			{
				$query .= ' d'.$i.'.content AS name'.$i.',';
			}
			else
			{
				$query .= ' h.'.$column_field_default[$i].' AS name'.$i.',';
			}
		}
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON c.created_by = u.id';
		$query .= ' LEFT JOIN `#__groups` AS g ON c.access = g.id';
		$query .= ' LEFT JOIN `#__collector_items_history_'.$collection.'` AS h ON h.item = c.id';
		for ( $i=0; $i < count($number_field_default); $i ++ )
		{
			if ($defined_field_default[$i])
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$i.' ON h.' . $column_field_default[$i] . ' = d'.$i.'.id';
			}
		}
		$query .= ' WHERE h.state = 1';
		$query .= ' AND c.id = ' . $id;
		$query .= ' AND c.collection = ' . $collection;
		$query .= ' ORDER BY c.ordering';
		
		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();
		
		$name = $row->name0;
		
		for ($j=1; $j<count($number_field_default); $j ++)
		{
			$field = 'name'.$j;
			$name .= ' ' . $row->$field;
		}
		
		$row->name = $name;
		
		return $row;
	}

	/**
	 * Method to get a list of items from a collection
	 *
	 * @access	public
	 * @param	object	$field	The field object
	 * @return 	array 			Array of Items objects.
	 */
	function getItemsList($field)
	{
		// recuperation du titre personnalise pour la collection
		$collection = $field->defined;
		
		$query = 'SELECT custom';
		$query .= ' FROM `#__collector`';
		$query .= ' WHERE id = \'' . $collection . '\'';
		
		$row = $this->_getList( $query );
		
		if ( $row[0]->custom == "0" )
		{
			$query = 'SELECT id';
			$query .= ' FROM `#__collector_fields`';
			$query .= ' WHERE collection = \'' . $collection . '\'';
			$query .= ' AND home = \'1\'';
			
			$row = $this->_getList( $query );
			
			$custom[] = $row[0]->id;
		}
		else
		{
			$custom = explode( '/', $row[0]->custom );
		}
		
		$query = 'SELECT id, field, tablecolumn, type, defined';
		$query .= ' FROM `#__collector_fields`';
		$query .= ' WHERE collection = \'' . $collection . '\'';
		
		$results = $this->_getList( $query );
		
		$i = 0;
		
		foreach ( $custom as $field )
		{
			for ($j = 0; $j < count($results); $j ++)
			{
				$number_field_default[$i] = $field;
				
				if ( $results[$j]->id == $field )
				{
					$name_field_default[$i] = $results[$j]->field;
					$column_field_default[$i] = $results[$j]->tablecolumn;
					if ( $results[$j]->type == 3 )
					{
						$defined_field_default[$i] = $results[$j]->defined;
					}
					else
					{
						$defined_field_default[$i] = null;
					}
				}
			}
			$i ++;
		}
		
		// recherche des objets de la collection
		//$query = 'SELECT c.id, c.state, ordering, hits, created, created_by, u.name AS author, created_by_alias, access, g.name AS groupname, publish_up, publish_down, ';
		$query = 'SELECT c.id,';
		for ( $i=0; $i < count($number_field_default); $i ++ )
		{
			if ($defined_field_default[$i])
			{
				$query .= ' d'.$number_field_default[$i].'.content AS name'.$i.',';
			}
			else
			{
				$query .= ' v' . $number_field_default[$i] . '.value AS name'.$i.',';
			}
		}
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON c.created_by = u.id';
		$query .= ' LEFT JOIN `#__groups` AS g ON c.access = g.id';
		$query .= ' LEFT JOIN `#__collector_items_history_' . $collection . '` AS h ON h.item = c.id';
		for ( $i=0; $i < count($number_field_default); $i ++ )
		{
			if ($defined_field_default[$i])
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$number_field_default[$i].' ON h.' . $column_field_default[$i] . ' = d'.$number_field_default[$i].'.id';
			}
		}
		$query .= ' WHERE h.state = 1';
		$query .= ' WHERE c.collection = '.$collection;
		$query .= ' ORDER BY c.ordering';
		
		$results = $this->_getList( $query );
		
		foreach ( $results as $row )
		{
			$item = new stdClass;
			$item->value = $row->id;
			
			$name = $row->name0;
			
			for ($j=1; $j<count($number_field_default); $j ++)
			{
				$field = 'name'.$j;
				$name .= ' ' . $row->$field;
			}
			
			$item->text = $name;
			
			$items[] = $item;
		}
		
		return $items;
	}

	/**
	 * Method to store a record
	 *
	 * @access	public
	 * @return	boolean True on success
	 */
	function store()
	{
		global $mainframe;

		$db			= & JFactory::getDBO();
		$user		= & JFactory::getUser();

		$post = JRequest::get('post');

		// on initialise les variables
		$params =& $mainframe->getParams('com_collector');

		$item = & JTable::getInstance('collector_items','Table');

		if ( $this->_itemId != '' )
		{
			$item->loadVersion($this->_id, $this->_itemId);
		}
		else
		{
			$item->initVersion($this->_id);
		}

		if ( $params->get('save_history') )
		{
			$version = null;
		}
		else
		{
			$version = $item->history->id;
		}

		if (!$item->bindVersion($post))
		{
			JError::raiseError( 500, $item->getError() );
			return false;
		}

		// make sure the collector record is valid
		if ( !$item->checkVersion() )
		{
			JError::raiseWarning( 500, $item->getError() );
			return false;
		}

		// store the record in the database
		if ( !$item->storeVersion($version) )
		{
			JError::raiseError( 500, $item->getError() );
			return false;
		}

		// libere la collection
		$item->checkin();

		if ( $this->_itemId == 0 )
		{
			// messaging for new items
			require_once (JPATH_ADMINISTRATOR.DS.'components'.DS.'com_messages'.DS.'tables'.DS.'message.php');

			// load language for messaging
			$lang =& JFactory::getLanguage();
			$lang->load('com_messages');

			$query = 'SELECT id' .
					' FROM #__users' .
					' WHERE sendEmail = 1';
			$db->setQuery($query);
			$users = $db->loadResultArray();
			foreach ($users as $user_id)
			{
				$mail = new TableMessage($db);
				$mail->send($user->get('id'), $user_id, JText::_('COM_COLLECTOR_NEW_ITEM'), JText::sprintf('COM_COLLECTOR_ON_NEW_ITEM', $user->get('username'), $item->id.':'.$item->alias));
			}
		} else {
			// If the article isn't new, then we need to clean the cache so that our changes appear realtime :)
			$cache = &JFactory::getCache('com_collector');
			$cache->clean();
		}

		return true;
	}

	/**
	 * Retrieve the default folder for images
	 *
	 * @access	public
	 * @return	string	Relative Path from site root
	 */
	function getFolder()
	{
		return 'images/collector/collection/'.$this->_collection->alias;
	}
	
	/**
	 * Method to force SQL_BIG_SELECTS
	 *
	 * @access	public
	 * @return	void
	 */
	function setBigSelects()
	{
		$db =& JFactory::getDBO();
		
		$query = 'SET SQL_BIG_SELECTS=1';
		$db->setQuery( $query );
		$db->query();
	}
}

}else{
//Code pour Joomla >= 1.6.0
// jimport( 'joomla.application.component.modelitem' );
// jimport( 'joomla.application.component.modelform' );
jimport( 'joomla.application.component.modeladmin' );

require_once(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_collector'.DS.'classes'.DS.'field.php');

/**
 * Filelist model
 * @package	Collector
 */
// class CollectorModelItem extends JModelItem
// class CollectorModelItem extends JModelForm
class CollectorModelItem extends JModelAdmin
{
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @since	1.6
	 */
	protected function populateState()
	{
		$app = JFactory::getApplication('site');

		// Load state from the request.
		$pkc = JRequest::getInt('collection');
		$pki = JRequest::getInt('id');
		$this->setState('collection.id', $pkc);
		$this->setState('item.id', $pki);

		// Load the parameters. Merge Global and Menu Item params into new object
		$params = $app->getParams();
		$menuParams = new JRegistry;

		if ($menu = $app->getMenu()->getActive()) {
			$menuParams->loadString($menu->params);
		}

		$mergedParams = clone $menuParams;
		$mergedParams->merge($params);

		$this->setState('params', $mergedParams);

		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);
		
		$user		= JFactory::getUser();
		if ((!$user->authorise('core.edit.state', 'com_collector.item.'.(int) $pki)) &&  (!$user->authorise('core.edit', 'com_collector.item.'.(int) $pki))){
			// limit to published for people who can't edit or edit.state.
			$this->setState('filter.published', 1);
			// Filter by start and end dates.
			$nullDate = $db->Quote($db->getNullDate());
			$nowDate = $db->Quote(JFactory::getDate()->toMySQL());

			$query->where('(i.publish_up = ' . $nullDate . ' OR i.publish_up <= ' . $nowDate . ')');
			$query->where('(i.publish_down = ' . $nullDate . ' OR i.publish_down >= ' . $nowDate . ')');
		}
		else {
			$this->setState('filter.published', array(0, 1, 2));
		}
		
		$itemid = JRequest::getInt('collection', 0) . ':' . JRequest::getInt('Itemid', 0);
		
		$search_all_value = $app->getUserStateFromRequest('com_collector.collection.'.$itemid.'.filter_search_all', 'filter_search_all', '');
		
		$orderCol = $app->getUserStateFromRequest('com_collector.collection.' . $itemid . '.filter_order', 'filter_order', 'i.ordering', 'string');
		// if (!in_array($orderCol, $this->filter_fields)) {
			// $orderCol = 'i.ordering';
		// }
		$this->setState('list.ordering', $orderCol);

		$listOrder = $app->getUserStateFromRequest('com_collector.collection.' . $itemid . '.filter_order_Dir',	'filter_order_Dir', '', 'cmd');
		if (!in_array(strtoupper($listOrder), array('ASC', 'DESC', ''))) {
			$listOrder = 'ASC';
		}
		$this->setState('list.direction', $listOrder);
	}

	/**
	 * Method to load default collection Id in <var>_collection</var>
	 *
	 * @access	private
	 */
	public function getCollection()
	{
		$user		= JFactory::getUser();
		
		if ( empty($this->_collection) )
		{
			$collection = $this->getState('collection.id');
			
			if ($collection == '')
			{
				$query = 'SELECT id';
				$query .= ' FROM `#__collector`';
				$query .= ' WHERE home = 1';
				
				$row = $this->_getList( $query );
				
				if ( !$row )
				{
					/**
					 * tag à defaut d'une collection
					 */
					$query = 'UPDATE `#__collector` SET home = 1 LIMIT 1;';
					$this->_db->setQuery( $query );
					$this->_db->query();
					
					$query = 'SELECT id';
					$query .= ' FROM `#__collector`';
					$query .= ' WHERE home = 1';
					
					$row = $this->_getList( $query );
				}
				if ( $row == null )
				{
					return false;
				}
				else
				{
					$collection = $row[0]->id;
				}
			}
			
			// Create a new query object.
			$db =& JFactory::getDBO();
			$query = $db->getQuery(true);
			
			// Select the required fields from the table.
			$query->select('c.*, u.name AS author');
			$query->from('#__collector AS c');
			$query->join('LEFT', '#__users AS u ON u.id = c.created_by');
			// Filter by start and end dates.
			$nullDate = $db->Quote($db->getNullDate());
			$nowDate = $db->Quote(JFactory::getDate()->toMySQL());

			$query->where('((c.created_by = '.$user->id.') OR (c.state = 1 AND ( c.publish_up = '.$nullDate.' OR c.publish_up <= '.$nowDate.') AND ( c.publish_down = '.$nullDate.' OR c.publish_down >= '.$nowDate.' )))');
			
			// Add the filder on ID
			$query->where('c.id = '.$collection);
			
			$db->setQuery( $query );
			
			$this->_collection = $db->loadObject();
			
			if ($this->_collection->custom == 0)
			{
				$query = $db->getQuery(true);
				$query->select('id');
				$query->from('#__collector_fields');
				$query->where('collection = '.$collection);
				$query->where('home = 1');
				
				$db->setQuery( $query );
				
				$this->_collection->custom = $db->loadResult();
			}
			
			$this->_collection->custom = explode('/',$this->_collection->custom);
		}
		
		return $this->_collection;
	}
	
	/**
	 * Method to load fields informations
	 *
	 * @access	private
	 * @return	mixed			Array of fields objects. False if no fields loaded.
	 */
	function getFields()
	{
		if ( empty($this->_fields) )
		{
			if ( $this->_collection->id == '0' )
			{
				return false;
			}
			else
			{
				$collection = $this->_collection->id;
			}
			
			$db		= $this->getDbo();
			$query	= $db->getQuery(true);
			
			$user		=& JFactory::getUser();
			$aid		= (int) $user->get('aid', 0);
			
			$jnow		=& JFactory::getDate();
			$now		= $jnow->toMySQL();
			$nullDate	= $db->getNullDate();
			
			$query->select('f.*, u.name AS author, u.usertype');
			$query->from('#__collector_fields AS f');
			
			// Join over the type.
			$query->select('t.type AS type');
			$query->join('LEFT', '#__collector_fields_type AS t ON t.id = f.type');
			
			$query->join('LEFT', '#__users AS u ON u.id = f.created_by');
			$query->where('collection = ' . $collection);
			
			$query->where('( f.created_by = ' . (int) $user->id . ' OR ( f.state = 1 AND ( f.publish_up = '.$db->Quote($nullDate).' OR f.publish_up <= '.$db->Quote($now).' ) AND ( f.publish_down = '.$db->Quote($nullDate).' OR f.publish_down >= '.$db->Quote($now).' ) ) )');
			
			// Filter by access level.
			if ($access = $this->getState('filter.access')) {
				$user	= JFactory::getUser();
				$groups	= implode(',', $user->getAuthorisedViewLevels());
				$query->where('f.access IN ('.$groups.')');
			}
			$query->order('ordering');
			
			$db->setQuery($query);
			$fields = $db->loadObjectList();
			
			if ( ! $fields ) {
				return false;
			}
			
			foreach ($fields as $field)
			{
				$registry = new JRegistry;
				$registry->loadString($field->attribs);
				$field->attribs = $registry->toArray();
				$this->_fields[] =& CollectorField::getInstance( $this->_collection->id, $field );
				
				// custom title
				if ( ($key = array_search($field->id, $this->_collection->custom))!==false )
				{
					$this->_collection->custom[$key] = $field->tablecolumn;
				}
			}
		}
		return $this->_fields;
	}
	
	/**
	 * Method to get an ojbect.
	 *
	 * @param	integer	The id of the object to get.
	 *
	 * @return	mixed	Object on success, false on failure.
	 */
	public function &getItemDisplay($id = null)
	{
		// Get collection
		$app		= JFactory::getApplication();
		$collection	= $this->getCollection();
		$fields		= $this->getFields();
		$params		= $app->getParams();
		
		// if ($this->_item === null)
		if (empty($this->_item))
		{
			$this->_item = false;

			if (empty($id)) {
				$id = $this->getState('item.id');
			}

			$user	= JFactory::getUser();
			$groups	= implode(',', $user->getAuthorisedViewLevels());
			
			// Create a new query object.
			$db			= $this->getDbo();
			$nullDate	= $db->getNullDate();
			$jnow		=& JFactory::getDate();
			$now		= $jnow->toMySQL();
			$query		= $db->getQuery(true);
			
			// Select the required fields from the table.
			$query->select(
				$this->getState(
					'list.select',
					'i.id, i.alias, i.collection, i.ordering, i.state, i.hits, i.created, i.created_by, i.created_by_alias, i.modified, i.modified_by, ' .
					'i.access, i.publish_up, i.publish_down, i.checked_out, i.checked_out_time, ' .
					// use created if modified is 0
					'CASE WHEN i.modified = 0 THEN i.created ELSE i.modified END as modified, ' .
						'i.modified_by, uam.name as modified_by_name'
				)
			);
			$query->from('#__collector_items AS i');
			
			// Join over the values.
			$query->join('LEFT', '#__collector_items_history_'.$collection->id.' AS h ON h.item = i.id');
			foreach($fields as $field)
			{
				$field->setQuery($query);
			}
			
			// Join over the users for the author and modified_by names.
			$query->select("CASE WHEN i.created_by_alias > ' ' THEN i.created_by_alias ELSE ua.name END AS author");
			$query->join('LEFT', '#__users AS ua ON ua.id = i.created_by');
			$query->join('LEFT', '#__users AS uam ON uam.id = i.modified_by');
			
			$query->where('h.state = 1');
			$query->where('i.collection = '.$collection->id);
			$query->where('i.id = '.$id);
			$query->where('i.access IN ('.$groups.')');
			$query->where('((i.created_by = '.$user->id.') OR (i.state = 1 AND ( i.publish_up = '.$db->Quote($nullDate).' OR i.publish_up <= '.$db->Quote($now).') AND ( i.publish_down = '.$db->Quote($nullDate).' OR i.publish_down >= '.$db->Quote($now).' )))');
			
			$whereSearch = array();
			
			$itemid = JRequest::getInt('collection', 0) . ':' . JRequest::getInt('Itemid', 0);
			
			$filter = $params->get('filter');
			
			foreach($fields as $field)
			{
				if ( $field->_field->filter == 1 )
				{
					$nameFilterCollection = 'filterfield_'.$field->_field->tablecolumn;
					if (isset($filter[$nameFilterCollection])) {
						$valueFilterMenu = $filter[$nameFilterCollection];
					} else {
						$valueFilterMenu = '';
					}

					$filtervalue = $app->getUserStateFromRequest('com_collector.collection.' . $itemid . '.'.$nameFilterCollection, $nameFilterCollection, $valueFilterMenu);
					
					$this->setState('filter.'.$nameFilterCollection, $filtervalue);
					
					if ($field->setFilterWhereClause($query,$filtervalue))
					{
						$this->_search = 1;
					}
				}
				
				$search_all_value = $this->getState('filter.filter_search_all');
				if ( $search_all_value != '' )
				{
					$this->_search = 1;
					$whereSearch[] = $field->getSearchWhereClause($query,$search_all_value);
				}
			}
			
			if (count($whereSearch) > 0 ) {
				$query->where('('.implode(' OR ', $whereSearch).')');
			}
			
			$db->setQuery($query);

			$this->_item = $db->loadObject();
			
			// Compute selected asset permissions.
			$user	= JFactory::getUser();
			$userId	= $user->get('id');
			$asset	= 'com_collector.item.'.$this->_item->id;

			// Check delete permission.
			if ($user->authorise('core.delete', $asset)) {
				$params->set('access-delete', true);
			}
			
			// Check general edit permission first.
			if ($user->authorise('core.edit', $asset)) {
				$params->set('access-edit', true);
			}
			// Now check if edit.own is available.
			elseif (!empty($userId) && $user->authorise('core.edit.own', $asset)) {
				// Check for a valid user and that they are the owner.
				if ($userId == $this->_item->created_by) {
					$params->set('access-edit', true);
				}
			}

			// Check edit state permission.
			$params->set('access-change', $user->authorise('core.edit.state', $asset));
			
			// Get item title.
			$this->_item->titleItem = '';
			foreach($collection->custom as $custom)
			{
				if ($this->_item->titleItem != '')
				{
					$this->_item->titleItem .= ' ';
				}
				$this->_item->titleItem .= $this->_item->$custom;
			}
		}
		
		return $this->_item;
	}

	/**
	 * Returns a reference to the a Table object, always creating it.
	 *
	 * @param	type	The table type to instantiate
	 * @param	string	A prefix for the table class name. Optional.
	 * @param	array	Configuration array for model. Optional.
	 * @return	JTable	A database object
	 * @since	1.6
	 */
	public function getTable($type = 'Collector_items', $prefix = 'Table', $config = array()) 
	{
		
		return JTable::getInstance($type, $prefix, $config);
	}
	
	/**
	 * Method to get a single record.
	 *
	 * @param   integer  $pk  The id of the primary key.
	 *
	 * @return  mixed    Object on success, false on failure.
	 * @since   11.1
	 */
	public function getItem($pk = null)
	{
		// Initialise variables.
		$pk		= (!empty($pk)) ? $pk : (int) $this->getState('item.id');
		$table	= $this->getTable();
		$collection = (int) $this->getState('collection.id');
		
		if ($pk > 0) {
			// Attempt to load the row.
			$return = $table->loadVersion($collection,$pk);

			// Check for a table object error.
			if ($return === false && $table->getError()) {
				$this->setError($table->getError());
				return false;
			}
		}
		else
		{
			$return = $table->initVersion($collection);
		}

		// Convert to the JObject before adding other data.
		$properties = $table->getProperties(1);
		$item = JArrayHelper::toObject($properties, 'JObject');

		if (property_exists($item, 'params')) {
			$registry = new JRegistry;
			$registry->loadString($item->params);
			$item->params = $registry->toArray();
		}

		// Convert the params field to an array.
		$registry = new JRegistry;
		$registry->loadString($item->metadata);
		$item->metadata = $registry->toArray();
		
		return $item;
	}
	
	/**
	 * Method to build the ORDER BY clause of the query to select items
	 *
	 * @access	private
	 * @return	string	ORDER BY clause
	 */
	function _buildCollectionOrderBy()
	{
		$app = JFactory::getApplication();
		
		$itemid = JRequest::getInt('collection', 0) . ':' . JRequest::getInt('Itemid', 0);
		
		$fields_order = array();
		
		$order = '';
		
		$collection	= $this->getCollection();
		$fields		= $this->getFields();
		$params		= $app->getParams();
		
		$special_order		= $params->get('order');
		if ( $special_order == 'ordering' ) {
			$order_default = 'i.ordering';
			$order_dir_default = '';
		} else if ( $special_order == 'created' ) {
			$order_default = 'i.created';
			$order_dir_default = '';
		} else if ( $special_order == 'rcreated' ) {
			$order_default = 'i.created';
			$order_dir_default = 'desc';
		} else if ( $special_order == 'modified' ) {
			$order_default = 'h.modified';
			$order_dir_default = 'desc';
		} else if ( $special_order == 'rmodified' ) {
			$order_default = 'h.modified';
			$order_dir_default = '';
		} else if ( $special_order == 'default' ) {
			foreach ($fields as $field)
			{
				$fields_order[$field->_field->id] = $field->getOrderBy();
			}
			foreach ( $collection->custom as $field )
			{
				if ( $order != '' )
				{
					$order .= ' , ';
				}
				$order .= $fields_order[$field];
			}
			$order_default = $order;
			$order_dir_default = '';
		} else {
			$order_default = 'i.ordering';
			$order_dir_default = '';
		}
		
		$orderby = $this->getState('list.ordering').' '.$this->getState('list.direction');
		
		return $orderby;
	}

	/**
	 * Method to test whether a record can have its state edited.
	 *
	 * @param	object	$record	A record object.
	 *
	 * @return	boolean	True if allowed to change the state of the record. Defaults to the permission set in the component.
	 */
	protected function canEditState($record)
	{
		$user = JFactory::getUser();

		// Check for existing collection.
		if (!empty($record->id)) {
			return $user->authorise('core.edit.state', 'com_collector.item.'.(int) $record->id);
		}
		// Default to component settings if no collection known.
		else {
			return $user->authorise('core.edit.state', 'com_collector');
		}
	}
	
	/**
     * Method to test whether a record can be deleted.
     *
     * @param   object  $record  A record object.
     *
     * @return  boolean  True if allowed to delete the record. Defaults to the permission for the component.
     *
     * @since   11.1
     */
    protected function canDelete($record)
    {
        $user = JFactory::getUser();
		
		// Check for existing collection.
		if (!empty($record->id)) {
			return $user->authorise('core.delete', 'com_collector.item.'.(int) $record->id);
		}
		// Default to component settings if no collection known.
		else {
			return $user->authorise('core.delete', 'com_collector');
		}
    }
	
	/**
	 * Method to get the record form.
	 *
	 * @param	array	$data		Data for the form.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 * @return	mixed	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true) 
	{
		jimport('joomla.utilities.simplexml');
		
		$collection = $this->getCollection();
		$fields = $this->getFields();
		
		$formXML = new JSimpleXML();
		$path = JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_collector'.DS.'models'.DS.'forms'.DS.'item.xml';
		$formXML->loadFile($path);
		$fieldset = $formXML->document->getElementByPath('fieldset');
		
		foreach ( $fields as $field )
		{
			$attributes = $field->getFieldAttributes();
			$fieldset->addChild('field',$attributes);
		}
		
		// Get the form.
		$form = $this->loadForm('com_collector.item', $formXML->document->toString(), array('control' => 'jform', 'load_data' => $loadData));
		if (empty($form)) 
		{
			return false;
		}
		
		// Determine correct permissions to check.
		if ($id = (int) $this->getState('item.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('item', 'action', 'core.edit');
			// Existing record. Can only edit own articles in selected categories.
			$form->setFieldAttribute('item', 'action', 'core.edit.own');
		}
		else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('item', 'action', 'core.create');
		}

		// Modify the form based on Edit State access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('publish_up', 'disabled', 'true');
			$form->setFieldAttribute('publish_down', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is an article you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('publish_up', 'filter', 'unset');
			$form->setFieldAttribute('publish_down', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
		}
		
		return $form;
	}
	
	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return	mixed	The data for the form.
	 * @since	1.6
	 */
	protected function loadFormData() 
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_collector.edit.item.data', array());
		if (empty($data)) 
		{
			$data = $this->getItem();
		}
		
		return $data;
	}
	
	/**
	* Method to save the form data.
	*
	* @param   array  $data  The form data.
	*
	* @return  boolean  True on success, False on error.
	* @since   11.1
	*/
	public function save($data)
	{
		// Initialise variables;
		$app		= JFactory::getApplication();
		$params		= $app->getParams();
		// $params		=& JComponentHelper::getParams( 'com_collector' );
		$dispatcher	= JDispatcher::getInstance();
		$table		= $this->getTable();
		$key		= $table->getKeyName();
		$pk			= (!empty($data[$key])) ? $data[$key] : (int)$this->getState('item.id');
		$isNew		= true;
		$collection = $data['collection'];
		
		// Include the content plugins for the on save events.
		JPluginHelper::importPlugin('content');

		// Allow an exception to be thrown.
		try
		{
			// Load the row if saving an existing record.
			if ($pk > 0) {
				$table->loadVersion($collection,$pk);
				$isNew = false;
			} else {
				$table->initVersion($collection);
			}
	
			// Bind the data.
			if (!$table->bind($data)) {
				$this->setError($table->getError());
				return false;
			}
	
			// Prepare the row for saving
			$this->prepareTable($table);
	
			// Check the data.
			if (!$table->check()) {
				$this->setError($table->getError());
				return false;
			}
	
			// Trigger the onContentBeforeSave event.
			$result = $dispatcher->trigger($this->event_before_save, array($this->option.'.'.$this->name, &$table, $isNew));
			if (in_array(false, $result, true)) {
				$this->setError($table->getError());
				return false;
			}
	
			// Store the data.
			if ( $params->get('save_history') ) {
				$version = null;
			} else {
				$version = $table->historyId;
			}
			if ( $params->get('auto_publish',1) ) {
				$table->state = 1;
			} else {
				$table->state = 0;
			}
			if (!$table->storeVersion($version)) {
				$this->setError($table->getError());
				return false;
			}
	
			// Clean the cache.
			$this->cleanCache();
	
			// Trigger the onContentAfterSave event.
			$dispatcher->trigger($this->event_after_save, array($this->option.'.'.$this->name, &$table, $isNew));
		}
		catch (Exception $e)
		{
			$this->setError($e->getMessage());
	
			return false;
		}
	
		$pkName = $table->getKeyName();
	
		if (isset($table->$pkName)) {
			$this->setState($this->getName().'.id', $table->$pkName);
		}
		$this->setState($this->getName().'.new', $isNew);
	
		return true;
	}
	
	/**
	 * Increment the hit counter for the article.
	 *
	 * @param	int		Optional primary key of the article to increment.
	 *
	 * @return	boolean	True if successful; false otherwise and internal error set.
	 */
	public function hit($pk = 0)
	{
		$hitcount = JRequest::getInt('hitcount', 1);

		if ($hitcount)
		{
			// Initialise variables.
			$pk = (!empty($pk)) ? $pk : (int) $this->getState('item.id');
			$db = $this->getDbo();

			$db->setQuery(
					'UPDATE #__collector_items' .
					' SET hits = hits + 1' .
					' WHERE id = '.(int) $pk
			);

			if (!$db->query()) {
					$this->setError($db->getErrorMsg());
					return false;
			}
		}

		return true;
	}

	/**
	 * Method to get navigation
	 * using FOR loop
	 * Put values in <var>_prev</var> and <var>_next</var>
	 *
	 * @access	public
	 * @return	void
	 */
	function getPrevNextFOR()
	{
		$db			= $this->getDbo();
		$nullDate	= $db->getNullDate();
		$jnow		=& JFactory::getDate();
		$now		= $jnow->toMySQL();
		$query		= $db->getQuery(true);
		
		$user	= JFactory::getUser();
		$groups	= implode(',', $user->getAuthorisedViewLevels());
		
		$app		= JFactory::getApplication();
		$collection	= $this->getCollection();
		$fields		= $this->getFields();
		$params		= $app->getParams();
		
		$this->_prev = 0;
		$this->_next = 0;

		// Get the WHERE and ORDER BY clauses for the query
		$orderby = $this->_buildCollectionOrderBy();

		$query->select('i.id, i.alias');
		$query->from('#__collector_items AS i');
		
		// Join over the values.
		$query->join('LEFT', '#__collector_items_history_'.$collection->id.' AS h ON h.item = i.id');
		foreach($fields as $field)
		{
			$field->setQuery($query);
		}
		
		// Join over the users for the author and modified_by names.
		$query->select("CASE WHEN i.created_by_alias > ' ' THEN i.created_by_alias ELSE ua.name END AS author");
		$query->join('LEFT', '#__users AS ua ON ua.id = i.created_by');
		$query->join('LEFT', '#__users AS uam ON uam.id = i.modified_by');
		
		$query->where('h.state = 1');
		$query->where('i.collection = '.$collection->id);
		$query->where('i.access IN ('.$groups.')');
		$query->where('((i.created_by = '.$user->id.') OR (i.state = 1 AND ( i.publish_up = '.$db->Quote($nullDate).' OR i.publish_up <= '.$db->Quote($now).') AND ( i.publish_down = '.$db->Quote($nullDate).' OR i.publish_down >= '.$db->Quote($now).' )))');
		
		$whereSearch = array();
		
		$itemid = JRequest::getInt('collection', 0) . ':' . JRequest::getInt('Itemid', 0);
		
		$filter = $params->get('filter');
		
		foreach($fields as $field)
		{
			if ( $field->_field->filter == 1 )
			{
				$nameFilterCollection = 'filterfield_'.$field->_field->tablecolumn;
				if (isset($filter[$nameFilterCollection])) {
					$valueFilterMenu = $filter[$nameFilterCollection];
				} else {
					$valueFilterMenu = '';
				}

				$filtervalue = $app->getUserStateFromRequest('com_collector.collection.' . $itemid . '.'.$nameFilterCollection, $nameFilterCollection, $valueFilterMenu);
				
				$this->setState('filter.'.$nameFilterCollection, $filtervalue);
				
				if ($field->setFilterWhereClause($query,$filtervalue))
				{
					$this->_search = 1;
				}
			}
			
			$search_all_value = $this->getState('filter.filter_search_all');
			if ( $search_all_value != '' )
			{
				$this->_search = 1;
				$whereSearch[] = $field->getSearchWhereClause($query,$search_all_value);
			}
		}
		
		if (count($whereSearch) > 0 ) {
			$query->where('('.implode(' OR ', $whereSearch).')');
		}
		
		$query->order($orderby);
		
		$db->setQuery($query);
		
		$items = $db->loadRowList();

		$total = count($items);

		$id = $this->getState('item.id');
		
		for($i=0;$i<count($items);$i++)
		{
			if ($items[$i][0] == $id)
			{
				$key = $i;
				break;
			}
		}
		
		//$key = array_search($this->_itemId, $items);
		if ( $key != 0 )
		{
			$this->_prev = $items[$key - 1][0].':'.$items[$key - 1][1];
		}
		if ( $key != $total - 1 )
		{
			$this->_next = $items[$key + 1][0].':'.$items[$key + 1][1];
		}
	}

	/**
	 * Method to get navigation
	 * using ARRAY search
	 * Put values in <var>_prev</var> and <var>_next</var>
	 *
	 * @access	public
	 * @return	void
	 */
	function getPrevNextARRAY()
	{
		$fields = $this->_collection->fields;
		$this->_prev = 0;
		$this->_next = 0;

		// Get the WHERE and ORDER BY clauses for the query
		$where = $this->_buildCollectionWhere();
		$orderby = $this->_buildCollectionOrderBy();

		$query = 'SELECT c.id,';
		$query .= ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug';
		$query .= ' FROM `#__collector_items` AS c';
		$query .= ' LEFT JOIN `#__users` AS u ON u.id = c.created_by';
		$query .= ' LEFT JOIN `#__users` AS u2 ON u2.id = c.modified_by';
		$query .= ' LEFT JOIN `#__collector_items_history_'.$this->_id.'` AS h ON h.item = c.id';

		foreach ($fields as $field)
		{
			if ($field->type == 3)
			{
				$query .= ' LEFT JOIN `#__collector_defined_content` AS d'.$field->id.' ON d'.$field->id.'.id = h.'.$field->tablecolumn;
			}
		}

		$query .= $where;
		$query .= $orderby;

		$this->_db->setQuery($query);
		$itemsId = $this->_db->loadResultArray();
		$itemsSlug = $this->_db->loadResultArray(1);

		$total = count($itemsId);

		$key = array_search($this->_itemId, $itemsId);
		if ( $key != 0 )
		{
			$this->_prev = $itemsSlug[$key - 1];
		}
		if ( $key != $total - 1 )
		{
			$this->_next = $itemsSlug[$key + 1];
		}
		
		$this->_limitstart = $this->_limit ? ((int)($key/$this->_limit))*$this->_limit : 0;
	}
	
	/**
	 * Method to get html navigation
	 * Put data in <var>_navigation</var>
	 *
	 * @access	public
	 * @return	string Navigation html
	 */
	function getNavigation()
	{
		// Load the content if it doesn't already exist
		if (empty($this->_navigation))
		{
			$this->_navigation = '';
			
			/*list($date_debut_usec, $date_debut_sec) = explode(" ", microtime());*/
			$this->getPrevNextFOR();
			/*list($date_fin_usec, $date_fin_sec) = explode(" ", microtime());
			echo 'Boucle FOR = '.($date_fin_usec - $date_debut_usec);
			
			list($date_debut_usec, $date_debut_sec) = explode(" ", microtime());
			$this->getPrevNextARRAY();
			list($date_fin_usec, $date_fin_sec) = explode(" ", microtime());
			echo ' - Joomla + Array = '.($date_fin_usec - $date_debut_usec);*/
			
			$prev = $this->_prev;
			$next = $this->_next;
			$img_base = './components/com_collector/assets/images/';
			$link_base = 'index.php';
			$link_back = $link_base;

			$option = JRequest::getVar('option', 0, 'get');
			$collection = JRequest::getVar('collection', 0, 'get');
			$item = JRequest::getVar('id', 0, 'get');
			$Itemid = JRequest::getVar('Itemid', 0, 'get');

			$link_base .= '?option='.$option.'&view=item&collection='.$collection.'&Itemid='.$Itemid;
			$link_back .= '?option='.$option.'&view=collection&id='.$collection.'&Itemid='.$Itemid;

			if ($prev == 0)
			{
				$this->_navigation .= '<img src="'.$img_base.'empty.png" />';
			}
			else
			{
				$this->_navigation .= '<a href="'.JRoute::_($link_base.'&id='. $prev) .'" ><img src="'.$img_base.'leftarrow.png" /></a>';
			}

			$this->_navigation .= '<a href="'.JRoute::_($link_back).'" ><img src="'.$img_base.'uparrow.png" /></a>';

			if ($next == 0)
			{
				$this->_navigation .= '<img src="'.$img_base.'empty.png" />';
			}
			else
			{
				$this->_navigation .= '<a href="'.JRoute::_($link_base.'&id='. $next) .'" ><img src="'.$img_base.'rightarrow.png" /></a>';
			}
		}
		return $this->_navigation;
	}
}

}

