<?php
/**
 * Joomla! 1.5 component Collector
 *
 * @version 	$Id: view.html.php 134 2012-04-05 20:45:38Z steevo $
 * @author 		Philippe Ousset steevo@steevo.fr
 * @package 	Collector
 * @license 	GNU/GPL
 *
 * Collector is a Multi Purpose Listing Tool.
 * Originaly developped to list Collections
 * it can be used for several purpose.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.view');
jimport('joomla.mail.helper');
jimport('joomla.filesystem.file');

if(version_compare(JVERSION,'1.6.0','<')){
//Code pour Joomla! 1.5
/**
 * HTML Collection View class for the Collector component
 *
 * @package	Collector
 */
class CollectorViewCollection extends JView
{
	/**
	 * Display function
	 */
	function display($tpl = null)
	{
		global $mainframe;

		//$uri 		=& JFactory::getURI();
		$user		=& JFactory::getUser();
		$document	=& JFactory::getDocument();
		$dispatcher =& JDispatcher::getInstance();
		$pathway	=& $mainframe->getPathway();
		$params		=& $mainframe->getParams('com_collector');

		// Initialize variables
		$model =& $this->getModel('collection');
		$collection	=& $model->getCollection();
		$template	=& $model->getTemplate();
		$pagination =& $model->getPagination();
		$order		=& $model->getOrder();
		$filtered	=& $model->isFiltered();
		$searched	=& $model->isSearched();

		$lists['order_default'] = $model->get('order_default');
		$lists['order_dir_default'] = $model->get('order_dir_default');

		$cparams =& $collection->parameters;
		$params->merge($cparams);

		$items =& $collection->items;
		$fields =& $collection->fields;
		$fieldsDisplayed =& $collection->fieldsDisplayed;

		if (($collection->id == 0))
		{
			$id = JRequest::getVar( 'id', '', 'default', 'int' );
			return JError::raiseError( 404, JText::sprintf( 'COM_COLLECTOR_COLLECTION_NOT_FOUND', $id ) );
		}

		// Check to see if the user has access to view the full collection
		$aid	= $user->get('aid');

		if ($collection->access <= $aid) {

		} else {
			if ( ! $aid )
			{
				// Redirect to login
				$uri		= JFactory::getURI();
				$return		= $uri->toString();

				$url  = 'index.php?option=com_user&view=login';
				$url .= '&return='.base64_encode($return);;

				//$url	= JRoute::_($url, false);
				$mainframe->redirect($url, JText::_('COM_COLLECTOR_YOU_MUST_LOGIN_FIRST') );
			}
			else{
				JError::raiseWarning( 403, JText::_('COM_COLLECTOR_ALERTNOTAUTH') );
				return;
			}
		}

		/*
		 * Process the prepare content plugins
		 */
		JPluginHelper::importPlugin('collector');


		/*
		 * Handle the metadata
		 */
		// because the application sets a default page title, we need to get it
		// right from the menu item itself
		// Get the menu item object
		$menus = &JSite::getMenu();
		$menu  = $menus->getActive();

		if (is_object( $menu ) && isset($menu->query['view']) && $menu->query['view'] == 'collection' && isset($menu->query['id']) && $menu->query['id'] == $collection->id) {
			$menu_params = new JParameter( $menu->params );
			if (!$menu_params->get( 'collection_title')) {
				$params->set('collection_title',	$collection->name);
			}
		} else {
			$params->set('collection_title',	$collection->name);
		}
		$document->setTitle( $params->get( 'page_title' ) );

		if ($collection->metadesc) {
			$document->setDescription( $collection->metadesc );
		}
		if ($collection->metakey) {
			$document->setMetadata('keywords', $collection->metakey);
		}

		if ($mainframe->getCfg('MetaTitle') == '1') {
			$mainframe->addMetaTag('title', $collection->name);
		}
		if ($mainframe->getCfg('MetaAuthor') == '1') {
			$mainframe->addMetaTag('author', $collection->author);
		}

		$mdata = new JParameter($collection->metadata);
		$mdata = $mdata->toArray();
		foreach ($mdata as $k => $v)
		{
			if ($v) {
				$document->setMetadata($k, $v);
			}
		}

		$itemid = JRequest::getVar( 'Itemid', '', 'default', 'int' );

		// table ordering
		$lists['order_Dir'] = $model->get('filter_order_Dir');
		$lists['order'] = $model->get('filter_order');

		$uri		=& JFactory::getURI();

		$query = array();
		$query['option'] = 'com_collector';
		$query['view'] = 'collection';
		$query['id'] = $collection->id.':'.$collection->alias;
		$query['reset'] = 0;
		$query['Itemid'] = $itemid;

		$uri->setPath('/index.php');

		$uri->setPath('');

		$action = JRoute::_('index.php?'.$uri->buildQuery($query));

		$this->assign('action', $action);

		$this->assignRef('collection', $collection);
		$this->assignRef('template', $template);
		$this->assignRef('params' , $params);
		$this->assignRef('itemid' , $itemid);
		$this->assignRef('items' , $items);
		$this->assignRef('fields' , $fields);
		$this->assignRef('fieldsDisplayed' , $fieldsDisplayed);
		$this->assignRef('user'   , $user);
		$this->assignRef('pagination', $pagination );
		$this->assignRef('order', $order );
		$this->assignRef('lists', $lists);
		$this->assignRef('searched', $searched);

		parent::display($tpl);
	}

	/**
	 * Method to display a field
	 *
	 * @access	public
	 * @param	object	$field	Field to display
	 * @param	object	$row	Item
	 * @return	string			HTML field
	 */
	function display_field_row($field, $row)
	{
		$db =& JFactory::getDBO();

		$model = $this->getModel('collection');
		$fieldId = $field->id;
		$fieldType = $field->type;

		//$value = 'field_'.$fieldId;
		$value = $field->tablecolumn;

		$emailMode = $this->params->get('emailMode');
		$weblinkMode = $this->params->get('weblinkMode');

		switch($fieldType)
		{
			// line
			case 1:
				if ( ( $emailMode == 1 ) && ( JMailHelper::isEmailAddress($row->$value) ) )
				{
					echo JHTML::_('email.cloak', $row->$value);
				}
				else if ( ( $weblinkMode == 1 ) && ( preg_match("=www.=", $row->$value) ) )
				{
					$url = trim($row->$value);
					// check en tete
					if ( !preg_match("=://=", $url) ) {
						$url = "http://".$url;
					}

					$motif='#^^http://([a-zA-Z0-9-]+.)?([a-zA-Z0-9-]+.)?[a-zA-Z0-9-]+\.[a-zA-Z]{2,4}(:[0-9]+)?(/[a-zA-Z0-9-]*)?(.[a-zA-Z0-9]{1,4})?$#';
					if ( preg_match($motif,$url) ) {
						echo '<a href="'.$url.'">'.$row->$value.'</a>';
					} else {
						echo htmlspecialchars($row->$value, ENT_QUOTES);
					}
				}
				else
				{
					echo htmlspecialchars($row->$value, ENT_QUOTES);
				}
				break;
			// text
			case 2:
				echo $row->$value;
				break;
			// define
			case 3:
				$query = 'SELECT content, image, defined';
				$query .= ' FROM #__collector_defined_content';
				$query .= ' WHERE id = "'.$row->$value.'"';

				$db->setQuery( $query );

				$result = $db->loadObject();

				if ( $result != null )
				{
					if ( JFile::exists($result->image) )
					{
						$query = 'SELECT width, height';
						$query .= ' FROM #__collector_defined';
						$query .= ' WHERE id = "'.$result->defined.'"';

						$db->setQuery( $query );

						$image = $db->loadObject();

						$imagePath=implode(DS,explode('/',$result->image));
						$imagePath=JPATH_SITE.DS.$imagePath;
						$taille=getimagesize($imagePath);
						$largeur=$taille[0];
						$hauteur=$taille[1];

						$largeurmax = $image->width ? $image->width : $largeur;
						$hauteurmax = $image->height ? $image->height : $hauteur;

						if ( ($hauteur/$hauteurmax) < ($largeur/$largeurmax) )
						{
							if ($largeur < $largeurmax)
							{
								$size= ' width="'.$largeur.'"';
							}
							else
							{
								$size= ' width="'.$largeurmax.'"';
							}
						}
						else
						{
							if ($hauteur < $hauteurmax)
							{
								$size= ' height="'.$hauteur.'"';
							}
							else
							{
								$size= ' height="'.$hauteurmax.'"';
							}
						}
						
						$return = '<img src="'.$result->image.'" alt="'.$result->content.'" title="'.$result->content.'" '.$size.' />';
					} else {
						$return = $result->content;
					}
				} else {
					$return = '';
				}
				echo $return;
				break;
			// object
			case 4 :
				$object = $model->getObject($field,$row->$value);
				if ($object)
				{
					$link = JRoute::_('index.php?option=com_collector&view=item&id='.$object->collection.'&item='.$object->slug);
					
					echo '<a href="'.$link.'">'.$object->name.'</a>';
				}
				break;
			// image
			case 5:
				if ($row->$value == '' ) {
					$row->$value = '||||';
				}
				$imageInfos = explode('|',$row->$value);
				$imageUrl = $imageInfos[0];
				$imagePath = implode(DS,explode('/',$imageUrl));
				$imageName = JFile::getName(JPATH_SITE.DS.$imagePath);
				$imageDesc = $imageInfos[1] ? $imageInfos[1] : $imageName;
				$imageTitle = $imageInfos[2] ? $imageInfos[2] : $imageName;
				$largeurmax = $imageInfos[3] ? $imageInfos[3] : 100;
				$hauteurmax = $imageInfos[4] ? $imageInfos[4] : 80;

				$image = '';

				if ($imageUrl == '')
				{
					// image de substitution
					$image=JPATH_SITE.DS.'components'.DS.'com_collector'.DS.'assets'.DS.'images'.DS.'camera.png'; // adresse de l'image
					$URLimage='./components/com_collector/assets/images/camera.png'; // adresse de l'image
				}
				else
				{
					$image=JPATH_SITE.DS.$imageUrl; // adresse de l'image
					if (!file_exists($image)) {
						$image=JPATH_SITE.DS.'components'.DS.'com_collector'.DS.'assets'.DS.'images'.DS.'camera.png'; // adresse de l'image
						$URLimage='./components/com_collector/assets/images/camera.png'; // adresse de l'image
					} else {
						$URLimage='./'.$imageUrl; // adresse de l'image
					}
				}

				$taille=getimagesize($image);
				$largeur=$taille[0];
				$hauteur=$taille[1];

				if ( ($hauteur/$hauteurmax) < ($largeur/$largeurmax) )
				{
					if ($largeur < $largeurmax)
					{
						$size= ' width="'.$largeur.'"';
					}
					else
					{
						$size= ' width="'.$largeurmax.'"';
					}
				}
				else
				{
					if ($hauteur < $hauteurmax)
					{
						$size= ' height="'.$hauteur.'"';
					}
					else
					{
						$size= ' height="'.$hauteurmax.'"';
					}
				}

				echo '<img alt="'.$imageDesc.'" title="'.$imageTitle.'" align="middle" border="1" src="'.$URLimage.'" '.$size.' />';
				break;
			// nombre
			case 6:
				if ( $row->$value != '' )
				{
					$query = 'SELECT template';
					$query .= ' FROM #__collector_fields';
					$query .= ' WHERE id = "'.$fieldId.'"';

					$db->setQuery( $query );

					$template = $db->loadResult();
					if ( $template == '' )
					{
						$template = '%%';
					}

					$return = JString::str_ireplace( '%%', $row->$value, $template );
				}
				else
				{
					$return = '';
				}
				echo $return;
				break;
			// date
			case 7:
				$query = 'SELECT template';
				$query .= ' FROM #__collector_fields';
				$query .= ' WHERE id = "'.$fieldId.'"';

				$db->setQuery( $query );

				$template = $db->loadResult();
				if ( $template == '' )
				{
					$template = '%Y-%m-%d %H:%M:%S';
				}
				$timestamp = strtotime($row->$value);
				echo JHTML::_( 'date', $timestamp, $template, 0);
				break;
			// file
			case 8:
				$fileInfos = explode('|',$row->$value);
				$fileUrl = $fileInfos[0];
				
				if ( $fileUrl == '' )
				{
					$return = '';
				}
				else
				{
					$filePath = implode(DS,explode('/',$fileUrl));
					$fileName = JFile::getName(JPATH_SITE.DS.$filePath);
					$fileDesc = $fileInfos[1] ? $fileInfos[1] : $fileName;
					$fileTitle = $fileInfos[2] ? $fileInfos[1] : $fileName;
					
					$ext = JFile::getExt(JPATH_SITE.DS.$filePath);
					$query = 'SELECT ico';
					$query .= ' FROM #__collector_files_ext';
					$query .= ' WHERE ext="'.$ext.'"';
					$db->setQuery( $query );
					$ico = $db->loadResult();
					$URLico='./administrator/components/com_collector/assets/images/'.$ico;
					$return = '<a href="'.$fileUrl.'" target="_blank" title="'.$fileTitle.'" ><img src="'.$URLico.'" /> '. $fileDesc . '</a>';
				}
				echo $return;
				break;
		}
	}

	/**
	 * Method to display search area
	 *
	 * @access	public
	 * @return	string	HTML search area
	 */
	function display_fields_search()
	{
		global $mainframe, $option;
		$db =& JFactory::getDBO();

		if(version_compare(JVERSION,'1.6.0','<')){
			//Code pour Joomla! 1.5
			$reset = $mainframe->getUserState($option.'.collection.reset');
			$search_all_value = $mainframe->getUserStateFromRequest('collection.filter_search_all', 'filter_search_all');
		}else{
			//Code pour Joomla >= 1.6.0
			$app = JFactory::getApplication();
			$reset = $app->getUserState($option.'.collection.reset');
			$search_all_value = $app->getUserStateFromRequest('collection.filter_search_all', 'filter_search_all');
		}


		echo '<table width="100%" >
				<tbody><tr><td width="100%" style="text-align: center;" >';

		if ( $this->params->get('show_word_filter', 1) )
		{
			echo '<div style="display: inline-block; margin-right: 10px; margin-bottom: 10px" >'. JText::_( 'COM_COLLECTOR_FILTER' ).' <input type="text" name="filter_search_all" class="inputbox" value="'.$search_all_value.'"/>'.'</div>';
		}

		$init[] = array('value' => 0, 'text' => '*');

		foreach ($this->fields as $field)
		{
			if ( ( $field->type == 3 ) && ( $field->filter == 1 ) )
			{
				// Get list of collections
				$db =& JFactory::getDBO();
				$query = 'SELECT id AS value, content AS text ';
				$query .= ' FROM #__collector_defined_content';
				$query .= ' WHERE defined = "'.$field->defined.'"';
				$query .= ' ORDER BY content';
				$db->setQuery( $query );

				$results = $db->loadObjectList();

				$select = $init;
				foreach ( $results as $key => $value )
				{
					$select[$key+1]=$value;
				}

				$nameFilterCollection = 'filterfield_'.$field->id;
				$valueFilterMenu = $this->params->get( $nameFilterCollection, 0 );
				
				if(version_compare(JVERSION,'1.6.0','<')){
					//Code pour Joomla! 1.5
					$filter_field = $reset ? $valueFilterMenu : $mainframe->getUserStateFromRequest( $option.'.collection.filter_field_'.$field->id, 'filter_field_'.$field->id, '', 'int' );
				}else{
					//Code pour Joomla >= 1.6.0
					$app = JFactory::getApplication();
					$filter_field = $reset ? $valueFilterMenu : $app->getUserStateFromRequest( $option.'.collection.filter_field_'.$field->id, 'filter_field_'.$field->id, '', 'int' );
				}

				$selectlists['field_'.$field->id] = JHTML::_('select.genericlist', $select, 'filter_field_'.$field->id, ' class="inputbox" size="1" ', 'value', 'text', $filter_field);

				if ( (!$valueFilterMenu) || ( $valueFilterMenu && (!$this->params->get('hide_filter'))) )
				{
					echo '<div style="display: inline-block; margin-right: 10px; margin-bottom: 10px" >'.$field->field.'  '.$selectlists['field_'.$field->id].'</div>';
				}
				else
				{
					echo '<input type=hidden name=\'filter_field_'.$field->id.'\' value=\''.$filter_field.'\' />';
				}
			}
		}
		echo '<div style="display: inline-block; margin-bottom: 10px;" ><button style="margin-right: 10px;" class="button" onclick="this.form.submit();">'.JText::_( 'COM_COLLECTOR_SEARCH' ).'</button><button class="button" onclick="initialiser();this.form.submit();">'.JText::_( 'COM_COLLECTOR_INIT' ).'</button></div>';
		echo '</td></tr></tbody>
			</table>';
	}

	/**
	 * Method to check if string is an email address
	 *
	 * @access	public
	 * @param	string	$address	String to check
	 * @return	boolean				True if string is an email address
	 */
	function isEmail($address)
	{
		$motif='#^[\w.-]+@[\w.-]+\.[a-zA-Z]{2,6}$#';
		if(preg_match($motif,$address))
			return true;
		else
			return false;
	}

	/**
	 * Method to check if string is an url
	 *
	 * @access	public
	 * @param	string	$url	String to check
	 * @return	boolean			True if string is an url
	 */
	function isLink($url)
	{
		$motif='#^^http://([a-zA-Z0-9-]+.)?([a-zA-Z0-9-]+.)?[a-zA-Z0-9-]+\.[a-zA-Z]{2,4}(:[0-9]+)?(/[a-zA-Z0-9-]*)?(.[a-zA-Z0-9]{1,4})?$#';
		if(preg_match($motif,$url))
			return true;
		else
			return false;
	}
}

}else{
//Code pour Joomla >= 1.6.0
/**
 * HTML Collection View class for the Collector component
 *
 * @package	Collector
 */
class CollectorViewCollection extends JView
{
	protected $state;
	protected $items;
	protected $pagination;
	
	/**
	 * Display function
	 */
	function display($tpl = null)
	{
		$app		= JFactory::getApplication();
		$params		= $app->getParams();

		$uri =& JFactory::getURI();
		$uri->delVar('reset');
		
		// Get some data from the models
		$state		= $this->get('State');
		$collection	= $this->get('Collection');
		$fields		= $this->get('Fields');
		$items		= $this->get('Items');
		$pagination	= $this->get('Pagination');
		$searched	= $this->get('Searched');
		$pagination->setAdditionalUrlParam('reset',0);
		
		// Check for errors.
		if ($collection->id == 0) {
			$id = JRequest::getVar( 'id', '', 'default', 'int' );
			return JError::raiseError(404, JText::sprintf( 'COM_COLLECTOR_COLLECTION_NOT_FOUND', $id ));
		}

		// Check whether category access level allows access.
		$user	= JFactory::getUser();
		$groups	= $user->getAuthorisedViewLevels();
		if (!in_array($collection->access, $groups)) {
			return JError::raiseError(403, JText::_('COM_COLLECTOR_ALERTNOTAUTH'));
		}
		
		// Compute the collection slug.
		$collection->slug = $collection->alias ? ($collection->id . ':' . $collection->alias) : $collection->id;
		
		// Compute the item slugs.
		for ($i = 0, $n = count($items); $i < $n; $i++)
		{
			$item = &$items[$i];
			$item->slug = $item->alias ? ($item->id . ':' . $item->alias) : $item->id;
		}
		
		//Escape strings for HTML output
		$this->pageclass_sfx = htmlspecialchars($params->get('pageclass_sfx'));
		
		$this->assignRef('params' , $params);
		$this->assignRef('state' , $state);
		$this->assignRef('collection' , $collection);
		$this->assignRef('fields' , $fields);
		$this->assignRef('items' , $items);
		$this->assignRef('pagination', $pagination );
		$this->assignRef('searched', $searched);
		
		$this->_prepareDocument();
		
		parent::display($tpl);
	}
	
	/**
	 * Prepares the document
	 */
	protected function _prepareDocument()
	{
		$app		= JFactory::getApplication();
		$menus		= $app->getMenu();
		$pathway	= $app->getPathway();
		$title		= null;

		// Because the application sets a default page title,
		// we need to get it from the menu item itself
		$menu = $menus->getActive();

		if ($menu) {
			$this->params->def('page_heading', $this->params->get('page_title', $menu->title));
		}
		else {
			$this->params->def('page_heading', $this->collection->name);
		}

		if ($menu && ($menu->query['option'] != 'com_collector' || $menu->query['view'] != 'collection' )) {
			$path = array(array('title' => $this->collection->name, 'link' => ''));

			$path = array_reverse($path);

			foreach ($path as $item)
			{
				$pathway->addItem($item['title'], $item['link']);
			}
			
			$this->params->set('page_heading', $this->collection->name);
		}

		// $title = $this->params->get('page_title', '');

		// if (empty($title)) {
			// $title = $app->getCfg('sitename');
		// }
		// elseif ($app->getCfg('sitename_pagetitles', 0) == 1) {
			// $title = JText::sprintf('JPAGETITLE', $app->getCfg('sitename'), $title);
		// }
		// elseif ($app->getCfg('sitename_pagetitles', 0) == 2) {
			// $title = JText::sprintf('JPAGETITLE', $title, $app->getCfg('sitename'));
		// }

		// $this->document->setTitle($title);

		// if ($this->category->metadesc)
		// {
			// $this->document->setDescription($this->category->metadesc);
		// }
		// elseif (!$this->category->metadesc && $this->params->get('menu-meta_description'))
		// {
			// $this->document->setDescription($this->params->get('menu-meta_description'));
		// }

		// if ($this->category->metakey)
		// {
			// $this->document->setMetadata('keywords', $this->category->metakey);
		// }
		// elseif (!$this->category->metakey && $this->params->get('menu-meta_keywords'))
		// {
			// $this->document->setMetadata('keywords', $this->params->get('menu-meta_keywords'));
		// }

		// if ($this->params->get('robots'))
		// {
			// $this->document->setMetadata('robots', $this->params->get('robots'));
		// }

		// if ($app->getCfg('MetaAuthor') == '1') {
			// $this->document->setMetaData('author', $this->category->getMetadata()->get('author'));
		// }

		// $mdata = $this->category->getMetadata()->toArray();

		// foreach ($mdata as $k => $v)
		// {
			// if ($v) {
				// $this->document->setMetadata($k, $v);
			// }
		// }
	}
}
}
?>
